@@ -58,17 +58,17 @@ class GrantAccessAction(WorkflowAction):
     widgets = {
         'content_type': {
             'class': 'django.forms.widgets.Select', 'kwargs': {
-                'attrs': {'class': 'select2'},
+                'attrs': {'class': 'select2'}
             }
         },
         'roles': {
             'class': 'django.forms.widgets.SelectMultiple', 'kwargs': {
-                'attrs': {'class': 'select2'},
+                'attrs': {'class': 'select2'}
             }
         },
         'permissions': {
             'class': 'django.forms.widgets.SelectMultiple', 'kwargs': {
-                'attrs': {'class': 'select2'},
+                'attrs': {'class': 'select2'}
             }
         }
     }
@@ -84,18 +84,23 @@ class GrantAccessAction(WorkflowAction):
         )
 
         content_type = ContentType.objects.get(
-            pk=int(form_data['action_data']['content_type'])
+            pk=int(
+                form_data['action_data']['content_type']
+            )
         )
         obj = content_type.get_object_for_this_type(
-            pk=int(form_data['action_data']['object_id'])
+            pk=int(
+                form_data['action_data']['object_id']
+            )
         )
 
         try:
             AccessControlList.objects.check_access(
-                obj=obj, permissions=(permission_acl_edit,), user=request.user
+                obj=obj, permissions=(permission_acl_edit,),
+                user=request.user
             )
         except Exception as exception:
-            raise ValidationError(exception)
+            raise ValidationError(message=exception)
         else:
             return form_data
 
@@ -117,10 +122,12 @@ class GrantAccessAction(WorkflowAction):
         self.obj = content_type.get_object_for_this_type(
             pk=self.form_data['object_id']
         )
-        self.roles = Role.objects.filter(pk__in=self.form_data['roles'])
+        self.roles = Role.objects.filter(
+            pk__in=self.form_data['roles']
+        )
         self.permissions = [
             Permission.get(
-                pk=permission, class_only=True
+                pk=permission
             ) for permission in self.form_data['permissions']
         ]
 
@@ -171,12 +178,12 @@ class GrantDocumentAccessAction(WorkflowAction):
     widgets = {
         'roles': {
             'class': 'django.forms.widgets.SelectMultiple', 'kwargs': {
-                'attrs': {'class': 'select2'},
+                'attrs': {'class': 'select2'}
             }
         },
         'permissions': {
             'class': 'django.forms.widgets.SelectMultiple', 'kwargs': {
-                'attrs': {'class': 'select2'},
+                'attrs': {'class': 'select2'}
             }
         }
     }
@@ -188,10 +195,12 @@ class GrantDocumentAccessAction(WorkflowAction):
         return super().get_form_schema(*args, **kwargs)
 
     def get_execute_data(self):
-        self.roles = Role.objects.filter(pk__in=self.form_data['roles'])
+        self.roles = Role.objects.filter(
+            pk__in=self.form_data['roles']
+        )
         self.permissions = [
             Permission.get(
-                pk=permission, class_only=True
+                pk=permission
             ) for permission in self.form_data['permissions']
         ]
 
