@@ -2,7 +2,9 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.events.classes import EventTypeNamespace
 
-namespace = EventTypeNamespace(label=_('Announcements'), name='announcement')
+namespace = EventTypeNamespace(
+    label=_('Announcements'), name='announcement'
+)
 
 event_announcement_created = namespace.add_event_type(
     label=_('Announcement created'), name='announcement_created'
