@@ -1,6 +1,10 @@
 COMMENT_APP_TEMPLATE_CACHE_DISABLE = '{# appearance_app_template_nocache #}'
 
+COMMAND_NAME_APPEARANCE_PREPARE_STATIC = 'appearance_prepare_static'
+
 DEFAULT_AJAX_REDIRECTION_CODE = 278
 DEFAULT_MAXIMUM_TITLE_LENGTH = 120
 DEFAULT_MESSAGE_POSITION = 'top-right'
 DEFAULT_MENU_POLLING_INTERVAL = 5000
+DEFAULT_THROTTLING_MAXIMUM_REQUESTS = 10
+DEFAULT_THROTTLING_TIMEOUT = 5000
