@@ -45,11 +45,11 @@ class Theme(models.Model):
         event_manager_class=EventManagerSave,
         created={
             'event': event_theme_created,
-            'target': 'self',
+            'target': 'self'
         },
         edited={
             'event': event_theme_edited,
-            'target': 'self',
+            'target': 'self'
         }
     )
     def save(self, *args, **kwargs):
