@@ -7,4 +7,4 @@ class ThemeTestCase(ThemeTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_theme()
 
-        self.assertTrue(self.test_theme.get_absolute_url())
+        self.assertTrue(self._test_theme.get_absolute_url())
