@@ -11,7 +11,7 @@ from mayan.apps.views.generics import (
     SingleObjectCreateView, SingleObjectDeleteView, SingleObjectDetailView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalObjectViewMixin
 
 from .forms import ThemeForm, UserThemeSettingForm, UserThemeSettingForm_view
 from .icons import (
@@ -96,7 +96,7 @@ class ThemeListView(SingleObjectListView):
             'no_results_title': _(
                 'There are no themes'
             ),
-            'title': _('Themes'),
+            'title': _('Themes')
         }
 
 
