@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from django.apps import apps
 
 
@@ -10,8 +8,7 @@ def handler_auto_admin_account_password_change(sender, instance, **kwargs):
 
     auto_admin_properties, created = AutoAdminSingleton.objects.get_or_create()
 
-    if instance == auto_admin_properties.account and \
-       instance.password != auto_admin_properties.password_hash:
+    if instance == auto_admin_properties.account and instance.password != auto_admin_properties.password_hash:
         # Only delete the auto admin properties when the password
         # has been changed
         auto_admin_properties.account = None
