@@ -17,8 +17,8 @@ from mayan.apps.navigation.classes import SourceColumn
 from mayan.apps.rest_api.fields import DynamicSerializerField
 
 from .events import (
-    event_cabinet_edited, event_cabinet_document_added,
-    event_cabinet_document_removed
+    event_cabinet_deleted, event_cabinet_edited,
+    event_cabinet_document_added, event_cabinet_document_removed
 )
 from .handlers import handler_cabinet_pre_delete, handler_index_document
 from .html_widgets import DocumentCabinetWidget
@@ -33,9 +33,9 @@ from .links import (
 from .menus import menu_cabinets
 from .methods import method_document_get_cabinets
 from .permissions import (
-    permission_cabinet_add_document, permission_cabinet_delete,
-    permission_cabinet_edit, permission_cabinet_remove_document,
-    permission_cabinet_view
+    permission_cabinet_add_document, permission_cabinet_create,
+    permission_cabinet_delete, permission_cabinet_edit,
+    permission_cabinet_remove_document, permission_cabinet_view
 )
 
 
@@ -108,8 +108,8 @@ class CabinetsApp(MayanAppConfig):
 
         ModelEventType.register(
             model=Cabinet, event_types=(
-                event_cabinet_edited, event_cabinet_document_added,
-                event_cabinet_document_removed
+                event_cabinet_deleted, event_cabinet_edited,
+                event_cabinet_document_added, event_cabinet_document_removed
             )
         )
         ModelEventType.register(
@@ -128,14 +128,17 @@ class CabinetsApp(MayanAppConfig):
         ModelPermission.register(
             model=Cabinet, permissions=(
                 permission_acl_edit, permission_acl_view,
-                permission_cabinet_delete, permission_cabinet_edit,
-                permission_cabinet_view, permission_cabinet_add_document,
+                permission_cabinet_create, permission_cabinet_delete,
+                permission_cabinet_edit, permission_cabinet_view,
+                permission_cabinet_add_document,
                 permission_cabinet_remove_document
             ), bind_link=False
         )
 
         model_query_fields_document = ModelQueryFields(model=Document)
-        model_query_fields_document.add_prefetch_related_field(field_name='cabinets')
+        model_query_fields_document.add_prefetch_related_field(
+            field_name='cabinets'
+        )
 
         def get_root_filter():
             return {
