@@ -1,22 +1,14 @@
-from django.db import connection
 from django.utils.translation import ugettext_lazy as _
+
 from mayan.apps.documents.search import (
     search_model_document, search_model_document_file,
     search_model_document_file_page, search_model_document_version,
     search_model_document_version_page
 )
-from mayan.apps.dynamic_search.classes import SearchModel
+from mayan.apps.dynamic_search.search_models import SearchModel
 
 from .permissions import permission_cabinet_view
 
-
-def transformation_format_uuid(term_string):
-    if connection.vendor in ('mysql', 'sqlite'):
-        return term_string.replace('-', '')
-    else:
-        return term_string
-
-
 # Cabinet
 
 search_model_cabinet = SearchModel(
@@ -42,8 +34,7 @@ search_model_cabinet.add_model_field(
     field='documents__description', label=_('Document description')
 )
 search_model_cabinet.add_model_field(
-    field='documents__uuid', label=_('Document UUID'),
-    transformation_function=transformation_format_uuid
+    field='documents__uuid', label=_('Document UUID')
 )
 
 # Cabinet documents files
