@@ -3,7 +3,7 @@ from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..events import (
-    event_cabinet_created, event_cabinet_edited,
+    event_cabinet_created, event_cabinet_deleted, event_cabinet_edited,
     event_cabinet_document_added, event_cabinet_document_removed
 )
 from ..models import Cabinet
@@ -170,9 +170,7 @@ class CabinetViewTestCase(
 class CabinetChildViewTestCase(
     CabinetTestMixin, CabinetViewTestMixin, GenericViewTestCase
 ):
-    def setUp(self):
-        super().setUp()
-        self._create_test_cabinet()
+    auto_create_test_cabinet = True
 
     def test_cabinet_child_create_view_no_permission(self):
         cabinet_count = Cabinet.objects.count()
@@ -189,7 +187,7 @@ class CabinetChildViewTestCase(
 
     def test_cabinet_child_create_view_with_access(self):
         self.grant_access(
-            obj=self._test_cabinet, permission=permission_cabinet_edit
+            obj=self._test_cabinet, permission=permission_cabinet_create
         )
         cabinet_count = Cabinet.objects.count()
 
@@ -201,15 +199,15 @@ class CabinetChildViewTestCase(
         self._test_cabinets[0].refresh_from_db()
         self.assertEqual(Cabinet.objects.count(), cabinet_count + 1)
         self.assertTrue(
-            self._test_cabinets[1] in self._test_cabinets[0].get_descendants()
+            self._test_cabinet_child in self._test_cabinets[0].get_descendants()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].action_object, self._test_cabinet)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self._test_cabinet)
+        self.assertEqual(events[0].target, self._test_cabinet_child)
         self.assertEqual(events[0].verb, event_cabinet_created.id)
 
     def test_cabinet_child_delete_view_no_permission(self):
@@ -243,18 +241,23 @@ class CabinetChildViewTestCase(
         self.assertEqual(Cabinet.objects.count(), cabinet_count - 1)
 
         events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, self._test_cabinet)
+        self.assertEqual(events[0].actor, self._test_cabinet)
+        self.assertEqual(events[0].target, None)
+        self.assertEqual(events[0].verb, event_cabinet_deleted.id)
 
 
 class CabinetDocumentViewTestCase(
     CabinetTestMixin, CabinetViewTestMixin, GenericDocumentViewTestCase
 ):
+    auto_create_test_cabinet = True
     auto_upload_test_document = False
 
     def setUp(self):
         super().setUp()
         self._create_test_document_stub()
-        self._create_test_cabinet()
 
     def test_cabinet_add_document_view_no_permission(self):
         self.grant_permission(permission=permission_cabinet_view)
@@ -414,7 +417,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_remove_document_view_no_permission(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         cabinet_document_count = self._test_cabinet.documents.count()
 
@@ -432,7 +437,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_remove_document_view_with_access(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self.grant_access(
             obj=self._test_cabinet,
@@ -464,7 +471,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events[0].verb, event_cabinet_document_removed.id)
 
     def test_cabinet_remove_trashed_document_view_with_access(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self.grant_access(
             obj=self._test_cabinet,
@@ -493,7 +502,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_document_list_view_no_permission(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self._clear_events()
 
@@ -509,7 +520,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_document_list_view_with_cabinet_access(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self.grant_access(
             obj=self._test_cabinet, permission=permission_cabinet_view
@@ -529,7 +542,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_document_list_view_with_document_access(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self.grant_access(
             obj=self._test_document, permission=permission_document_view
@@ -549,7 +564,9 @@ class CabinetDocumentViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_cabinet_document_list_view_with_full_access(self):
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
 
         self.grant_access(
             obj=self._test_cabinet, permission=permission_cabinet_view
@@ -601,12 +618,12 @@ class DocumentCabinetViewTestCase(
     CabinetTestMixin, DocumentCabinetViewTestMixin,
     GenericDocumentViewTestCase
 ):
+    auto_create_test_cabinet = True
     auto_upload_test_document = False
 
     def setUp(self):
         super().setUp()
         self._create_test_document_stub()
-        self._create_test_cabinet()
 
     def test_document_cabinet_list_view_no_permission(self):
         self._test_document.cabinets.add(self._test_cabinet)
