@@ -1,5 +1,3 @@
-from django.utils.encoding import force_text
-
 from mayan.apps.documents.permissions import (
     permission_document_file_view, permission_document_version_view,
     permission_document_view
@@ -11,7 +9,7 @@ from mayan.apps.documents.search import (
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.dynamic_search.literals import SEARCH_MODEL_NAME_KWARG
-from mayan.apps.dynamic_search.tests.mixins import SearchViewTestMixin
+from mayan.apps.dynamic_search.tests.mixins.view_mixins import SearchViewTestMixin
 
 from ..permissions import permission_cabinet_view
 
@@ -27,16 +25,18 @@ class DocumentSearchResultWidgetViewTestCase(
         super().setUp()
         self._create_test_cabinet()
         self._upload_test_document()
-        self._test_cabinet.document_add(document=self._test_document)
+        self._test_cabinet.document_add(
+            document=self._test_document, user=self._test_case_user
+        )
         self._test_object_permission = permission_document_view
         self._test_object_text = self._test_document.label
         self._test_search_model = search_model_document
-        self._test_search_term_data = {'uuid': self._test_document.uuid}
+        self._test_search_term_data = {'uuid': str(self._test_document.uuid)}
 
     def test_document_cabinet_widget_no_permission(self):
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertNotContains(
@@ -55,7 +55,7 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertNotContains(
@@ -73,7 +73,7 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertContains(
@@ -91,7 +91,7 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertNotContains(
@@ -112,9 +112,10 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
+
         self.assertContains(
             response=response, text=self._test_object_text, status_code=200
         )
@@ -133,7 +134,7 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertContains(
@@ -157,7 +158,7 @@ class DocumentSearchResultWidgetViewTestCase(
 
         response = self._request_search_results_view(
             data=self._test_search_term_data, kwargs={
-                SEARCH_MODEL_NAME_KWARG: self._test_search_model.get_full_name()
+                SEARCH_MODEL_NAME_KWARG: self._test_search_model.full_name
             }
         )
         self.assertContains(
@@ -178,7 +179,7 @@ class DocumentFileSearchResultWidgetViewTestCase(
         self._test_object_permission = permission_document_file_view
         self._test_search_model = search_model_document_file
         self._test_search_term_data = {
-            'document__uuid': self._test_document.uuid
+            'document__uuid': str(self._test_document.uuid)
         }
 
 
@@ -187,11 +188,11 @@ class DocumentFilePageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self._test_document_file.pages.first())
+        self._test_object_text = str(self._test_document_file.pages.first())
         self._test_object_permission = permission_document_file_view
         self._test_search_model = search_model_document_file_page
         self._test_search_term_data = {
-            'document_file__document__uuid': self._test_document.uuid
+            'document_file__document__uuid': str(self._test_document.uuid)
         }
 
 
@@ -200,11 +201,11 @@ class DocumentVersionSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self._test_document_version)
+        self._test_object_text = str(self._test_document_version)
         self._test_object_permission = permission_document_version_view
         self._test_search_model = search_model_document_version
         self._test_search_term_data = {
-            'document__uuid': self._test_document.uuid
+            'document__uuid': str(self._test_document.uuid)
         }
 
 
@@ -213,9 +214,11 @@ class DocumentVersionPageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self._test_document_version.pages.first())
+        self._test_object_text = str(
+            self._test_document_version.pages.first()
+        )
         self._test_object_permission = permission_document_version_view
         self._test_search_model = search_model_document_version_page
         self._test_search_term_data = {
-            'document_version__document__uuid': self._test_document.uuid
+            'document_version__document__uuid': str(self._test_document.uuid)
         }
