@@ -87,12 +87,12 @@ class CabinetDocumentUploadTestCase(
         )
 
         self.assertEqual(events[5].action_object, self._test_cabinets[0])
-        self.assertEqual(events[5].actor, test_document)
+        self.assertEqual(events[5].actor, self._test_case_user)
         self.assertEqual(events[5].target, test_document)
         self.assertEqual(events[5].verb, event_cabinet_document_added.id)
 
         self.assertEqual(events[6].action_object, self._test_cabinets[1])
-        self.assertEqual(events[6].actor, test_document)
+        self.assertEqual(events[6].actor, self._test_case_user)
         self.assertEqual(events[6].target, test_document)
         self.assertEqual(events[6].verb, event_cabinet_document_added.id)
 
