@@ -6,12 +6,13 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.models import AccessControlList
 from mayan.apps.documents.models import Document
+from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.views.document_views import DocumentListView
 from mayan.apps.views.generics import (
     MultipleObjectFormActionView, SingleObjectCreateView,
     SingleObjectDeleteView, SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalObjectViewMixin
 
 from .forms import CabinetListForm
 from .icons import (
@@ -43,7 +44,7 @@ class CabinetCreateView(SingleObjectCreateView):
 
     def get_extra_context(self):
         return {
-            'title': _('Create cabinet'),
+            'title': _('Create cabinet')
         }
 
     def get_instance_extra_data(self):
@@ -53,7 +54,7 @@ class CabinetCreateView(SingleObjectCreateView):
 class CabinetChildAddView(ExternalObjectViewMixin, SingleObjectCreateView):
     fields = ('label',)
     external_object_class = Cabinet
-    external_object_permission = permission_cabinet_edit
+    external_object_permission = permission_cabinet_create
     external_object_pk_url_kwarg = 'cabinet_id'
     view_icon = icon_cabinet_child_add
 
@@ -85,7 +86,7 @@ class CabinetDeleteView(SingleObjectDeleteView):
     def get_extra_context(self):
         return {
             'object': self.object,
-            'title': _('Delete the cabinet: %s?') % self.object,
+            'title': _('Delete the cabinet: %s?') % self.object
         }
 
 
@@ -98,7 +99,7 @@ class CabinetDetailView(ExternalObjectViewMixin, DocumentListView):
 
     def get_document_queryset(self):
         return self.external_object.get_documents(
-            user=self.request.user
+            permission=permission_document_view, user=self.request.user
         )
 
     def get_extra_context(self, **kwargs):
@@ -118,9 +119,9 @@ class CabinetDetailView(ExternalObjectViewMixin, DocumentListView):
                 'no_results_icon': icon_cabinet,
                 'no_results_main_link': link_cabinet_child_add.resolve(
                     context=RequestContext(
-                        request=self.request, dict_={
+                        dict_={
                             'object': self.external_object
-                        }
+                        }, request=self.request
                     )
                 ),
                 'no_results_text': _(
@@ -132,7 +133,7 @@ class CabinetDetailView(ExternalObjectViewMixin, DocumentListView):
                 'object': self.external_object,
                 'title': _(
                     'Details of cabinet: %s'
-                ) % self.external_object.get_full_path(),
+                ) % self.external_object.get_full_path()
             }
         )
 
@@ -150,7 +151,7 @@ class CabinetEditView(SingleObjectEditView):
     def get_extra_context(self):
         return {
             'object': self.object,
-            'title': _('Edit cabinet: %s') % self.object,
+            'title': _('Edit cabinet: %s') % self.object
         }
 
     def get_instance_extra_data(self):
@@ -175,7 +176,7 @@ class CabinetListView(SingleObjectListView):
                 'documents. Each cabinet can contain documents as '
                 'well as other sub level cabinets.'
             ),
-            'no_results_title': _('No cabinets available'),
+            'no_results_title': _('No cabinets available')
         }
 
     def get_source_queryset(self):
@@ -196,9 +197,9 @@ class DocumentCabinetAddView(MultipleObjectFormActionView):
     success_message_plural = _(
         '%(count)d documents added to cabinets successfully.'
     )
+    title_plural = _('Add %(count)d documents to cabinets.')
     title_single = _('Add document "%(object)s" to cabinets.')
     title_singular = _('Add %(count)d document to cabinets.')
-    title_plural = _('Add %(count)d documents to cabinets.')
     view_icon = icon_document_cabinet_add
 
     def get_extra_context(self):
@@ -207,7 +208,7 @@ class DocumentCabinetAddView(MultipleObjectFormActionView):
         if self.object_list.count() == 1:
             context.update(
                 {
-                    'object': self.object_list.first(),
+                    'object': self.object_list.first()
                 }
             )
 
@@ -241,8 +242,7 @@ class DocumentCabinetAddView(MultipleObjectFormActionView):
                 user=self.request.user
             )
 
-            cabinet._event_actor = self.request.user
-            cabinet.document_add(document=instance)
+            cabinet.document_add(document=instance, user=self.request.user)
 
 
 class DocumentCabinetListView(ExternalObjectViewMixin, CabinetListView):
@@ -257,9 +257,9 @@ class DocumentCabinetListView(ExternalObjectViewMixin, CabinetListView):
             'no_results_icon': icon_cabinet,
             'no_results_main_link': link_document_cabinet_add.resolve(
                 context=RequestContext(
-                    request=self.request, dict_={
+                    dict_={
                         'object': self.external_object
-                    }
+                    }, request=self.request
                 )
             ),
             'no_results_text': _(
@@ -271,7 +271,7 @@ class DocumentCabinetListView(ExternalObjectViewMixin, CabinetListView):
             'object': self.external_object,
             'title': _(
                 'Cabinets containing document: %s'
-            ) % self.external_object,
+            ) % self.external_object
         }
 
     def get_source_queryset(self):
@@ -294,9 +294,9 @@ class DocumentCabinetRemoveView(MultipleObjectFormActionView):
     success_message_plural = _(
         '%(count)d documents removed from cabinets successfully.'
     )
+    title_plural = _('Remove %(count)d documents from cabinets.')
     title_single = _('Remove document "%(object)s" from cabinets.')
     title_singular = _('Remove %(count)d document from cabinets.')
-    title_plural = _('Remove %(count)d documents from cabinets.')
     view_icon = icon_document_cabinet_remove
 
     def get_extra_context(self):
@@ -305,7 +305,7 @@ class DocumentCabinetRemoveView(MultipleObjectFormActionView):
         if self.object_list.count() == 1:
             context.update(
                 {
-                    'object': self.object_list.first(),
+                    'object': self.object_list.first()
                 }
             )
 
@@ -333,9 +333,11 @@ class DocumentCabinetRemoveView(MultipleObjectFormActionView):
     def object_action(self, form, instance):
         for cabinet in form.cleaned_data['cabinets']:
             AccessControlList.objects.check_access(
-                obj=cabinet, permissions=(permission_cabinet_remove_document,),
-                user=self.request.user
+                obj=cabinet, permissions=(
+                    permission_cabinet_remove_document,
+                ), user=self.request.user
             )
 
-            cabinet._event_actor = self.request.user
-            cabinet.document_remove(document=instance)
+            cabinet.document_remove(
+                document=instance, user=self.request.user
+            )
