@@ -70,7 +70,8 @@ class CheckoutsApp(MayanAppConfig):
         ModelEventType.register(
             model=Document, event_types=(
                 event_document_auto_checked_in, event_document_checked_in,
-                event_document_checked_out, event_document_forcefully_checked_in
+                event_document_checked_out,
+                event_document_forcefully_checked_in
             )
         )
 
@@ -87,7 +88,9 @@ class CheckoutsApp(MayanAppConfig):
         )
 
         model_query_fields_document = ModelQueryFields(model=Document)
-        model_query_fields_document.add_select_related_field(field_name='documentcheckout')
+        model_query_fields_document.add_select_related_field(
+            field_name='documentcheckout'
+        )
 
         SourceColumn(
             attribute='get_user_display', include_label=True, order=99,
@@ -98,8 +101,8 @@ class CheckoutsApp(MayanAppConfig):
             source=CheckedOutDocument
         )
         SourceColumn(
-            attribute='get_checkout_expiration', include_label=True, order=99,
-            source=CheckedOutDocument
+            attribute='get_checkout_expiration', include_label=True,
+            order=99, source=CheckedOutDocument
         )
 
         dashboard_administrator.add_widget(
@@ -109,7 +112,9 @@ class CheckoutsApp(MayanAppConfig):
         menu_list_facet.bind_links(
             links=(link_check_out_info,), sources=(Document,)
         )
-        menu_main.bind_links(links=(link_check_out_list,), position=40)
+        menu_main.bind_links(
+            links=(link_check_out_list,), position=40
+        )
         menu_multi_item.bind_links(
             links=(
                 link_check_in_document_multiple,
