@@ -5,7 +5,6 @@ import traceback
 from django import apps
 from django.conf.urls import include, url
 from django.contrib import admin
-from django.utils.encoding import force_text
 from django.utils.module_loading import import_string
 from django.utils.translation import ugettext_lazy as _
 
@@ -19,6 +18,7 @@ from .links import (
 )
 
 from .menus import menu_about, menu_topbar, menu_user
+from .settings import setting_home_view
 from .signals import signal_pre_initial_setup, signal_pre_upgrade
 
 logger = logging.getLogger(name=__name__)
@@ -40,8 +40,8 @@ class MayanAppConfig(apps.AppConfig):
 
         if self.app_url:
             top_url = '{installation_base_url}{app_urls}/'.format(
-                installation_base_url=installation_base_url,
-                app_urls=self.app_url
+                app_urls=self.app_url,
+                installation_base_url=installation_base_url
             )
         elif self.app_url is not None:
             # When using app_url as '' to register a top of URL view.
@@ -49,8 +49,8 @@ class MayanAppConfig(apps.AppConfig):
         else:
             # If app_url is None, use the app's name for the URL base.
             top_url = '{installation_base_url}{app_name}/'.format(
-                installation_base_url=installation_base_url,
-                app_name=self.name
+                app_name=self.name,
+                installation_base_url=installation_base_url
             )
 
         try:
@@ -61,9 +61,9 @@ class MayanAppConfig(apps.AppConfig):
             non_critical_error_list = (
                 'No module named urls',
                 'No module named \'{}.urls\''.format(self.name),
-                'Module "{}.urls" does not define a "urlpatterns" attribute/class'.format(self.name),
+                'Module "{}.urls" does not define a "urlpatterns" attribute/class'.format(self.name)
             )
-            if force_text(s=exception) not in non_critical_error_list:
+            if str(exception) not in non_critical_error_list:
                 logger.exception(
                     'Import time error when running AppConfig.ready() of app '
                     '"%s".', self.name
@@ -96,9 +96,9 @@ class MayanAppConfig(apps.AppConfig):
             non_critical_error_list = (
                 'No module named urls',
                 'No module named \'{}.urls\''.format(self.name),
-                'Module "{}.urls" does not define a "passthru_urlpatterns" attribute/class'.format(self.name),
+                'Module "{}.urls" does not define a "passthru_urlpatterns" attribute/class'.format(self.name)
             )
-            if force_text(s=exception) not in non_critical_error_list:
+            if str(exception) not in non_critical_error_list:
                 logger.exception(
                     'Import time error when running AppConfig.ready() of app '
                     '"%s".', self.name
@@ -140,7 +140,9 @@ class CommonApp(MayanAppConfig):
             name='menu_main', template_name='appearance/menus/menu_main.html'
         )
         AJAXTemplate(
-            name='menu_topbar', template_name='appearance/menus/menu_topbar.html'
+            context={'home_view': setting_home_view.value},
+            name='menu_topbar',
+            template_name='appearance/menus/menu_topbar.html'
         )
 
         menu_about.bind_links(
@@ -150,7 +152,10 @@ class CommonApp(MayanAppConfig):
             )
         )
 
-        menu_topbar.bind_links(links=(menu_about, menu_user), position=10)
+        menu_topbar.bind_links(
+            links=(menu_about, menu_user),
+            position=10
+        )
 
         signal_pre_initial_setup.connect(
             dispatch_uid='common_handler_pre_initial_setup',
