@@ -22,10 +22,13 @@ def common_get_object_verbose_name(obj):
     try:
         return obj._meta.verbose_name
     except AttributeError:
-        if isinstance(obj, str):
-            return ''
-        else:
-            return type(obj)
+        try:
+            return obj.verbose_name
+        except AttributeError:
+            if isinstance(obj, str):
+                return ''
+            else:
+                return type(obj)
 
 
 @register.filter
