@@ -6,7 +6,7 @@ from django.views.generic import RedirectView
 from stronghold.views import StrongholdPublicMixin
 
 from mayan.apps.views.generics import ConfirmView, SimpleView
-from mayan.apps.views.mixins import (
+from mayan.apps.views.view_mixins import (
     ExternalContentTypeObjectViewMixin, ObjectNameViewMixin
 )
 
@@ -112,10 +112,10 @@ class SetupListView(SimpleView):
             'resolved_links': menu_setup.resolve(
                 request=self.request, sort_results=True
             ),
-            'title': _('Setup items'),
             'subtitle': _(
                 'Here you can configure all aspects of the system.'
-            )
+            ),
+            'title': _('Setup items')
         }
 
 
@@ -128,8 +128,8 @@ class ToolsListView(SimpleView):
             'resolved_links': menu_tools.resolve(
                 request=self.request, sort_results=True
             ),
-            'title': _('Tools'),
             'subtitle': _(
                 'These modules are used to do system maintenance.'
-            )
+            ),
+            'title': _('Tools')
         }
