@@ -1,9 +1,3 @@
-class DatabaseWarning(UserWarning):
-    """
-    Warning when using unsupported database backends.
-    """
-
-
 class DeprecationWarning(UserWarning):
     """
     Warning when a feature or interface has been deprecated.
