@@ -9,4 +9,9 @@ class AssetTasksTestCase(AssetTaskTestMixin, AssetTestMixin, BaseTestCase):
         self._create_test_asset()
 
     def test_asset_task_content_object_image_generate(self):
+        self._clear_events()
+
         self._execute_asset_task_content_object_image_generate()
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
