@@ -26,15 +26,15 @@ class AssetTransformationTestCase(AssetTestMixin, BaseTestCase):
         self._create_test_asset()
 
         test_transformation_0 = TransformationAssetPaste(
-            asset_name=self.test_asset.internal_name, rotation=0
+            asset_name=self._test_asset.internal_name, rotation=0
         )
 
         test_transformation_1 = TransformationAssetPaste(
-            asset_name=self.test_asset.internal_name, rotation=10
+            asset_name=self._test_asset.internal_name, rotation=10
         )
 
         test_transformation_2 = TransformationAssetPaste(
-            asset_name=self.test_asset.internal_name, rotation=0
+            asset_name=self._test_asset.internal_name, rotation=0
         )
 
         self.assertNotEqual(
@@ -140,14 +140,14 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_crop_transformation_optional_arguments(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationCrop
+            layer=self._test_layer, transformation=TransformationCrop
         )
 
         self._silence_logger(name='mayan.apps.converter.managers')
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationCrop,
             arguments={'top': '10'}
         )
@@ -156,14 +156,14 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_crop_transformation_invalid_arguments(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationCrop
+            layer=self._test_layer, transformation=TransformationCrop
         )
 
         self._silence_logger(name='mayan.apps.converter.managers')
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationCrop,
             arguments={'top': 'x', 'left': '-'}
         )
@@ -171,14 +171,14 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_crop_transformation_non_valid_range_arguments(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationCrop
+            layer=self._test_layer, transformation=TransformationCrop
         )
 
         self._silence_logger(name='mayan.apps.converter.managers')
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationCrop,
             arguments={'top': '-1000', 'bottom': '100000000'}
         )
@@ -187,19 +187,19 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_crop_transformation_overlapping_ranges_arguments(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationCrop
+            layer=self._test_layer, transformation=TransformationCrop
         )
 
         self._silence_logger(name='mayan.apps.converter.managers')
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationCrop,
             arguments={'top': '1000', 'bottom': '1000'}
         )
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationCrop,
             arguments={'left': '1000', 'right': '10000'}
         )
@@ -208,13 +208,13 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_draw_rectangle_transformation(self):
         BaseTransformation.register(
-            layer=self.test_layer,
+            layer=self._test_layer,
             transformation=TransformationDrawRectangle
         )
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page,
             transformation_class=TransformationDrawRectangle,
             arguments={}
@@ -224,12 +224,12 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_lineart_transformations(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationLineArt
+            layer=self._test_layer, transformation=TransformationLineArt
         )
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationLineArt,
             arguments={}
         )
@@ -238,26 +238,26 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_rotate_transformations(self):
         BaseTransformation.register(
-            layer=self.test_layer, transformation=TransformationRotate90
+            layer=self._test_layer, transformation=TransformationRotate90
         )
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationRotate90,
             arguments={}
         )
 
         self.assertTrue(document_page.generate_image())
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationRotate180,
             arguments={}
         )
 
         self.assertTrue(document_page.generate_image())
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page, transformation_class=TransformationRotate270,
             arguments={}
         )
@@ -266,13 +266,14 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_zoom_transformation(self):
         BaseTransformation.register(
-            layer=self.test_layer,
+            layer=self._test_layer,
             transformation=TransformationZoom
         )
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
+
+        self._test_layer.add_transformation_to(
 
-        self.test_layer.add_transformation_to(
             obj=document_page,
             transformation_class=TransformationZoom,
             arguments={'percent': 200}
@@ -282,13 +283,13 @@ class TransformationTestCase(LayerTestMixin, GenericDocumentTestCase):
 
     def test_zoom_transformation_with_negative_value(self):
         BaseTransformation.register(
-            layer=self.test_layer,
+            layer=self._test_layer,
             transformation=TransformationZoom
         )
 
-        document_page = self.test_document.pages.first()
+        document_page = self._test_document.pages.first()
 
-        self.test_layer.add_transformation_to(
+        self._test_layer.add_transformation_to(
             obj=document_page,
             transformation_class=TransformationZoom,
             arguments={'percent': -50}
