@@ -4,7 +4,7 @@ import logging
 from PIL import Image, ImageColor, ImageFilter
 
 from django import forms
-from django.utils.encoding import force_bytes, force_text
+from django.utils.encoding import force_bytes
 from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 
@@ -26,7 +26,7 @@ logger = logging.getLogger(name=__name__)
 
 class BaseTransformationType(type):
     def __str__(self):
-        return force_text(s=self.label)
+        return str(self.label)
 
 
 class BaseTransformation(metaclass=BaseTransformationType):
@@ -34,10 +34,10 @@ class BaseTransformation(metaclass=BaseTransformationType):
     Transformation can modify the appearance of the document's page preview.
     Some transformation available are: Rotate, zoom, resize and crop.
     """
-    arguments = ()
-    name = 'base_transformation'
     _layer_transformations = {}
     _registry = {}
+    arguments = ()
+    name = 'base_transformation'
 
     @staticmethod
     def combine(transformations):
@@ -45,7 +45,9 @@ class BaseTransformation(metaclass=BaseTransformationType):
 
         for transformation in transformations or ():
             try:
-                result.update(transformation.cache_hash())
+                result.update(
+                    transformation.cache_hash()
+                )
             except Exception as exception:
                 logger.error(
                     'Unable to compute hash for transformation: %s; %s',
@@ -59,7 +61,9 @@ class BaseTransformation(metaclass=BaseTransformationType):
         result = URL()
 
         for index, transformation in enumerate(transformation_instance_list):
-            result.args['transformation_{}_name'.format(index)] = transformation.name
+            result.args[
+                'transformation_{}_name'.format(index)
+            ] = transformation.name
 
             for argument in transformation.arguments:
                 value = getattr(transformation, argument)
@@ -113,49 +117,74 @@ class BaseTransformation(metaclass=BaseTransformationType):
             for layer, transformations in cls._layer_transformations.items():
                 for transformation in transformations:
                     if transformation in flat_transformation_list:
-                        layer_transformation_choices.setdefault(layer, [])
+                        layer_transformation_choices.setdefault(
+                            layer, []
+                        )
                         layer_transformation_choices[layer].append(
-                            (transformation.name, transformation.get_label())
+                            (
+                                transformation.name,
+                                transformation.get_label()
+                            )
                         )
 
                 # Sort the transformation for each layer group.
-                layer_transformation_choices[layer].sort(key=lambda x: x[1])
+                layer_transformation_choices[layer].sort(
+                    key=lambda x: x[1]
+                )
 
             result = [
-                (layer.label, transformations) for layer, transformations in layer_transformation_choices.items()
+                (
+                    layer.label, transformations
+                ) for layer, transformations in layer_transformation_choices.items()
             ]
 
             # Finally sort by transformation layer group.
-            return sorted(result, key=lambda x: x[0])
+            return sorted(
+                result, key=lambda x: x[0]
+            )
         else:
             return sorted(
-                (name, klass.get_label()) for name, klass in transformation_list
+                (
+                    name, klass.get_label()
+                ) for name, klass in transformation_list
             )
 
     @classmethod
     def register(cls, layer, transformation):
         cls._registry[transformation.name] = transformation
-        cls._layer_transformations.setdefault(layer, set())
+        cls._layer_transformations.setdefault(
+            layer, set()
+        )
         cls._layer_transformations[layer].add(transformation)
 
     def __init__(self, **kwargs):
         self.kwargs = {}
         for argument_name in self.__class__.get_arguments():
-            setattr(self, argument_name, kwargs.get(argument_name))
+            setattr(
+                self, argument_name, kwargs.get(argument_name)
+            )
             self.kwargs[argument_name] = kwargs.get(argument_name)
 
     def _update_hash(self):
-        result = hashlib.sha256(force_bytes(s=self.name))
+        result = hashlib.sha256(
+            string=force_bytes(s=self.name)
+        )
 
         # Sort arguments for guaranteed repeatability.
         for key, value in sorted(self.kwargs.items()):
-            result.update(force_bytes(s=key))
-            result.update(force_bytes(s=value))
+            result.update(
+                force_bytes(s=key)
+            )
+            result.update(
+                force_bytes(s=value)
+            )
 
         return result
 
     def cache_hash(self):
-        return force_bytes(s=self._update_hash().hexdigest())
+        return force_bytes(
+            s=self._update_hash().hexdigest()
+        )
 
     def execute_on(self, image):
         self.image = image
@@ -276,7 +305,9 @@ class TransformationCrop(BaseTransformation):
             bottom
         )
 
-        return self.image.crop(box=(left, top, right, bottom))
+        return self.image.crop(
+            box=(left, top, right, bottom)
+        )
 
 
 class TransformationDrawRectangle(
@@ -552,7 +583,9 @@ class TransformationResize(BaseTransformation):
         super().execute_on(*args, **kwargs)
 
         width = int(self.width)
-        height = int(self.height or (1.0 * width / self.aspect))
+        height = int(
+            self.height or (1.0 * width / self.aspect)
+        )
 
         factor = 1
         while self.image.size[0] / factor > 2 * width and self.image.size[1] * 2 / factor > 2 * height:
@@ -567,7 +600,9 @@ class TransformationResize(BaseTransformation):
             )
 
         # Resize the image with best quality algorithm ANTIALIAS.
-        self.image.thumbnail(size=(width, height), resample=Image.ANTIALIAS)
+        self.image.thumbnail(
+            size=(width, height), resample=Image.ANTIALIAS
+        )
 
         return self.image
 
@@ -609,8 +644,8 @@ class TransformationRotate(BaseTransformation):
             fillcolor = None
 
         return self.image.rotate(
-            angle=360 - self.degrees, resample=Image.BICUBIC, expand=True,
-            fillcolor=fillcolor
+            angle=360 - self.degrees, expand=True, fillcolor=fillcolor,
+            resample=Image.BICUBIC
         )
 
 
