@@ -42,23 +42,23 @@ urlpatterns_assets = [
 
 urlpatterns_transformations = [
     url(
-        regex=r'^object/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/$',
+        regex=r'^objects/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/$',
         name='transformation_list', view=TransformationListView.as_view()
     ),
     url(
-        regex=r'^object/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/select/$',
+        regex=r'^objects/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/select/$',
         name='transformation_select', view=TransformationSelectView.as_view()
     ),
     url(
-        regex=r'^object/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_name>[-_\w]+)/create/$',
+        regex=r'^objects/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_name>[-_\w]+)/create/$',
         name='transformation_create', view=TransformationCreateView.as_view()
     ),
     url(
-        regex=r'^layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_id>\d+)/delete/$',
+        regex=r'^objects/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_id>\d+)/delete/$',
         name='transformation_delete', view=TransformationDeleteView.as_view()
     ),
     url(
-        regex=r'^layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_id>\d+)/edit/$',
+        regex=r'^objects/(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)/(?P<object_id>\d+)/layers/(?P<layer_name>[-_\w]+)/transformations/(?P<transformation_id>\d+)/edit/$',
         name='transformation_edit', view=TransformationEditView.as_view()
     )
 ]
@@ -70,7 +70,8 @@ urlpatterns.extend(urlpatterns_transformations)
 api_urls_assets = [
     url(
         regex=r'^app_image_error/(?P<app_image_error_name>[-\w]+)/image/$',
-        name='app-image-error-image', view=APIAppImageErrorImageView.as_view()
+        name='app-image-error-image',
+        view=APIAppImageErrorImageView.as_view()
     ),
     url(
         regex=r'^assets/$', name='asset-list',
