@@ -3,6 +3,7 @@ from django.utils.translation import ugettext_lazy as _
 from mayan.apps.views.generics import SingleObjectListView, SimpleView
 
 from .classes import Dashboard
+from .icons import icon_dashboard_detail, icon_dashboard_list
 
 
 class DashboardListView(SingleObjectListView):
@@ -10,6 +11,7 @@ class DashboardListView(SingleObjectListView):
         'hide_object': True,
         'title': _('Dashboards'),
     }
+    view_icon = icon_dashboard_list
 
     def get_source_queryset(self):
         return Dashboard.get_all()
@@ -17,6 +19,7 @@ class DashboardListView(SingleObjectListView):
 
 class DashboardDetailView(SimpleView):
     template_name = 'appearance/generic_template.html'
+    view_icon = icon_dashboard_detail
 
     def get_extra_context(self):
         dashboard = Dashboard.get(name=self.kwargs['dashboard_name'])
