@@ -31,7 +31,9 @@ class HashAlgorithm:
             self.hash_object.update(data)
 
     def get_digest(self):
-        return force_text(s=self._get_digest())
+        return force_text(
+            s=self._get_digest()
+        )
 
 
 class SHA1Algorithm(HashAlgorithm):
@@ -48,7 +50,7 @@ class SHA256Algorithm(HashAlgorithm):
 
     def _get_digest(self):
         return base64.b64encode(
-            self.hash_object.digest()
+            s=self.hash_object.digest()
         )
 
 
