@@ -21,8 +21,8 @@ class CheckVersionView(SimpleView):
 
     def get_extra_context(self):
         return {
-            'title': _('Check for updates'),
-            'content': PyPIClient().check_version_verbose()
+            'content': PyPIClient().check_version_verbose(),
+            'title': _('Check for updates')
         }
 
 
@@ -36,7 +36,9 @@ class DependencyGroupEntryListView(SingleObjectListView):
             'hide_object': True,
             'object': self.get_object(),
             'subtitle': self.get_object().help_text,
-            'title': _('Entries for dependency group: %s') % self.get_object(),
+            'title': _(
+                'Entries for dependency group: %s'
+            ) % self.get_object()
         }
 
     def get_source_queryset(self):
@@ -63,7 +65,7 @@ class DependencyGroupListView(SingleObjectListView):
         return {
             'hide_link': True,
             'hide_object': True,
-            'title': _('Dependency groups'),
+            'title': _('Dependency groups')
         }
 
     def get_source_queryset(self):
@@ -84,7 +86,9 @@ class DependencyGroupEntryDetailView(SingleObjectListView):
             'hide_link': True,
             'hide_object': True,
             'navigation_object_list': ('group', 'entry'),
-            'title': _('Dependency group and entry: %(group)s, %(entry)s') % {
+            'title': _(
+                'Dependency group and entry: %(group)s, %(entry)s'
+            ) % {
                 'group': group, 'entry': entry
             }
         }
@@ -127,5 +131,5 @@ class DependencyLicensesView(SimpleView):
         return {
             'form': DependenciesLicensesForm(),
             'read_only': True,
-            'title': _('Other packages licenses'),
+            'title': _('Other packages licenses')
         }
