@@ -68,8 +68,10 @@ class DjangoGPGApp(MayanAppConfig):
             source=KeyStub
         )
         SourceColumn(
-            func=lambda context: context['object'].expires or _('No expiration'),
-            include_label=True, label=_('Expiration date'), source=KeyStub
+            func=lambda context: context['object'].expires or _(
+                'No expiration'
+            ), include_label=True, label=_('Expiration date'),
+            source=KeyStub
         )
         SourceColumn(
             attribute='length', include_label=True, label=_('Length'),
@@ -80,8 +82,12 @@ class DjangoGPGApp(MayanAppConfig):
             include_label=True, label=_('User ID'), source=KeyStub
         )
 
-        menu_object.bind_links(links=(link_key_detail,), sources=(Key,))
-        menu_object.bind_links(links=(link_key_receive,), sources=(KeyStub,))
+        menu_object.bind_links(
+            links=(link_key_detail,), sources=(Key,)
+        )
+        menu_object.bind_links(
+            links=(link_key_receive,), sources=(KeyStub,)
+        )
 
         menu_object.bind_links(
             links=(link_key_delete, link_key_download),
@@ -103,4 +109,6 @@ class DjangoGPGApp(MayanAppConfig):
                 'django_gpg:key_upload', Key, KeyStub
             )
         )
-        menu_setup.bind_links(links=(link_key_setup,))
+        menu_setup.bind_links(
+            links=(link_key_setup,)
+        )
