@@ -2,7 +2,9 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.events.classes import EventTypeNamespace
 
-namespace = EventTypeNamespace(label=_('Key management'), name='django_gpg')
+namespace = EventTypeNamespace(
+    label=_('Key management'), name='django_gpg'
+)
 
 event_key_created = namespace.add_event_type(
     label=_('Key created'),
