@@ -6,11 +6,11 @@ icon_key_download = Icon(driver_name='fontawesome', symbol='download')
 icon_key_setup = Icon(driver_name='fontawesome', symbol='key')
 icon_key_upload = Icon(driver_name='fontawesome', symbol='upload')
 icon_keyserver_search = Icon(driver_name='fontawesome', symbol='search')
-icon_private_keys = Icon(
+icon_private_key_list = Icon(
     driver_name='fontawesome-dual', primary_symbol='key',
     secondary_symbol='eye-slash'
 )
-icon_public_keys = Icon(
+icon_public_key_list = Icon(
     driver_name='fontawesome-dual', primary_symbol='key',
     secondary_symbol='eye'
 )
