@@ -44,7 +44,7 @@ class KeyAPITestCase(KeyTestMixin, KeyAPIViewTestMixin, BaseAPITestCase):
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_key_private)
+        self.assertEqual(events[0].target, self._test_key_private)
         self.assertEqual(events[0].verb, event_key_created.id)
 
     def test_key_delete_api_view_no_permission(self):
@@ -63,7 +63,7 @@ class KeyAPITestCase(KeyTestMixin, KeyAPIViewTestMixin, BaseAPITestCase):
     def test_key_delete_api_view_with_access(self):
         self._create_test_key_private()
         self.grant_access(
-            obj=self.test_key_private, permission=permission_key_delete
+            obj=self._test_key_private, permission=permission_key_delete
         )
 
         self._clear_events()
@@ -90,7 +90,7 @@ class KeyAPITestCase(KeyTestMixin, KeyAPIViewTestMixin, BaseAPITestCase):
     def test_key_detail_api_view_with_access(self):
         self._create_test_key_private()
         self.grant_access(
-            obj=self.test_key_private, permission=permission_key_view
+            obj=self._test_key_private, permission=permission_key_view
         )
 
         self._clear_events()
@@ -98,7 +98,7 @@ class KeyAPITestCase(KeyTestMixin, KeyAPIViewTestMixin, BaseAPITestCase):
         response = self._request_test_key_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['fingerprint'], self.test_key_private.fingerprint
+            response.data['fingerprint'], self._test_key_private.fingerprint
         )
 
         events = self._get_test_events()
