@@ -1,3 +1,5 @@
+from django.utils.translation import ugettext_lazy as _
+
 from mayan.apps.user_management.serializers import UserSerializer
 from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import MultiKwargHyperlinkedIdentityField
@@ -7,17 +9,16 @@ from .models import Comment
 
 class CommentSerializer(serializers.HyperlinkedModelSerializer):
     url = MultiKwargHyperlinkedIdentityField(
-        view_kwargs=(
+        label=_('URL'), view_kwargs=(
             {
                 'lookup_field': 'document_id',
-                'lookup_url_kwarg': 'document_id',
+                'lookup_url_kwarg': 'document_id'
             },
             {
                 'lookup_field': 'pk',
-                'lookup_url_kwarg': 'comment_id',
-            },
-        ),
-        view_name='rest_api:comment-detail'
+                'lookup_url_kwarg': 'comment_id'
+            }
+        ), view_name='rest_api:comment-detail'
     )
     user = UserSerializer(read_only=True)
 
