@@ -16,4 +16,9 @@ class DocumentCommentModelTestCase(
     def test_method_get_absolute_url(self):
         self._create_test_comment()
 
+        self._clear_events()
+
         self.assertTrue(self._test_document_comment.get_absolute_url())
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
