@@ -18,7 +18,9 @@ class IndexTemplateAdmin(admin.ModelAdmin):
 
     def get_document_types(self, instance):
         return ', '.join(
-            ['"{}"'.format(document_type) for document_type in instance.document_types.all()]
+            [
+                '"{}"'.format(document_type) for document_type in instance.document_types.all()
+            ]
         ) or _('None')
 
     get_document_types.short_description = _('Document types')
