@@ -1,6 +1,5 @@
 from django.shortcuts import get_object_or_404
 
-from mayan.apps.acls.models import AccessControlList
 from mayan.apps.documents.models import Document
 from mayan.apps.documents.permissions import permission_document_view
 from mayan.apps.documents.serializers.document_serializers import DocumentSerializer
@@ -13,6 +12,8 @@ from ..serializers import (
     IndexInstanceNodeSerializer, IndexInstanceSerializer
 )
 
+from .index_instance_api_view_mixins import APIIndexInstanceNodeViewMixin
+
 
 class APIDocumentIndexInstanceNodeListView(
     ExternalObjectAPIViewMixin, generics.ListAPIView
@@ -31,8 +32,8 @@ class APIDocumentIndexInstanceNodeListView(
     }
     serializer_class = IndexInstanceNodeSerializer
 
-    def get_queryset(self):
-        return self.external_object.index_instance_nodes.all()
+    def get_source_queryset(self):
+        return self.get_external_object().index_instance_nodes.all()
 
 
 class APIIndexInstanceDetailView(generics.RetrieveAPIView):
@@ -41,8 +42,8 @@ class APIIndexInstanceDetailView(generics.RetrieveAPIView):
     """
     lookup_url_kwarg = 'index_instance_id'
     mayan_object_permissions = {'GET': (permission_index_instance_view,)}
-    queryset = IndexInstance.objects.all()
     serializer_class = IndexInstanceSerializer
+    source_queryset = IndexInstance.objects.all()
 
 
 class APIIndexInstanceListView(generics.ListAPIView):
@@ -50,22 +51,8 @@ class APIIndexInstanceListView(generics.ListAPIView):
     get: Returns a list of all the indexes instances.
     """
     mayan_object_permissions = {'GET': (permission_index_instance_view,)}
-    queryset = IndexInstance.objects.all()
     serializer_class = IndexInstanceSerializer
-
-
-class APIIndexInstanceNodeViewMixin:
-    serializer_class = IndexInstanceNodeSerializer
-
-    def get_index_instance(self):
-        queryset = AccessControlList.objects.restrict_queryset(
-            permission=permission_index_instance_view,
-            queryset=IndexInstance.objects.all(), user=self.request.user
-        )
-
-        return get_object_or_404(
-            klass=queryset, pk=self.kwargs['index_instance_id']
-        )
+    source_queryset = IndexInstance.objects.all()
 
 
 class APIIndexInstanceNodeListView(
@@ -76,7 +63,7 @@ class APIIndexInstanceNodeListView(
     """
     ordering_fields = ('id', 'values')
 
-    def get_queryset(self):
+    def get_source_queryset(self):
         return self.get_index_instance().get_children()
 
 
@@ -88,7 +75,7 @@ class APIIndexInstanceNodeDetailView(
     """
     lookup_url_kwarg = 'index_instance_node_id'
 
-    def get_queryset(self):
+    def get_source_queryset(self):
         return self.get_index_instance().get_descendants()
 
 
@@ -107,7 +94,7 @@ class APIIndexInstanceNodeChildrenNodeListView(
             pk=self.kwargs['index_instance_node_id']
         )
 
-    def get_queryset(self):
+    def get_source_queryset(self):
         return self.get_node().get_children()
 
 
@@ -127,7 +114,7 @@ class APIIndexInstanceNodeDocumentListView(
             pk=self.kwargs['index_instance_node_id']
         )
 
-    def get_queryset(self):
+    def get_source_queryset(self):
         return Document.valid.filter(
             pk__in=self.get_node().documents.values('pk')
         )
