@@ -6,10 +6,11 @@ icon_document_index_instance_list = Icon(
     driver_name='fontawesome', symbol='list-ul'
 )
 icon_document_type_index_templates = icon_index
+
 icon_index_level_up = Icon(
     driver_name='fontawesomecss', css_classes='fa-level-up-alt fa-rotate-90'
 )
-
+icon_index_instance_list = Icon(driver_name='fontawesome', symbol='list-ul')
 icon_index_instance_node_with_documents = Icon(
     driver_name='fontawesome', symbol='folder'
 )
@@ -28,7 +29,12 @@ icon_index_template_create = Icon(
 )
 icon_index_template_delete = Icon(driver_name='fontawesome', symbol='times')
 icon_index_template_document_types = icon_document_type
-icon_index_template_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
+icon_index_template_edit = Icon(
+    driver_name='fontawesome', symbol='pencil-alt'
+)
+icon_index_template_event_triggers = Icon(
+    driver_name='fontawesome', symbol='bolt'
+)
 icon_index_template_list = Icon(driver_name='fontawesome', symbol='list-ul')
 
 icon_index_template_node_create = Icon(
