@@ -19,20 +19,20 @@ from .views.index_instance_views import (
     IndexInstanceListView
 )
 from .views.index_template_views import (
-    DocumentTypeIndexTemplateListView, IndexTemplateAllRebuildView,
+    DocumentTypeIndexTemplateAddRemoveView, IndexTemplateAllRebuildView,
     IndexTemplateCreateView, IndexTemplateDeleteView,
-    IndexTemplateDocumentTypesView, IndexTemplateEditView,
-    IndexTemplateListView, IndexTemplateNodeListView,
-    IndexTemplateNodeCreateView, IndexTemplateNodeDeleteView,
-    IndexTemplateNodeEditView, IndexTemplateRebuildView,
-    IndexTemplateResetView
+    IndexTemplateDocumentTypeAddRemoveView, IndexTemplateEditView,
+    IndexTemplateEventTriggerListView, IndexTemplateListView,
+    IndexTemplateNodeListView, IndexTemplateNodeCreateView,
+    IndexTemplateNodeDeleteView, IndexTemplateNodeEditView,
+    IndexTemplateRebuildView, IndexTemplateResetView
 )
 
 urlpatterns_templates = [
     url(
         regex=r'^document_types/(?P<document_type_id>\d+)/index_templates/$',
         name='document_type_index_templates',
-        view=DocumentTypeIndexTemplateListView.as_view()
+        view=DocumentTypeIndexTemplateAddRemoveView.as_view()
     ),
     url(
         regex=r'^templates/$', name='index_template_list',
@@ -49,12 +49,17 @@ urlpatterns_templates = [
     url(
         regex=r'^templates/(?P<index_template_id>\d+)/document_types/$',
         name='index_template_document_types',
-        view=IndexTemplateDocumentTypesView.as_view()
+        view=IndexTemplateDocumentTypeAddRemoveView.as_view()
     ),
     url(
         regex=r'^templates/(?P<index_template_id>\d+)/edit/$',
         name='index_template_edit', view=IndexTemplateEditView.as_view()
     ),
+    url(
+        regex=r'^templates/(?P<index_template_id>\d+)/event_triggers/$',
+        name='index_template_event_triggers',
+        view=IndexTemplateEventTriggerListView.as_view()
+    ),
     url(
         regex=r'^templates/(?P<index_template_id>\d+)/nodes/$',
         name='index_template_view',
@@ -62,15 +67,18 @@ urlpatterns_templates = [
     ),
     url(
         regex=r'^templates/(?P<index_template_id>\d+)/rebuild/$',
-        name='index_template_rebuild', view=IndexTemplateRebuildView.as_view()
+        name='index_template_rebuild',
+        view=IndexTemplateRebuildView.as_view()
     ),
     url(
         regex=r'^templates/nodes/(?P<index_template_node_id>\d+)/children/create/$',
-        name='template_node_create', view=IndexTemplateNodeCreateView.as_view()
+        name='template_node_create',
+        view=IndexTemplateNodeCreateView.as_view()
     ),
     url(
         regex=r'^templates/nodes/(?P<index_template_node_id>\d+)/delete/$',
-        name='template_node_delete', view=IndexTemplateNodeDeleteView.as_view()
+        name='template_node_delete',
+        view=IndexTemplateNodeDeleteView.as_view()
     ),
     url(
         regex=r'^templates/nodes/(?P<index_template_node_id>\d+)/edit/$',
@@ -80,7 +88,8 @@ urlpatterns_templates = [
 
 urlpatterns_instances = [
     url(
-        regex=r'^instances/$', name='index_list', view=IndexInstanceListView.as_view()
+        regex=r'^instances/$', name='index_list',
+        view=IndexInstanceListView.as_view()
     ),
     url(
         regex=r'^instances/nodes/(?P<index_instance_node_id>\d+)/$',
@@ -88,7 +97,8 @@ urlpatterns_instances = [
     ),
     url(
         regex=r'^documents/(?P<document_id>\d+)/instances/$',
-        name='document_index_list', view=DocumentIndexInstanceNodeListView.as_view()
+        name='document_index_list',
+        view=DocumentIndexInstanceNodeListView.as_view()
     )
 ]
 
@@ -113,7 +123,7 @@ api_urls_document_indexes = [
         regex=r'^documents/(?P<document_id>[0-9]+)/indexes/$',
         name='document-index-list',
         view=APIDocumentIndexInstanceNodeListView.as_view()
-    ),
+    )
 ]
 
 api_urls_index_instances = [
@@ -123,11 +133,13 @@ api_urls_index_instances = [
     ),
     url(
         regex=r'^index_instances/(?P<index_instance_id>[0-9]+)/$',
-        name='indexinstance-detail', view=APIIndexInstanceDetailView.as_view()
+        name='indexinstance-detail',
+        view=APIIndexInstanceDetailView.as_view()
     ),
     url(
         regex=r'^index_instances/(?P<index_instance_id>[0-9]+)/nodes/$',
-        name='indexinstancenode-list', view=APIIndexInstanceNodeListView.as_view()
+        name='indexinstancenode-list',
+        view=APIIndexInstanceNodeListView.as_view()
     ),
     url(
         regex=r'^index_instances/(?P<index_instance_id>[0-9]+)/nodes/(?P<index_instance_node_id>[0-9]+)/$',
@@ -143,7 +155,7 @@ api_urls_index_instances = [
         regex=r'^index_instances/(?P<index_instance_id>[0-9]+)/nodes/(?P<index_instance_node_id>[0-9]+)/documents/$',
         name='indexinstancenode-document-list',
         view=APIIndexInstanceNodeDocumentListView.as_view()
-    ),
+    )
 ]
 
 api_urls_index_templates = [
@@ -188,8 +200,9 @@ api_urls_index_templates = [
     ),
     url(
         regex=r'^index_templates/(?P<index_template_id>[0-9]+)/nodes/(?P<index_template_node_id>[0-9]+)/$',
-        name='indextemplatenode-detail', view=APIIndexTemplateNodeDetailView.as_view()
-    ),
+        name='indextemplatenode-detail',
+        view=APIIndexTemplateNodeDetailView.as_view()
+    )
 ]
 
 api_urls = []
