@@ -1,9 +1,12 @@
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
-from mayan.apps.documents.tests.literals import TEST_HYBRID_DOCUMENT
+from mayan.apps.documents.tests.literals import (
+    TEST_FILE_HYBRID_PDF_CONTENT, TEST_FILE_HYBRID_PDF_FILENAME
+)
 
 from ..events import (
     event_parsing_document_file_content_deleted,
-    event_parsing_document_file_finished, event_parsing_document_file_submitted
+    event_parsing_document_file_finished,
+    event_parsing_document_file_submitted
 )
 from ..models import DocumentFilePageContent
 from ..permissions import (
@@ -11,7 +14,6 @@ from ..permissions import (
     permission_document_type_parsing_setup
 )
 
-from .literals import TEST_DOCUMENT_CONTENT
 from .mixins import (
     DocumentFileContentTestMixin, DocumentFileContentToolsViewTestMixin,
     DocumentFileContentViewTestMixin, DocumentTypeContentViewTestMixin
@@ -35,7 +37,7 @@ class DocumentFileContentViewTestCase(
 
     def test_document_file_content_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
@@ -43,7 +45,8 @@ class DocumentFileContentViewTestCase(
 
         response = self._request_test_document_file_content_view()
         self.assertContains(
-            response=response, text=TEST_DOCUMENT_CONTENT, status_code=200
+            response=response, text=TEST_FILE_HYBRID_PDF_CONTENT,
+            status_code=200
         )
 
         events = self._get_test_events()
@@ -51,11 +54,11 @@ class DocumentFileContentViewTestCase(
 
     def test_trashed_document_file_content_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -65,124 +68,128 @@ class DocumentFileContentViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_content_delete_single_view_no_permission(self):
+    def test_document_file_content_single_delete_view_no_permission(self):
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_single_view()
+        response = self._request_test_document_file_content_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_content_delete_single_view_with_access(self):
+    def test_document_file_content_single_delete_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_single_view()
+        response = self._request_test_document_file_content_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertFalse(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(
             events[0].verb, event_parsing_document_file_content_deleted.id
         )
 
-    def test_trashed_document_file_content_delete_single_view_with_access(self):
+    def test_trashed_document_file_content_single_delete_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_single_view()
+        response = self._request_test_document_file_content_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_content_delete_multiple_view_no_permission(self):
+    def test_document_file_content_multiple_delete_view_no_permission(self):
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_multiple_view()
+        response = self._request_test_document_file_content_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_content_delete_multiple_view_with_access(self):
+    def test_document_file_content_multiple_delete_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_multiple_view()
+        response = self._request_test_document_file_content_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertFalse(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(
             events[0].verb, event_parsing_document_file_content_deleted.id
         )
 
-    def test_trashed_document_file_content_delete_multiple_view_with_access(self):
+    def test_trashed_document_file_content_multiple_delete_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_file_content_delete_multiple_view()
+        response = self._request_test_document_file_content_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentFilePageContent.objects.filter(
-                document_file_page=self.test_document_file.pages.first()
+                document_file_page=self._test_document_file.pages.first()
             ).exists()
         )
 
@@ -207,7 +214,7 @@ class DocumentFilePageContentViewTestCase(
 
     def test_document_file_page_content_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
@@ -215,7 +222,8 @@ class DocumentFilePageContentViewTestCase(
 
         response = self._request_test_document_file_page_content_view()
         self.assertContains(
-            response=response, text=TEST_DOCUMENT_CONTENT, status_code=200
+            response=response, text=TEST_FILE_HYBRID_PDF_CONTENT,
+            status_code=200
         )
 
         events = self._get_test_events()
@@ -223,11 +231,11 @@ class DocumentFilePageContentViewTestCase(
 
     def test_trashed_document_file_page_content_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -237,44 +245,6 @@ class DocumentFilePageContentViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_parsing_error_list_view_no_permission(self):
-        self._clear_events()
-
-        response = self._request_test_document_file_parsing_error_list_view()
-
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_file_parsing_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
-        )
-
-        self._clear_events()
-
-        response = self._request_test_document_file_parsing_error_list_view()
-        self.assertEqual(response.status_code, 200)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_trashed_document_file_parsing_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
-        )
-
-        self.test_document.delete()
-
-        self._clear_events()
-
-        response = self._request_test_document_file_parsing_error_list_view()
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
 
 class DocumentFileContentParsingViewTestCase(
     DocumentFileContentViewTestMixin, GenericDocumentViewTestCase
@@ -294,7 +264,7 @@ class DocumentFileContentParsingViewTestCase(
         self.expected_content_types = ('application/octet-stream',)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
@@ -304,10 +274,8 @@ class DocumentFileContentParsingViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assert_download_response(
-            response=response, content=(
-                ''.join(
-                    self.test_document_file.content()
-                )
+            response=response, content=''.join(
+                self._test_document_file.content()
             )
         )
 
@@ -316,11 +284,11 @@ class DocumentFileContentParsingViewTestCase(
 
     def test_trashed_document_file_parsing_download_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -341,7 +309,8 @@ class DocumentFileContentParsingViewTestCase(
 
     def test_document_file_parsing_submit_single_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
         self._clear_events()
@@ -352,26 +321,27 @@ class DocumentFileContentParsingViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(
             events[0].verb, event_parsing_document_file_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_file)
+        self.assertEqual(events[1].target, self._test_document_file)
         self.assertEqual(
             events[1].verb, event_parsing_document_file_finished.id
         )
 
     def test_trashed_document_file_parsing_single_submit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -392,7 +362,8 @@ class DocumentFileContentParsingViewTestCase(
 
     def test_document_file_parsing_submit_multiple_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
         self._clear_events()
@@ -403,26 +374,27 @@ class DocumentFileContentParsingViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(
             events[0].verb, event_parsing_document_file_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_file)
+        self.assertEqual(events[1].target, self._test_document_file)
         self.assertEqual(
             events[1].verb, event_parsing_document_file_finished.id
         )
 
     def test_trashed_document_file_parsing_multiple_submit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_parse
+            obj=self._test_document,
+            permission=permission_document_file_parse
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -437,35 +409,14 @@ class DocumentTypeParsingViewTestCase(
     DocumentFileContentToolsViewTestMixin, GenericDocumentViewTestCase
 ):
     _skip_file_descriptor_test = True
+    _test_document_filename = TEST_FILE_HYBRID_PDF_FILENAME
     auto_upload_test_document = False
-    # Ensure we use a PDF file
-    test_document_filename = TEST_HYBRID_DOCUMENT
 
     def _get_document_file_content(self):
         return ''.join(
-            self.test_document_file.content()
+            self._test_document_file.content()
         )
 
-    def test_document_parsing_error_list_view_no_permission(self):
-        self._clear_events()
-
-        response = self._request_document_parsing_error_list_view()
-        self.assertEqual(response.status_code, 403)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_parsing_error_list_view_with_permission(self):
-        self.grant_permission(permission=permission_document_file_parse)
-
-        self._clear_events()
-
-        response = self._request_document_parsing_error_list_view()
-        self.assertEqual(response.status_code, 200)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
     def test_document_type_parsing_view_no_permission(self):
         self._upload_test_document()
 
@@ -475,11 +426,11 @@ class DocumentTypeParsingViewTestCase(
         self.assertEqual(response.status_code, 200)
         self.assertNotContains(
             response=response, status_code=200,
-            text=self.test_document_type.label
+            text=self._test_document_type.label
         )
 
         self.assertNotEqual(
-            self._get_document_file_content(), TEST_DOCUMENT_CONTENT
+            self._get_document_file_content(), TEST_FILE_HYBRID_PDF_CONTENT
         )
 
         events = self._get_test_events()
@@ -496,22 +447,22 @@ class DocumentTypeParsingViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self._get_document_file_content(), TEST_DOCUMENT_CONTENT
+            self._get_document_file_content(), TEST_FILE_HYBRID_PDF_CONTENT
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(
             events[0].verb, event_parsing_document_file_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_file)
+        self.assertEqual(events[1].target, self._test_document_file)
         self.assertEqual(
             events[1].verb, event_parsing_document_file_finished.id
         )
@@ -533,7 +484,7 @@ class DocumentTypeContentViewTestCase(
 
     def test_document_type_parsing_settings_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_parsing_setup
         )
 
