@@ -1,12 +1,11 @@
 from .tasks import (
-    task_unverify_key_signatures,
-    task_verify_missing_embedded_signature,
+    task_unverify_key_signatures, task_verify_missing_embedded_signature,
     task_verify_key_signatures
 )
 
 
 def handler_verify_missing_embedded_signature(sender, **kwargs):
-    task_verify_missing_embedded_signature.delay()
+    task_verify_missing_embedded_signature.apply_async()
 
 
 def handler_unverify_key_signatures(sender, **kwargs):
