@@ -14,17 +14,16 @@ from .models import DetachedSignature, EmbeddedSignature
 
 class BaseSignatureSerializer(serializers.HyperlinkedModelSerializer):
     document_file_url = MultiKwargHyperlinkedIdentityField(
-        view_kwargs=(
+        label=_('Document file URL'), view_kwargs=(
             {
                 'lookup_field': 'document_file_id',
-                'lookup_url_kwarg': 'document_file_id',
+                'lookup_url_kwarg': 'document_file_id'
             },
             {
                 'lookup_field': 'document_file.document_id',
-                'lookup_url_kwarg': 'document_id',
+                'lookup_url_kwarg': 'document_id'
             }
-        ),
-        view_name='rest_api:documentfile-detail'
+        ), view_name='rest_api:documentfile-detail'
     )
     key_url = serializers.SerializerMethodField()
 
@@ -59,15 +58,14 @@ class BaseSignSerializer(serializers.HyperlinkedModelSerializer):
         help_text=_(
             'Primary key of the secret key used to sign the document '
             'file.'
-        ), source_queryset=Key.objects.private_keys(),
+        ), label=_('Key ID'), source_queryset=Key.objects.private_keys(),
         source_permission=permission_key_sign
     )
     passphrase = serializers.CharField(
         help_text=_(
             'The passphrase to unlock the key and allow it to be used to '
             'sign the document file.'
-        ),
-        required=False, write_only=True
+        ), label=_('Passphrase'), required=False, write_only=True
     )
 
     class Meta:
@@ -99,7 +97,9 @@ class DetachedSignatureSerializer(BaseSignatureSerializer):
 
 class DetachedSignatureUploadSerializer(DetachedSignatureSerializer):
     class Meta(DetachedSignatureSerializer.Meta):
-        fields = DetachedSignatureSerializer.Meta.fields + ('signature_file',)
+        fields = DetachedSignatureSerializer.Meta.fields + (
+            'signature_file',
+        )
         model = DetachedSignature
 
 
@@ -107,21 +107,20 @@ class EmbeddedSignatureSerializer(
     BaseSignatureSerializer, serializers.HyperlinkedModelSerializer
 ):
     url = MultiKwargHyperlinkedIdentityField(
-        view_kwargs=(
+        label=_('URL'), view_kwargs=(
             {
                 'lookup_field': 'document_file.document.pk',
-                'lookup_url_kwarg': 'document_id',
+                'lookup_url_kwarg': 'document_id'
             },
             {
                 'lookup_field': 'document_file_id',
-                'lookup_url_kwarg': 'document_file_id',
+                'lookup_url_kwarg': 'document_file_id'
             },
             {
                 'lookup_field': 'pk',
-                'lookup_url_kwarg': 'embedded_signature_id',
+                'lookup_url_kwarg': 'embedded_signature_id'
             },
-        ),
-        view_name='rest_api:embeddedsignature-detail'
+        ), view_name='rest_api:embeddedsignature-detail'
     )
 
     class Meta(BaseSignatureSerializer.Meta):
