@@ -71,6 +71,10 @@ from .links import (
     link_workflow_template_transition_field_edit,
     link_workflow_template_transition_field_list
 )
+from .methods import (
+    method_document_type_workflow_templates_add,
+    method_document_type_workflow_templates_remove
+)
 from .permissions import (
     permission_workflow_template_delete, permission_workflow_template_edit,
     permission_workflow_tools, permission_workflow_instance_transition,
@@ -117,6 +121,15 @@ class DocumentStatesApp(MayanAppConfig):
             name='workflow', value=DocumentStateHelper.constructor
         )
 
+        DocumentType.add_to_class(
+            name='workflow_templates_add',
+            value=method_document_type_workflow_templates_add
+        )
+        DocumentType.add_to_class(
+            name='workflow_templates_remove',
+            value=method_document_type_workflow_templates_remove
+        )
+
         DynamicSerializerField.add_serializer(
             klass=Workflow,
             serializer_class='mayan.apps.document_states.serializers.workflow_template_serializers.WorkflowTemplateSerializer'
@@ -164,7 +177,7 @@ class DocumentStatesApp(MayanAppConfig):
                 'destination_state': {
                     'workflow': '{workflow.pk}',
                     'label': '{instance.destination_state.label}'
-                },
+                }
             }
         )
         ModelCopy(
@@ -186,7 +199,7 @@ class DocumentStatesApp(MayanAppConfig):
             field_names=(
                 'auto_launch', 'internal_name', 'label', 'document_types',
                 'states', 'transitions'
-            ),
+            )
         )
 
         ModelEventType.register(
@@ -302,7 +315,9 @@ class DocumentStatesApp(MayanAppConfig):
             attribute='internal_name', include_label=True, is_sortable=True,
             source=Workflow
         )
-        column_workflow_internal_name.add_exclude(source=WorkflowRuntimeProxy)
+        column_workflow_internal_name.add_exclude(
+            source=WorkflowRuntimeProxy
+        )
         column_workflow_get_initial_state = SourceColumn(
             attribute='get_initial_state', empty_value=_('None'),
             include_label=True, source=Workflow
@@ -331,14 +346,15 @@ class DocumentStatesApp(MayanAppConfig):
         )
         SourceColumn(
             func=lambda context: getattr(
-                context['object'].get_current_state(), 'completion', _('None')
+                context['object'].get_current_state(),
+                'completion', _('None')
             ), include_label=True, label=_('Completion'),
             source=WorkflowInstance
         )
 
         SourceColumn(
-            attribute='datetime', is_identifier=True, label=_('Date and time'),
-            source=WorkflowInstanceLogEntry
+            attribute='datetime', is_identifier=True,
+            label=_('Date and time'), source=WorkflowInstanceLogEntry
         )
         SourceColumn(
             attribute='user', include_label=True, label=_('User'),
@@ -438,8 +454,8 @@ class DocumentStatesApp(MayanAppConfig):
             source=WorkflowTransition
         )
         SourceColumn(
-            attribute='destination_state', include_label=True, is_sortable=True,
-            source=WorkflowTransition
+            attribute='destination_state', include_label=True,
+            is_sortable=True, source=WorkflowTransition
         )
         SourceColumn(
             attribute='has_condition', include_label=True,
@@ -506,7 +522,7 @@ class DocumentStatesApp(MayanAppConfig):
             sources=(
                 'document_states:document_multiple_workflow_templates_launch',
                 'document_states:document_single_workflow_templates_launch',
-                'document_states:workflow_instance_list', WorkflowInstance,
+                'document_states:workflow_instance_list', WorkflowInstance
             )
         )
 
@@ -651,7 +667,7 @@ class DocumentStatesApp(MayanAppConfig):
             ), sources=(
                 WorkflowTransition,
                 'document_states:workflow_template_transition_create',
-                'document_states:workflow_template_transition_list',
+                'document_states:workflow_template_transition_list'
             )
         )
         menu_secondary.bind_links(
@@ -660,17 +676,21 @@ class DocumentStatesApp(MayanAppConfig):
             ), sources=(
                 WorkflowState,
                 'document_states:workflow_template_state_create',
-                'document_states:workflow_template_state_list',
+                'document_states:workflow_template_state_list'
             )
         )
 
-        menu_setup.bind_links(links=(link_workflow_template_list,))
+        menu_setup.bind_links(
+            links=(link_workflow_template_list,)
+        )
 
-        menu_tools.bind_links(links=(link_tool_launch_workflows,))
+        menu_tools.bind_links(
+            links=(link_tool_launch_workflows,)
+        )
 
         post_migrate.connect(
             dispatch_uid='workflows_handler_create_workflow_image_cache',
-            receiver=handler_create_workflow_image_cache,
+            receiver=handler_create_workflow_image_cache
         )
         post_save.connect(
             dispatch_uid='workflows_handler_launch_workflow_on_create',
