@@ -70,19 +70,10 @@ DEFAULT_LANGUAGE_CODES = (
     'ibo', 'aze', 'awa', 'gan', 'ceb', 'nld', 'kur', 'hbs', 'mlg', 'skr',
     'ctg', 'zha', 'tuk', 'asm', 'mad', 'som', 'mwr', 'mag', 'bgc', 'hun',
     'hne', 'dcc', 'aka', 'kaz', 'syl', 'zul', 'ces', 'kin', 'hat', 'que',
-    'swe', 'hmn', 'sna', 'mos', 'xho', 'bel'
+    'swe', 'hmn', 'sna', 'mos', 'xho', 'bel', 'heb'
 )
 DEFAULT_STUB_EXPIRATION_INTERVAL = 60 * 60 * 24  # 24 hours
 
-DOCUMENT_VERSION_EXPORT_MESSAGE_BODY = _(
-    'Document version "%(document_version)s" has been '
-    'exported and is available for download using the '
-    'link: %(download_url)s or from '
-    'the downloads area (%(download_list_url)s).'
-)
-DOCUMENT_VERSION_EXPORT_MESSAGE_SUBJECT = _('Document version exported.')
-DOCUMENT_VERSION_EXPORT_MIMETYPE = 'application/pdf'
-
 IMAGE_ERROR_NO_ACTIVE_VERSION = 'document_no_active_version'
 IMAGE_ERROR_NO_VERSION_PAGES = 'document_no_version_pages'
 IMAGE_ERROR_FILE_PAGE_TRANSFORMATION_ERROR = 'document_file_page_transformation_error'
