@@ -524,7 +524,7 @@ class Migration(migrations.Migration):
                 ),
                 (
                     'filename', models.CharField(
-                        max_length=128, verbose_name='Filename', db_index=True
+                        db_index=True, max_length=128, verbose_name='Filename'
                     )
                 ),
                 (
@@ -638,7 +638,7 @@ class Migration(migrations.Migration):
         ),
         migrations.AlterUniqueTogether(
             name='documenttypefilename',
-            unique_together=set([('document_type', 'filename')]),
+            unique_together={('document_type', 'filename')},
         ),
         migrations.AddField(
             model_name='documentpage',
