@@ -2,12 +2,11 @@ import uuid
 
 import django.core.files.storage
 from django.db import migrations, models
-from django.utils.encoding import force_text
 
 
 class Migration(migrations.Migration):
     dependencies = [
-        ('documents', '0042_auto_20180403_0702'),
+        ('documents', '0042_auto_20180403_0702')
     ]
 
     operations = [
@@ -17,7 +16,7 @@ class Migration(migrations.Migration):
             field=models.CharField(
                 blank=True, editable=False, max_length=64, null=True,
                 verbose_name='Encoding'
-            ),
+            )
         ),
         migrations.AlterField(
             model_name='documentversion',
@@ -25,8 +24,10 @@ class Migration(migrations.Migration):
             field=models.FileField(
                 storage=django.core.files.storage.FileSystemStorage(
                     location=b'/home/rosarior/development/mayan-edms/mayan/media/document_storage'
-                ), upload_to=force_text(s=uuid.uuid4()), verbose_name='File'
-            ),
+                ), upload_to=str(
+                    uuid.uuid4()
+                ), verbose_name='File'
+            )
         ),
         migrations.AlterField(
             model_name='documentversion',
@@ -34,6 +35,6 @@ class Migration(migrations.Migration):
             field=models.CharField(
                 blank=True, editable=False, max_length=255, null=True,
                 verbose_name='MIME type'
-            ),
-        ),
+            )
+        )
     ]
