@@ -1,5 +1,7 @@
 from django.db import migrations
 
+from mayan.apps.databases.literals import DJANGO_POSITIVE_INTEGER_FIELD_MAX_VALUE
+
 
 def code_document_file_size_copy(apps, schema_editor):
     DocumentFile = apps.get_model(
@@ -11,8 +13,14 @@ def code_document_file_size_copy(apps, schema_editor):
         document_file.file.close()
 
         if document_file.file.storage.exists(name=name):
-            document_file.size = document_file.file.storage.size(name=name)
-            document_file.save(update_fields=('size',))
+            document_file_size = document_file.file.storage.size(name=name)
+            if document_file_size > DJANGO_POSITIVE_INTEGER_FIELD_MAX_VALUE:
+                document_file_size = DJANGO_POSITIVE_INTEGER_FIELD_MAX_VALUE
+
+            document_file.size = document_file_size
+            document_file.save(
+                update_fields=('size',)
+            )
 
 
 class Migration(migrations.Migration):
