@@ -1,7 +1,6 @@
-from django.db import connection
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.dynamic_search.classes import SearchModel
+from mayan.apps.dynamic_search.search_models import SearchModel
 from mayan.apps.views.literals import LIST_MODE_CHOICE_ITEM
 
 from .permissions import (
@@ -9,14 +8,6 @@ from .permissions import (
     permission_document_version_view, permission_document_view
 )
 
-
-def transformation_format_uuid(term_string):
-    if connection.vendor in ('mysql', 'sqlite'):
-        return term_string.replace('-', '')
-    else:
-        return term_string
-
-
 # Document
 
 search_model_document = SearchModel(
@@ -41,9 +32,7 @@ search_model_document.add_model_field(
 search_model_document.add_model_field(field='datetime_created')
 search_model_document.add_model_field(field='label')
 search_model_document.add_model_field(field='description')
-search_model_document.add_model_field(
-    field='uuid', transformation_function=transformation_format_uuid
-)
+search_model_document.add_model_field(field='uuid')
 search_model_document.add_model_field(
     field='files__checksum', label=('Document file checksum')
 )
@@ -78,8 +67,7 @@ search_model_document_file.add_model_field(
     field='document__description', label=_('Document description')
 )
 search_model_document_file.add_model_field(
-    field='document__uuid', label=_('Document UUID'),
-    transformation_function=transformation_format_uuid
+    field='document__uuid', label=_('Document UUID')
 )
 search_model_document_file.add_model_field(field='checksum')
 search_model_document_file.add_model_field(field='comment')
@@ -114,8 +102,7 @@ search_model_document_file_page.add_model_field(
     field='document_file__checksum', label=_('Document file checksum')
 )
 search_model_document_file_page.add_model_field(
-    field='document_file__document__uuid', label=_('Document UUID'),
-    transformation_function=transformation_format_uuid
+    field='document_file__document__uuid', label=_('Document UUID')
 )
 search_model_document_file_page.add_model_field(
     field='document_file__mimetype', label=_('Document file MIME type')
@@ -155,8 +142,7 @@ search_model_document_version.add_model_field(
     field='document__description', label=_('Document description')
 )
 search_model_document_version.add_model_field(
-    field='document__uuid', label=_('Document UUID'),
-    transformation_function=transformation_format_uuid
+    field='document__uuid', label=_('Document UUID')
 )
 
 # Document version page
@@ -187,6 +173,5 @@ search_model_document_version_page.add_model_field(
     label=_('Document description')
 )
 search_model_document_version_page.add_model_field(
-    field='document_version__document__uuid', label=_('Document UUID'),
-    transformation_function=transformation_format_uuid
+    field='document_version__document__uuid', label=_('Document UUID')
 )
