@@ -1,3 +1,5 @@
+from django.utils.translation import ugettext_lazy as _
+
 from mayan.apps.rest_api import serializers
 from mayan.apps.user_management.serializers import UserSerializer
 
@@ -7,8 +9,12 @@ from .document_serializers import DocumentSerializer
 
 
 class RecentlyAccessedDocumentSerializer(serializers.ModelSerializer):
-    document = DocumentSerializer(read_only=True)
-    user = UserSerializer(read_only=True)
+    document = DocumentSerializer(
+        label=_('Document'), read_only=True
+    )
+    user = UserSerializer(
+        label=_('User'), read_only=True
+    )
 
     class Meta:
         fields = ('document', 'id', 'datetime_accessed', 'user')
