@@ -10,8 +10,9 @@ from ...models import Document, DocumentType
 
 from ..literals import (
     DEFAULT_DOCUMENT_STUB_LABEL, TEST_DOCUMENT_DESCRIPTION,
-    TEST_DOCUMENT_DESCRIPTION_EDITED, TEST_DOCUMENT_TYPE_LABEL,
-    TEST_FILE_SMALL_FILENAME, TEST_FILE_SMALL_PATH
+    TEST_DOCUMENT_DESCRIPTION_EDITED, TEST_DOCUMENT_LABEL,
+    TEST_DOCUMENT_TYPE_LABEL, TEST_FILE_SMALL_FILENAME,
+    TEST_FILE_SMALL_PATH
 )
 
 
@@ -87,15 +88,16 @@ class DocumentAPIViewTestMixin:
 
 
 class DocumentTestMixin:
-    auto_create_test_document_stub = False
-    auto_create_test_document_type = True
-    auto_upload_test_document = True
+    _test_document_count = 1
     _test_document_file_filename = TEST_FILE_SMALL_FILENAME
     _test_document_file_path = None
     _test_document_filename = TEST_FILE_SMALL_FILENAME
     _test_document_language = None
     _test_document_path = None
+    auto_create_test_document_stub = False
+    auto_create_test_document_type = True
     auto_delete_test_document_type = True
+    auto_upload_test_document = True
 
     def setUp(self):
         super().setUp()
@@ -104,15 +106,25 @@ class DocumentTestMixin:
         self._test_documents = []
         self._test_document_files = []
         self._test_document_file_pages = []
+        self._test_document_id_list = []
+        self._test_document_id_list_string = []
         self._test_document_types = []
+        self._test_document_versions = []
+        self._test_document_version_pages = []
 
         if self.auto_create_test_document_type:
             self._create_test_document_type()
 
-            if self.auto_upload_test_document:
-                self._upload_test_document()
-            elif self.auto_create_test_document_stub:
-                self._create_test_document_stub()
+            if self._test_document_count > 1:
+                if self.auto_upload_test_document:
+                    self._upload_test_documents()
+                elif self.auto_create_test_document_stub:
+                    self._create_test_document_stubs()
+            else:
+                if self.auto_upload_test_document:
+                    self._upload_test_document()
+                elif self.auto_create_test_document_stub:
+                    self._create_test_document_stub()
 
     def tearDown(self):
         if self.auto_delete_test_document_type:
@@ -121,14 +133,25 @@ class DocumentTestMixin:
         super().tearDown()
 
     def _create_test_document_stub(self, document_type=None, label=None):
-        self._test_document_stub = Document.objects.create(
-            document_type=document_type or self._test_document_type,
-            label=label or '{}_{}'.format(
+        if label is None:
+            label = '{}_{}'.format(
                 DEFAULT_DOCUMENT_STUB_LABEL, len(self._test_documents)
             )
+
+        self._test_document_stub = Document.objects.create(
+            document_type=document_type or self._test_document_type,
+            label=label
         )
         self._test_document = self._test_document_stub
         self._test_documents.append(self._test_document)
+        self._test_document_id_list.append(self._test_document.pk)
+        self._test_document_id_list_string.append(
+            str(self._test_document.pk)
+        )
+
+    def _create_test_document_stubs(self, count=None):
+        for index in range(count or self._test_document_count):
+            self._create_test_document_stub()
 
     def _create_test_document_type(self, label=None):
         label = label or '{}_{}'.format(
@@ -155,7 +178,7 @@ class DocumentTestMixin:
     def _upload_test_document(
         self, description=None, document_file_attributes=None,
         document_type=None, document_version_attributes=None, label=None,
-        _user=None
+        user=None
     ):
         self._calculate_test_document_path()
 
@@ -172,17 +195,27 @@ class DocumentTestMixin:
             document, document_file = document_type.new_document(
                 description=test_document_description,
                 file_object=file_object, label=label,
-                language=self._test_document_language, _user=_user
+                language=self._test_document_language, user=user
             )
 
         self._test_document = document
-        self._test_documents.append(document)
+        self._test_documents.append(self._test_document)
+        self._test_document_id_list.append(self._test_document.pk)
+        self._test_document_id_list_string.append(
+            str(self._test_document.pk)
+        )
 
         self._test_document_file = document_file
-        self._test_document_files.append(document_file)
-        self._test_document_file_pages = list(document_file.file_pages.all())
-        self._test_document_file_page = document_file.file_pages.first()
+        self._test_document_files.append(self._test_document_file)
+        self._test_document_file_pages = list(
+            self._test_document_file.file_pages.all()
+        )
+        self._test_document_file_page = self._test_document_file.file_pages.first()
         self._test_document_version = self._test_document.version_active
+        self._test_document_versions.append(self._test_document_version)
+        self._test_document_version_pages = list(
+            self._test_document_version.version_pages.all()
+        )
         self._test_document_version_page = self._test_document_version.version_pages.first()
 
         if document_file_attributes:
@@ -197,10 +230,19 @@ class DocumentTestMixin:
 
             self._test_document_version.save()
 
+    def _create_test_documents(self, count=None):
+        for index in range(count or self._test_document_count):
+            self._upload_test_document(
+                label='{}_{}'.format(
+                    TEST_DOCUMENT_LABEL,
+                    len(self._test_documents)
+                )
+            )
+
 
 class DocumentViewTestMixin:
-    def _request_test_document_list_view(self):
-        return self.get(viewname='documents:document_list')
+    def _request_test_document_list_view(self, data=None):
+        return self.get(viewname='documents:document_list', data=data)
 
     def _request_test_document_preview_view(self):
         return self.get(
