@@ -1,4 +1,4 @@
-from mayan.apps.dynamic_search.tests.mixins import SearchTestMixin
+from mayan.apps.dynamic_search.tests.mixins.base import SearchTestMixin
 
 from ..permissions import permission_document_file_view
 from ..search import search_model_document_file_page, search_model_document_file
@@ -17,7 +17,7 @@ class DocumentFileSearchTestCase(
         self.assertTrue(terms is not None)
         self.assertTrue(terms != '')
 
-        return self.search_backend.search(
+        return self._test_search_backend.search(
             search_model=search_model_document_file, query=query,
             user=self._test_case_user
         )
@@ -327,7 +327,7 @@ class DocumentFileSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document__uuid': self._test_document.uuid
+                'document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file not in queryset)
@@ -344,7 +344,7 @@ class DocumentFileSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document__uuid': self._test_document.uuid
+                'document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file in queryset)
@@ -363,7 +363,7 @@ class DocumentFileSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document__uuid': self._test_document.uuid
+                'document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file not in queryset)
@@ -431,7 +431,7 @@ class DocumentFilePageSearchTestCase(
         self.assertTrue(terms is not None)
         self.assertTrue(terms != '')
 
-        return self.search_backend.search(
+        return self._test_search_backend.search(
             search_model=search_model_document_file_page, query=query,
             user=self._test_case_user
         )
@@ -641,7 +641,7 @@ class DocumentFilePageSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document_file__document__uuid': self._test_document.uuid
+                'document_file__document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file_page not in queryset)
@@ -658,7 +658,7 @@ class DocumentFilePageSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document_file__document__uuid': self._test_document.uuid
+                'document_file__document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file_page in queryset)
@@ -677,7 +677,7 @@ class DocumentFilePageSearchTestCase(
 
         queryset = self._do_test_search(
             query={
-                'document_file__document__uuid': self._test_document.uuid
+                'document_file__document__uuid': str(self._test_document.uuid)
             }
         )
         self.assertTrue(self._test_document_file_page not in queryset)
