@@ -10,13 +10,11 @@ from mayan.apps.file_caching.permissions import permission_cache_partition_purge
 from mayan.apps.file_caching.tests.mixins import CachePartitionViewTestMixin
 
 from ..events import (
-    event_document_file_deleted, event_document_file_downloaded,
-    event_document_file_edited,
+    event_document_file_deleted, event_document_file_edited
 )
 from ..permissions import (
-    permission_document_file_delete, permission_document_file_download,
-    permission_document_file_edit, permission_document_file_print,
-    permission_document_file_view
+    permission_document_file_delete, permission_document_file_edit,
+    permission_document_file_print, permission_document_file_view
 )
 
 from .base import GenericDocumentViewTestCase
@@ -392,67 +390,6 @@ class DocumentFileViewTestCase(
         self.assertEqual(events.count(), 0)
 
 
-class DocumentFileDownloadViewTestCase(
-    DocumentFileViewTestMixin, GenericDocumentViewTestCase
-):
-    def test_document_file_download_view_no_permission(self):
-        self._clear_events()
-
-        response = self._request_test_document_file_download_view()
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_file_download_view_with_permission(self):
-        # Set the expected_content_types for
-        # common.tests.mixins.ContentTypeCheckMixin
-        self.expected_content_types = (
-            self._test_document.file_latest.mimetype,
-        )
-
-        self.grant_access(
-            obj=self._test_document,
-            permission=permission_document_file_download
-        )
-
-        self._clear_events()
-
-        response = self._request_test_document_file_download_view()
-        self.assertEqual(response.status_code, 200)
-
-        with self._test_document.file_latest.open() as file_object:
-            self.assert_download_response(
-                response=response, content=file_object.read(),
-                filename=self._test_document.file_latest.filename,
-                mime_type=self._test_document.file_latest.mimetype
-            )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 1)
-
-        self.assertEqual(events[0].action_object, self._test_document)
-        self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self._test_document_file)
-        self.assertEqual(events[0].verb, event_document_file_downloaded.id)
-
-    def test_trashed_document_file_download_view_with_permission(self):
-        self.grant_access(
-            obj=self._test_document,
-            permission=permission_document_file_download
-        )
-
-        self._test_document.delete()
-
-        self._clear_events()
-
-        response = self._request_test_document_file_download_view()
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-
 class DocumentFileTransformationViewTestCase(
     LayerTestMixin, DocumentFileTransformationTestMixin,
     DocumentFileTransformationViewTestMixin, GenericDocumentViewTestCase
