@@ -5,21 +5,20 @@ from mayan.apps.converter.permissions import (
     permission_transformation_delete, permission_transformation_edit
 )
 from mayan.apps.converter.tests.mixins import LayerTestMixin
-from mayan.apps.documents.tests.literals import TEST_MULTI_PAGE_TIFF
+from mayan.apps.documents.tests.literals import TEST_FILE_MULTI_PAGE_TIFF_FILENAME
 
 from ..events import (
     event_document_version_page_created, event_document_version_page_deleted
 )
-from ..literals import DOCUMENT_FILE_ACTION_PAGES_KEEP
 from ..permissions import (
     permission_document_version_edit, permission_document_version_view
 )
 
 from .base import GenericDocumentViewTestCase
+from .mixins.document_file_mixins import DocumentFileTestMixin
 from .mixins.document_version_mixins import (
-    DocumentVersionPageAppendViewTestMixin,
     DocumentVersionPageRemapViewTestMixin,
-    DocumentVersionPageResetViewTestMixin, DocumentVersionPageViewTestMixin,
+    DocumentVersionPageViewTestMixin,
     DocumentVersionTransformationTestMixin,
     DocumentVersionTransformationViewTestMixin
 )
@@ -29,7 +28,7 @@ class DocumentVersionPageViewTestCase(
     DocumentVersionPageViewTestMixin, GenericDocumentViewTestCase
 ):
     def test_document_version_page_delete_no_permission(self):
-        test_document_version_page_count = self.test_document_version.pages.count()
+        test_document_version_page_count = self._test_document_version.pages.count()
 
         self._clear_events()
 
@@ -37,7 +36,7 @@ class DocumentVersionPageViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document_version.pages.count(),
+            self._test_document_version.pages.count(),
             test_document_version_page_count
         )
 
@@ -45,10 +44,10 @@ class DocumentVersionPageViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_page_delete_with_access(self):
-        test_document_version_page_count = self.test_document_version.pages.count()
+        test_document_version_page_count = self._test_document_version.pages.count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
@@ -58,7 +57,7 @@ class DocumentVersionPageViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document_version.pages.count(),
+            self._test_document_version.pages.count(),
             test_document_version_page_count - 1
         )
 
@@ -67,20 +66,20 @@ class DocumentVersionPageViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_document_version_page_deleted.id
         )
 
     def test_trashed_document_version_page_delete_with_access(self):
-        test_document_version_page_count = self.test_document_version.pages.count()
+        test_document_version_page_count = self._test_document_version.pages.count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -88,7 +87,7 @@ class DocumentVersionPageViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document_version.pages.count(),
+            self._test_document_version.pages.count(),
             test_document_version_page_count
         )
 
@@ -106,7 +105,7 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -115,7 +114,7 @@ class DocumentVersionPageViewTestCase(
         response = self._request_test_document_version_page_list_view()
         self.assertContains(
             response=response, status_code=200,
-            text=str(self.test_document_version)
+            text=str(self._test_document_version)
         )
 
         events = self._get_test_events()
@@ -123,11 +122,11 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -148,7 +147,7 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_rotate_left_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -162,11 +161,11 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_rotate_left_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -187,7 +186,7 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_rotate_right_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -201,11 +200,11 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_rotate_right_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -219,7 +218,7 @@ class DocumentVersionPageViewTestCase(
         self._clear_events()
 
         response = self._request_test_document_version_page_view(
-            document_version_page=self.test_document_version.pages.first()
+            document_version_page=self._test_document_version.pages.first()
         )
         self.assertEqual(response.status_code, 404)
 
@@ -228,18 +227,18 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
         self._clear_events()
 
         response = self._request_test_document_version_page_view(
-            document_version_page=self.test_document_version.pages.first()
+            document_version_page=self._test_document_version.pages.first()
         )
         self.assertContains(
             response=response, status_code=200, text=str(
-                self.test_document_version.pages.first()
+                self._test_document_version.pages.first()
             )
         )
 
@@ -248,16 +247,16 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_version_page_view(
-            document_version_page=self.test_document_version.pages.first()
+            document_version_page=self._test_document_version.pages.first()
         )
         self.assertEqual(response.status_code, 404)
 
@@ -275,7 +274,7 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_zoom_in_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -289,11 +288,11 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_zoom_in_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -314,7 +313,7 @@ class DocumentVersionPageViewTestCase(
 
     def test_document_version_page_zoom_out_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -328,11 +327,11 @@ class DocumentVersionPageViewTestCase(
 
     def test_trashed_document_version_page_zoom_out_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -343,132 +342,20 @@ class DocumentVersionPageViewTestCase(
         self.assertEqual(events.count(), 0)
 
 
-class DocumentVersionPageAppendViewTestCase(
-    DocumentVersionPageAppendViewTestMixin, GenericDocumentViewTestCase
-):
-    def setUp(self):
-        super().setUp()
-        self._upload_test_document_file(
-            action=DOCUMENT_FILE_ACTION_PAGES_KEEP
-        )
-        self.test_document_file_pages = []
-        self.source_content_types = []
-        self.source_object_ids = []
-
-        for test_document_file in self.test_document.files.all():
-            for test_document_file_page in test_document_file.pages.all():
-                self.test_document_file_pages.append(test_document_file_page)
-                self.source_content_types.append(
-                    ContentType.objects.get_for_model(
-                        model=test_document_file_page
-                    )
-                )
-                self.source_object_ids.append(test_document_file_page.pk)
-
-    def test_document_version_append_view_no_permission(self):
-        document_version_page_count = self.test_document_version.pages.count()
-
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_append_view()
-        self.assertEqual(response.status_code, 404)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.count(),
-            document_version_page_count
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_version_append_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_version,
-            permission=permission_document_version_edit
-        )
-
-        document_version_page_count = self.test_document_version.pages.count()
-
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_append_view()
-        self.assertEqual(response.status_code, 302)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.count(),
-            document_version_page_count + 1
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 3)
-
-        self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
-        self.assertEqual(
-            events[0].verb, event_document_version_page_deleted.id
-        )
-
-        self.assertEqual(events[1].action_object, self.test_document_version)
-        self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(
-            events[1].target, self.test_document_version.pages[0]
-        )
-        self.assertEqual(
-            events[1].verb, event_document_version_page_created.id
-        )
-        self.assertEqual(events[2].action_object, self.test_document_version)
-        self.assertEqual(events[2].actor, self._test_case_user)
-        self.assertEqual(
-            events[2].target, self.test_document_version.pages[1]
-        )
-        self.assertEqual(
-            events[2].verb, event_document_version_page_created.id
-        )
-
-    def test_trashed_document_version_append_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_version,
-            permission=permission_document_version_edit
-        )
-
-        document_version_page_count = self.test_document_version.pages.count()
-
-        self.test_document.delete()
-
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_append_view()
-        self.assertEqual(response.status_code, 404)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.count(),
-            document_version_page_count
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-
 class DocumentVersionPageRemapViewTestCase(
-    DocumentVersionPageRemapViewTestMixin, GenericDocumentViewTestCase
+    DocumentVersionPageRemapViewTestMixin, DocumentFileTestMixin,
+    GenericDocumentViewTestCase
 ):
     def setUp(self):
         super().setUp()
         self._upload_test_document_file()
-        self.test_document_file_pages = []
+        self._test_document_file_pages = []
         self.source_content_types = []
         self.source_object_ids = []
 
-        for test_document_file in self.test_document.files.all():
+        for test_document_file in self._test_document.files.all():
             for test_document_file_page in test_document_file.pages.all():
-                self.test_document_file_pages.append(test_document_file_page)
+                self._test_document_file_pages.append(test_document_file_page)
                 self.source_content_types.append(
                     ContentType.objects.get_for_model(
                         model=test_document_file_page
@@ -507,15 +394,15 @@ class DocumentVersionPageRemapViewTestCase(
         )
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
 
         self.assertNotEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[0]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[0]
         )
         self.assertEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[1]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[1]
         )
 
         events = self._get_test_events()
@@ -523,7 +410,7 @@ class DocumentVersionPageRemapViewTestCase(
 
     def test_document_version_remap_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
@@ -534,15 +421,15 @@ class DocumentVersionPageRemapViewTestCase(
         )
         self.assertEqual(response.status_code, 302)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
 
         self.assertEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[0]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[0]
         )
         self.assertNotEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[1]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[1]
         )
 
         events = self._get_test_events()
@@ -550,15 +437,15 @@ class DocumentVersionPageRemapViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_document_version_page_deleted.id
         )
 
-        self.assertEqual(events[1].action_object, self.test_document_version)
+        self.assertEqual(events[1].action_object, self._test_document_version)
         self.assertEqual(events[1].actor, self._test_case_user)
         self.assertEqual(
-            events[1].target, self.test_document_version.pages[0]
+            events[1].target, self._test_document_version.pages[0]
         )
         self.assertEqual(
             events[1].verb, event_document_version_page_created.id
@@ -566,11 +453,11 @@ class DocumentVersionPageRemapViewTestCase(
 
     def test_trashed_document_version_remap_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -579,15 +466,15 @@ class DocumentVersionPageRemapViewTestCase(
         )
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
 
         self.assertNotEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[0]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[0]
         )
         self.assertEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[1]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[1]
         )
 
         events = self._get_test_events()
@@ -595,7 +482,7 @@ class DocumentVersionPageRemapViewTestCase(
 
     def test_document_version_remap_repeated_target_page_number_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
@@ -606,114 +493,15 @@ class DocumentVersionPageRemapViewTestCase(
         )
         self.assertEqual(response.status_code, 200)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
 
         self.assertNotEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[0]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[0]
         )
         self.assertEqual(
-            self.test_document_version.pages.first().content_object,
-            self.test_document_file_pages[1]
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-
-class DocumentVersionPageResetViewTestCase(
-    DocumentVersionPageResetViewTestMixin, GenericDocumentViewTestCase
-):
-    def setUp(self):
-        super().setUp()
-        self._upload_test_document_file(
-            action=DOCUMENT_FILE_ACTION_PAGES_KEEP
-        )
-        self.test_document_file_pages = []
-        self.source_content_types = []
-        self.source_object_ids = []
-
-        for test_document_file in self.test_document.files.all():
-            for test_document_file_page in test_document_file.pages.all():
-                self.test_document_file_pages.append(test_document_file_page)
-                self.source_content_types.append(
-                    ContentType.objects.get_for_model(
-                        model=test_document_file_page
-                    )
-                )
-                self.source_object_ids.append(test_document_file_page.pk)
-
-    def test_document_version_reset_view_no_permission(self):
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_reset_view()
-        self.assertEqual(response.status_code, 404)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.all()[0].content_object,
-            self.test_document_file_pages[0]
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_version_reset_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_version,
-            permission=permission_document_version_edit
-        )
-
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_reset_view()
-        self.assertEqual(response.status_code, 302)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.all()[0].content_object,
-            self.test_document_file_pages[1]
-        )
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 2)
-
-        self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
-        self.assertEqual(
-            events[0].verb, event_document_version_page_deleted.id
-        )
-
-        self.assertEqual(events[1].action_object, self.test_document_version)
-        self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(
-            events[1].target, self.test_document_version.pages[0]
-        )
-        self.assertEqual(
-            events[1].verb, event_document_version_page_created.id
-        )
-
-    def test_trashed_document_version_reset_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document_version,
-            permission=permission_document_version_edit
-        )
-
-        self.test_document.delete()
-
-        self._clear_events()
-
-        response = self._request_test_document_version_page_list_reset_view()
-        self.assertEqual(response.status_code, 404)
-
-        self.test_document_version.refresh_from_db()
-
-        self.assertEqual(
-            self.test_document_version.pages.all()[0].content_object,
-            self.test_document_file_pages[0]
+            self._test_document_version.pages.first().content_object,
+            self._test_document_file_pages[1]
         )
 
         events = self._get_test_events()
@@ -724,12 +512,12 @@ class DocumentVersionTransformationViewTestCase(
     LayerTestMixin, DocumentVersionTransformationTestMixin,
     DocumentVersionTransformationViewTestMixin, GenericDocumentViewTestCase
 ):
-    test_document_filename = TEST_MULTI_PAGE_TIFF
+    _test_document_filename = TEST_FILE_MULTI_PAGE_TIFF_FILENAME
 
     def setUp(self):
         super().setUp()
         self.assertTrue(
-            expr=self.test_document_version.pages.count() > 1,
+            expr=self._test_document_version.pages.count() > 1,
             msg='Test document must have more than one page'
         )
 
@@ -737,7 +525,7 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self._clear_events()
@@ -747,7 +535,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count
         )
 
@@ -758,11 +546,11 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_delete
         )
 
@@ -773,7 +561,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count - 1
         )
 
@@ -784,15 +572,15 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_delete
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -801,7 +589,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count
         )
 
@@ -812,7 +600,7 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self._clear_events()
@@ -822,7 +610,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count
         )
 
@@ -833,15 +621,15 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_delete
         )
 
@@ -852,7 +640,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count - 1,
         )
 
@@ -863,19 +651,19 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_delete
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -884,7 +672,7 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), transformation_count
         )
 
@@ -895,10 +683,10 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         page_first_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
         page_last_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.last()
+            obj=self._test_document_version.pages.last()
         ).count()
 
         self._clear_events()
@@ -908,12 +696,12 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), page_first_transformation_count
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.last()
+                obj=self._test_document_version.pages.last()
             ).count(), page_last_transformation_count
         )
 
@@ -924,14 +712,14 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         page_first_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
         page_last_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.last()
+            obj=self._test_document_version.pages.last()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_edit
         )
 
@@ -942,12 +730,12 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), page_first_transformation_count
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.last()
+                obj=self._test_document_version.pages.last()
             ).count(), page_last_transformation_count + 1
         )
 
@@ -958,18 +746,18 @@ class DocumentVersionTransformationViewTestCase(
         self._create_document_version_transformation()
 
         page_first_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.first()
+            obj=self._test_document_version.pages.first()
         ).count()
         page_last_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_version.pages.last()
+            obj=self._test_document_version.pages.last()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_transformation_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -978,12 +766,12 @@ class DocumentVersionTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.first()
+                obj=self._test_document_version.pages.first()
             ).count(), page_first_transformation_count
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_version.pages.last()
+                obj=self._test_document_version.pages.last()
             ).count(), page_last_transformation_count
         )
 
