@@ -3,7 +3,7 @@ from mayan.apps.acls.permissions import permission_acl_edit
 from mayan.apps.acls.tests.mixins import (
     ACLTestMixin, AccessControlListViewTestMixin
 )
-from mayan.apps.common.tests.base import BaseTestCase
+from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import DocumentType
 from ..permissions import permission_document_view
@@ -23,10 +23,10 @@ class DocumentTypeACLPermissionsViewTestCase(
     auto_upload_test_document = False
 
     def test_document_type_acl_permission_view_with_access(self):
-        self.test_object = self.test_document_type
+        self._test_object = self._test_document_type
         self._create_test_acl()
         self.grant_access(
-            obj=self.test_object, permission=permission_acl_edit
+            obj=self._test_object, permission=permission_acl_edit
         )
 
         response = self._request_test_acl_permission_list_get_view()
