@@ -6,17 +6,17 @@ from .api_views.document_api_views import (
     APIDocumentUploadView
 )
 from .api_views.document_file_api_views import (
-    APIDocumentFileDetailView, APIDocumentFileDownloadView,
-    APIDocumentFileListView, APIDocumentFilePageImageView,
-    APIDocumentFilePageDetailView, APIDocumentFilePageListView
+    APIDocumentFileDetailView, APIDocumentFileListView,
+    APIDocumentFilePageImageView, APIDocumentFilePageDetailView,
+    APIDocumentFilePageListView
 )
 from .api_views.document_type_api_views import (
     APIDocumentTypeDetailView, APIDocumentTypeListView,
     APIDocumentTypeQuickLabelDetailView, APIDocumentTypeQuickLabelListView
 )
 from .api_views.document_version_api_views import (
-    APIDocumentVersionDetailView, APIDocumentVersionExportView,
-    APIDocumentVersionListView, APIDocumentVersionModificationBackendListView,
+    APIDocumentVersionDetailView, APIDocumentVersionListView,
+    APIDocumentVersionModificationBackendListView,
     APIDocumentVersionModificationView, APIDocumentVersionPageDetailView,
     APIDocumentVersionPageImageView, APIDocumentVersionPageListView
 )
@@ -34,8 +34,8 @@ from .api_views.trashed_document_api_views import (
     APITrashedDocumentRestoreView, APITrashedDocumentImageView
 )
 from .views.document_file_views import (
-    DocumentFileDeleteView, DocumentFileDownloadView, DocumentFileEditView,
-    DocumentFileListView, DocumentFilePrintFormView, DocumentFilePrintView,
+    DocumentFileDeleteView, DocumentFileEditView, DocumentFileListView,
+    DocumentFilePrintFormView, DocumentFilePrintView,
     DocumentFilePropertiesView, DocumentFilePreviewView,
     DocumentFileTransformationsClearView,
     DocumentFileTransformationsCloneView
@@ -68,10 +68,9 @@ from .views.document_version_page_views import (
 from .views.document_version_views import (
     DocumentVersionActiveView, DocumentVersionCreateView,
     DocumentVersionDeleteView, DocumentVersionEditView,
-    DocumentVersionExportView, DocumentVersionListView,
-    DocumentVersionModifyView, DocumentVersionPreviewView,
-    DocumentVersionPrintFormView, DocumentVersionPrintView,
-    DocumentVersionTransformationsClearView,
+    DocumentVersionListView, DocumentVersionModifyView,
+    DocumentVersionPreviewView, DocumentVersionPrintFormView,
+    DocumentVersionPrintView, DocumentVersionTransformationsClearView,
     DocumentVersionTransformationsCloneView
 )
 from .views.document_views import (
@@ -111,11 +110,6 @@ urlpatterns_document_files = [
         name='document_file_multiple_delete',
         view=DocumentFileDeleteView.as_view()
     ),
-    url(
-        regex=r'^documents/files/(?P<document_file_id>\d+)/download/$',
-        name='document_file_download',
-        view=DocumentFileDownloadView.as_view()
-    ),
     url(
         regex=r'^documents/files/(?P<document_file_id>\d+)/edit/$',
         name='document_file_edit',
@@ -290,11 +284,6 @@ urlpatterns_document_version = [
         name='document_version_single_delete',
         view=DocumentVersionDeleteView.as_view()
     ),
-    url(
-        regex=r'^documents/versions/(?P<document_version_id>\d+)/export/$',
-        name='document_version_export',
-        view=DocumentVersionExportView.as_view()
-    ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/edit/$',
         name='document_version_edit',
@@ -573,11 +562,6 @@ api_urls_document_files = [
         regex=r'^documents/(?P<document_id>[0-9]+)/files/(?P<document_file_id>[0-9]+)/$',
         name='documentfile-detail', view=APIDocumentFileDetailView.as_view()
     ),
-    url(
-        regex=r'^documents/(?P<document_id>[0-9]+)/files/(?P<document_file_id>[0-9]+)/download/$',
-        name='documentfile-download',
-        view=APIDocumentFileDownloadView.as_view()
-    ),
     url(
         regex=r'^documents/(?P<document_id>[0-9]+)/files/(?P<document_file_id>[0-9]+)/pages/$',
         name='documentfilepage-list',
@@ -632,11 +616,6 @@ api_urls_document_versions = [
         name='documentversion-detail',
         view=APIDocumentVersionDetailView.as_view()
     ),
-    url(
-        regex=r'^documents/(?P<document_id>[0-9]+)/versions/(?P<document_version_id>[0-9]+)/export/$',
-        view=APIDocumentVersionExportView.as_view(),
-        name='documentversion-export'
-    ),
     url(
         regex=r'^documents/(?P<document_id>[0-9]+)/versions/(?P<document_version_id>[0-9]+)/modify/$',
         name='documentversion-modify',
