@@ -34,13 +34,3 @@ def get_language_choices():
             logger.warning('Unknown language code "%s".', iso639_3)
 
     return sorted(result, key=lambda x: x[1])
-
-
-def parse_range(astr):
-    # http://stackoverflow.com/questions/4248399/
-    # page-range-for-printing-algorithm
-    result = set()
-    for part in astr.split(','):
-        x = part.split('-')
-        result.update(range(int(x[0]), int(x[-1]) + 1))
-    return sorted(result)
