@@ -11,13 +11,12 @@ from mayan.apps.converter.permissions import (
     permission_transformation_delete, permission_transformation_edit
 )
 from mayan.apps.converter.transformations import TransformationResize
-from mayan.apps.organizations.utils import get_organization_installation_url
 from mayan.apps.views.generics import (
     ConfirmView, FormView, MultipleObjectConfirmActionView,
     MultipleObjectDeleteView, SingleObjectCreateView, SingleObjectDetailView,
     SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalObjectViewMixin
 
 from ..classes import DocumentVersionModification
 from ..events import event_document_viewed
@@ -29,9 +28,8 @@ from ..forms.misc_forms import PageNumberForm
 from ..icons import (
     icon_document_version_active, icon_document_version_create,
     icon_document_version_delete, icon_document_version_edit,
-    icon_document_version_export, icon_document_version_list,
-    icon_document_version_modification, icon_document_version_preview,
-    icon_document_version_print,
+    icon_document_version_list, icon_document_version_modification,
+    icon_document_version_preview, icon_document_version_print,
     icon_document_version_transformation_list_clear,
     icon_document_version_transformation_list_clone
 )
@@ -40,21 +38,15 @@ from ..models.document_models import Document
 from ..models.document_version_models import DocumentVersion
 from ..permissions import (
     permission_document_version_create, permission_document_version_delete,
-    permission_document_version_edit, permission_document_version_export,
-    permission_document_version_print, permission_document_version_view
+    permission_document_version_edit, permission_document_version_print,
+    permission_document_version_view
 )
 from ..settings import setting_preview_height, setting_preview_width
-from ..tasks import (
-    task_document_version_delete, task_document_version_export
-)
+from ..tasks import task_document_version_delete
 
 from .misc_views import PrintFormView, DocumentPrintBaseView
-from .mixins import RecentDocumentViewMixin
+from .view_mixins import RecentDocumentViewMixin
 
-__all__ = (
-    'DocumentVersionCreateView', 'DocumentVersionListView',
-    'DocumentVersionPreviewView'
-)
 logger = logging.getLogger(name=__name__)
 
 
@@ -69,7 +61,7 @@ class DocumentVersionActiveView(ExternalObjectViewMixin, ConfirmView):
             'object': self.external_object,
             'title': _(
                 'Make the document version "%s" the active version?'
-            ) % self.external_object,
+            ) % self.external_object
         }
 
     def view_action(self, form=None):
@@ -94,7 +86,7 @@ class DocumentVersionCreateView(ExternalObjectViewMixin, SingleObjectCreateView)
             'object': self.external_object,
             'title': _(
                 'Create a document version for document: %s'
-            ) % self.external_object,
+            ) % self.external_object
         }
 
     def get_instance_extra_data(self):
@@ -135,7 +127,7 @@ class DocumentVersionDeleteView(MultipleObjectDeleteView):
         if self.object_list.count() > 1:
             context.update(
                 {
-                    'object': self.object_list.first().document,
+                    'object': self.object_list.first().document
                 }
             )
 
@@ -167,12 +159,12 @@ class DocumentVersionEditView(SingleObjectEditView):
 
     def get_extra_context(self):
         return {
-            'title': _('Edit document version: %s') % self.object,
+            'title': _('Edit document version: %s') % self.object
         }
 
     def get_instance_extra_data(self):
         return {
-            '_event_actor': self.request.user,
+            '_event_actor': self.request.user
         }
 
     def get_post_action_redirect(self):
@@ -183,49 +175,6 @@ class DocumentVersionEditView(SingleObjectEditView):
         )
 
 
-class DocumentVersionExportView(MultipleObjectConfirmActionView):
-    object_permission = permission_document_version_export
-    pk_url_kwarg = 'document_version_id'
-    source_queryset = DocumentVersion.valid.all()
-    success_message_single = _(
-        'Document version "%(object)s" export successfully queued.'
-    )
-    success_message_singular = _(
-        '%(count)d document version export successfully queued.'
-    )
-    success_message_plural = _(
-        '%(count)d document versions exports successfully queued.'
-    )
-    title_single = _('Export document version "%(object)s".')
-    title_singular = _('Export %(count)d document version.')
-    title_plural = _('Export %(count)d document versions.')
-    view_icon = icon_document_version_export
-
-    def get_extra_context(self):
-        context = {
-            'message': _(
-                'The process will be performed in the background. '
-                'The exported file will be available in the downloads area.'
-            ),
-        }
-
-        if self.object_list.count() == 1:
-            context['object'] = self.object_list.first()
-
-        return context
-
-    def object_action(self, form, instance):
-        task_document_version_export.apply_async(
-            kwargs={
-                'document_version_id': instance.pk,
-                'organization_installation_url': get_organization_installation_url(
-                    request=self.request
-                ),
-                'user_id': self.request.user.pk
-            }
-        )
-
-
 class DocumentVersionListView(
     ExternalObjectViewMixin, RecentDocumentViewMixin, SingleObjectListView
 ):
@@ -280,7 +229,7 @@ class DocumentVersionModifyView(ExternalObjectViewMixin, FormView):
             name=form.cleaned_data['backend']
         ).execute(
             document_version=self.external_object,
-            _user=self.request.user
+            user=self.request.user
         )
 
         messages.success(
@@ -295,7 +244,8 @@ class DocumentVersionModifyView(ExternalObjectViewMixin, FormView):
         context = {
             'object': self.external_object,
             'title': _(
-                'Execute version modification action for document version: %s'
+                'Execute version modification action for document '
+                'version: %s'
             ) % self.external_object
         }
 
@@ -325,7 +275,7 @@ class DocumentVersionPreviewView(SingleObjectDetailView):
         return {
             'hide_labels': True,
             'object': self.object,
-            'title': _('Preview of document version: %s') % self.object,
+            'title': _('Preview of document version: %s') % self.object
         }
 
     def get_form_extra_kwargs(self):
@@ -372,10 +322,12 @@ class DocumentVersionTransformationsClearView(MultipleObjectConfirmActionView):
     pk_url_kwarg = 'document_version_id'
     source_queryset = DocumentVersion.valid.all()
     success_message = _(
-        'Transformation clear request processed for %(count)d document version.'
+        'Transformation clear request processed for %(count)d document '
+        'version.'
     )
     success_message_plural = _(
-        'Transformation clear request processed for %(count)d document versions.'
+        'Transformation clear request processed for %(count)d document '
+        'versions.'
     )
     view_icon = icon_document_version_transformation_list_clear
 
