@@ -4,7 +4,7 @@ from django.utils.translation import ugettext_lazy as _
 from mayan.apps.common.utils import parse_range
 from mayan.apps.converter.transformations import TransformationResize
 from mayan.apps.views.generics import FormView, SimpleView
-from mayan.apps.views.mixins import ExternalObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalObjectViewMixin
 
 from ..forms.misc_forms import PrintForm
 from ..literals import PAGE_RANGE_RANGE
@@ -41,7 +41,7 @@ class PrintFormView(ExternalObjectViewMixin, FormView):
             'object': self.external_object,
             'submit_method': 'GET',
             'submit_target': '_blank',
-            'title': _('Print: %s') % self.external_object,
+            'title': _('Print: %s') % self.external_object
         }
 
 
