@@ -1,5 +1,3 @@
-import logging
-
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
@@ -11,8 +9,6 @@ from .managers import (
     DuplicateBackendEntryManager, StoredDuplicateBackendManager
 )
 
-logger = logging.getLogger(name=__name__)
-
 
 class StoredDuplicateBackend(BackendModelMixin, models.Model):
     _backend_model_null_backend = NullBackend
