@@ -1,10 +1,14 @@
+from unittest import skip
+
 from django.db import models
 
 from mayan.apps.testing.tests.base import BaseTestCase
 
-from ..classes import SearchBackend, SearchModel
+from ..search_backends import SearchBackend
+from ..search_models import SearchModel
 
-from .mixins import SearchTaskTestMixin, SearchTestMixin
+from .mixins.base import SearchTestMixin
+from .mixins.task_mixins import SearchTaskTestMixin
 
 
 class SearchTaskTestCase(SearchTaskTestMixin, SearchTestMixin, BaseTestCase):
@@ -12,9 +16,10 @@ class SearchTaskTestCase(SearchTaskTestMixin, SearchTestMixin, BaseTestCase):
     auto_create_test_object_fields = {
         'test_field': models.CharField(max_length=8)
     }
+    auto_test_search_objects_create = False
 
     def _do_search(self, search_terms):
-        return self.search_backend.search(
+        return self._test_search_backend.search(
             search_model=self._test_model_search,
             query={
                 'test_field': search_terms
@@ -30,11 +35,14 @@ class SearchTaskTestCase(SearchTaskTestMixin, SearchTestMixin, BaseTestCase):
 
     def setUp(self):
         super().setUp()
-        self._create_test_object(instance_kwargs={'test_field': 'abc'})
+        self._create_test_object(
+            instance_kwargs={'test_field': 'abc'}
+        )
 
         backend = SearchBackend.get_instance()
         backend.reset()
 
+    @skip(reason='Test with a backend that supports reindexing.')
     def test_task_index_instances(self):
         queryset = self._do_search(
             search_terms=self._test_objects[0].test_field
@@ -48,6 +56,7 @@ class SearchTaskTestCase(SearchTaskTestMixin, SearchTestMixin, BaseTestCase):
         )
         self.assertTrue(self._test_objects[0] in queryset)
 
+    @skip(reason='Test with a backend that supports reindexing.')
     def test_task_reindex_backend(self):
         queryset = self._do_search(
             search_terms=self._test_objects[0].test_field
