@@ -2,7 +2,9 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.permissions import PermissionNamespace
 
-namespace = PermissionNamespace(label=_('Events'), name='events')
+namespace = PermissionNamespace(
+    label=_('Events'), name='events'
+)
 
 permission_events_clear = namespace.add_permission(
     label=_('Clear the events of an object'), name='events_clear'
