@@ -1,13 +1,11 @@
-from actstream.models import Action
+from actstream.models import Action, any_stream
 
 from mayan.apps.acls.classes import ModelPermission
-from mayan.apps.permissions.tests.mixins import RoleTestMixin
-from mayan.apps.user_management.tests.mixins import GroupTestMixin
 
 from ..classes import (
     EventModelRegistry, EventTypeNamespace, EventType, ModelEventType
 )
-from ..models import Notification
+from ..models import Notification, ObjectEventSubscription
 from ..permissions import permission_events_view
 
 from .literals import (
@@ -17,37 +15,37 @@ from .literals import (
 
 
 class EventsClearViewTestMixin:
-    def _request_test_events_by_verb_clear_view(self):
+    def _request_test_verb_event_list_clear_view(self):
         return self.post(
-            viewname='events:events_by_verb_clear', kwargs={
+            viewname='events:verb_event_list_clear', kwargs={
                 'verb': self._test_event_type.id
             }
         )
 
-    def _request_test_events_list_clear_view(self):
-        return self.post(viewname='events:events_list_clear')
+    def _request_test_event_list_clear_view(self):
+        return self.post(viewname='events:event_list_clear')
 
-    def _request_events_for_object_clear_view(self):
+    def _request_object_event_list_clear_view(self):
         return self.post(
-            viewname='events:events_for_object_clear',
+            viewname='events:object_event_list_clear',
             kwargs=self.view_arguments
         )
 
 
 class EventsExportViewTestMixin:
-    def _request_test_events_by_verb_export_view(self):
+    def _request_test_verb_event_list_export_view(self):
         return self.post(
-            viewname='events:events_by_verb_export', kwargs={
+            viewname='events:verb_event_list_export', kwargs={
                 'verb': self._test_event_type.id
             }
         )
 
-    def _request_test_events_list_export_view(self):
-        return self.post(viewname='events:events_list_export')
+    def _request_test_event_list_export_view(self):
+        return self.post(viewname='events:event_list_export')
 
-    def _request_events_for_object_export_view(self):
+    def _request_object_event_list_export_view(self):
         return self.post(
-            viewname='events:events_for_object_export',
+            viewname='events:object_event_list_export',
             kwargs=self.view_arguments
         )
 
@@ -57,17 +55,36 @@ class EventListAPIViewTestMixin:
         return self.get(viewname='rest_api:event-list')
 
 
+class EventObjectTestMixin:
+    def _create_test_object_with_event_type_and_permission(self):
+        self._create_test_object()
+
+        EventModelRegistry.register(model=self.TestModel)
+
+        ModelEventType.register(
+            event_types=(self._test_event_type,), model=self.TestModel
+        )
+
+        EventType.refresh()
+
+        ModelPermission.register(
+            model=self.TestModel, permissions=(
+                permission_events_view,
+            )
+        )
+
+
 class EventTestMixin:
     def setUp(self):
         super().setUp()
-        self.test_events = []
+        self._test_events = []
 
     def _create_test_event(self, action_object=None, actor=None, target=None):
-        self.test_event = self._test_event_type.commit(
+        self._test_event = self._test_event_type.commit(
             action_object=action_object, actor=actor or self._test_case_user,
             target=target
         )
-        self.test_events.append(self.test_event)
+        self._test_events.append(self._test_event)
 
 
 class EventTestCaseMixin:
@@ -119,62 +136,37 @@ class EventTypeTestMixin:
         )
 
         self._test_event_type_namespace = EventTypeNamespace(
-            label=test_namespace_label,
-            name=test_namespace_name
+            label=test_namespace_label, name=test_namespace_name
         )
         self._test_event_type = self._test_event_type_namespace.add_event_type(
-            label=test_event_label,
-            name=test_event_name
+            label=test_event_label, name=test_event_name
         )
         self._test_event_types.append(self._test_event_type)
 
 
 class EventViewTestMixin:
-    def _request_test_events_by_verb_view(self):
+    def _request_test_verb_event_list_view(self):
         return self.get(
-            viewname='events:events_by_verb', kwargs={
+            viewname='events:verb_event_list', kwargs={
                 'verb': self._test_event_type.id
             }
         )
 
-    def _request_test_events_list_view(self):
-        return self.get(viewname='events:events_list')
+    def _request_test_event_list_view(self):
+        return self.get(viewname='events:event_list')
 
-    def _request_events_for_object_view(self):
+    def _request_test_object_event_list_view(self):
         return self.get(
-            viewname='events:events_for_object', kwargs=self.view_arguments
+            viewname='events:object_event_list', kwargs=self.view_arguments
         )
 
 
-class NotificationTestMixin(
-    EventTypeTestMixin, GroupTestMixin, RoleTestMixin
-):
-    def _create_local_test_object(self):
-        super()._create_test_object()
-
-        EventModelRegistry.register(model=self.TestModel)
-
-        ModelEventType.register(
-            event_types=(self._test_event_type,), model=self.TestModel
-        )
-
-        EventType.refresh()
-
-        ModelPermission.register(
-            model=self.TestModel, permissions=(
-                permission_events_view,
-            )
-        )
-
-    def _create_local_test_user(self):
-        self._create_test_user()
-        self._create_test_group(add_users=(self.test_user,))
-        self._create_test_role(add_groups=(self.test_group,))
-
+class NotificationTestMixin:
     def _create_test_notification(self):
-        self.test_notification = Notification.objects.create(
-            user=self._test_case_user, action=Action.objects.first(),
-            read=False
+        action = any_stream(obj=self._test_object).first()
+
+        self._test_notification = Notification.objects.create(
+            action=action, read=False, user=self._test_case_user
         )
 
 
@@ -188,7 +180,7 @@ class NotificationViewTestMixin:
     def _request_test_notification_mark_read(self):
         return self.post(
             viewname='events:notification_mark_read', kwargs={
-                'notification_id': self.test_notification.pk
+                'notification_id': self._test_notification.pk
             }
         )
 
@@ -201,6 +193,22 @@ class ObjectEventAPITestMixin:
         )
 
 
-class UserEventViewsTestMixin:
+class ObjectEventSubscriptionTestMixin:
+    def _create_test_object_event_subscription(self):
+        ObjectEventSubscription.objects.create(
+            content_object=self._test_object,
+            user=self._test_case_user,
+            stored_event_type=self._test_event_type.get_stored_event_type()
+        )
+
+
+class UserEventViewTestMixin:
     def _request_test_user_event_type_subscription_list_view(self):
-        return self.get(viewname='events:event_types_user_subscriptions_list')
+        return self.get(viewname='events:event_type_user_subscription_list')
+
+
+class UserObjectSubscriptionViewTestMixin:
+    def _request_user_object_subscription_list_view(self):
+        return self.get(
+            viewname='events:user_object_subscription_list'
+        )
