@@ -5,7 +5,7 @@ from actstream.models import Action
 
 from mayan.apps.databases.classes import QuerysetParametersSerializer
 from mayan.apps.views.generics import ConfirmView
-from mayan.apps.views.mixins import ExternalContentTypeObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalContentTypeObjectViewMixin
 
 from ..icons import (
     icon_event_list_export, icon_object_event_list_export,
@@ -14,7 +14,7 @@ from ..icons import (
 from ..permissions import permission_events_export
 from ..tasks import task_event_queryset_export
 
-from .mixins import VerbEventViewMixin
+from .view_mixins import VerbEventViewMixin
 
 
 class EventExportBaseView(ConfirmView):
@@ -25,7 +25,8 @@ class EventExportBaseView(ConfirmView):
         return {
             'message': _(
                 'The process will be performed in the background. '
-                'The exported events will be available in the downloads area.'
+                'The exported events will be available in the downloads '
+                'area.'
             )
         }
 
@@ -42,9 +43,9 @@ class EventExportBaseView(ConfirmView):
         )
 
         messages.success(
-            request=self.request, message=_(
+            message=_(
                 'Event list export task queued successfully.'
-            )
+            ), request=self.request
         )
 
 
