@@ -12,7 +12,9 @@ from .permissions import permission_cache_purge, permission_cache_view
 
 def condition_valid_storage(context, resolved_object):
     try:
-        storage = DefinedStorage.get(name=context['object'].defined_storage_name)
+        storage = DefinedStorage.get(
+            name=context['object'].defined_storage_name
+        )
     except KeyError:
         return False
     else:
