@@ -2,10 +2,13 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.permissions import PermissionNamespace
 
-namespace = PermissionNamespace(label=_('File caching'), name='file_caching')
+namespace = PermissionNamespace(
+    label=_('File caching'), name='file_caching'
+)
 
 permission_cache_partition_purge = namespace.add_permission(
-    label=_('Purge an object cache'), name='file_caching_cache_partition_purge'
+    label=_('Purge an object cache'),
+    name='file_caching_cache_partition_purge'
 )
 permission_cache_purge = namespace.add_permission(
     label=_('Purge a file cache'), name='file_caching_cache_purge'
