@@ -111,7 +111,7 @@ class CacheViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
-        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].action_object, self._test_cache)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_cache_partition)
         self.assertEqual(events[0].verb, event_cache_partition_purged.id)
@@ -161,7 +161,7 @@ class CacheViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
-        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].action_object, self._test_cache)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_cache_partition)
         self.assertEqual(events[0].verb, event_cache_partition_purged.id)
