@@ -6,7 +6,7 @@ from mayan.apps.views.generics import (
     ConfirmView, MultipleObjectConfirmActionView, SingleObjectDetailView,
     SingleObjectListView
 )
-from mayan.apps.views.mixins import (
+from mayan.apps.views.view_mixins import (
     ContentTypeViewMixin, ExternalObjectViewMixin
 )
 
@@ -47,7 +47,7 @@ class CacheDetailView(SingleObjectDetailView):
     def get_extra_context(self):
         return {
             'object': self.object,
-            'title': _('Details of cache: %s') % self.object,
+            'title': _('Details of cache: %s') % self.object
         }
 
 
@@ -80,7 +80,7 @@ class CachePartitionDetailView(SingleObjectDetailView):
     def get_extra_context(self):
         return {
             'object': self.object,
-            'title': _('Details cache: %s') % self.object,
+            'title': _('Details of cache partition: %s') % self.object
         }
 
 
@@ -97,7 +97,9 @@ class CachePartitionPurgeView(
     def get_extra_context(self):
         return {
             'object': self.external_object,
-            'title': _('Purge cache partitions of "%s"?') % self.external_object
+            'title': _(
+                'Purge cache partitions of "%s"?'
+            ) % self.external_object
         }
 
     def view_action(self, form=None):
@@ -122,8 +124,8 @@ class CachePurgeView(MultipleObjectConfirmActionView):
     model = Cache
     object_permission = permission_cache_purge
     pk_url_kwarg = 'cache_id'
-    success_message_singular = _('%(count)d cache submitted for purging.')
     success_message_plural = _('%(count)d caches submitted for purging.')
+    success_message_singular = _('%(count)d cache submitted for purging.')
     view_icon = icon_cache_purge
 
     def get_extra_context(self):
