@@ -26,6 +26,10 @@ from .links import (
     link_document_smart_link_instance_list, link_smart_link_list,
     link_smart_link_setup
 )
+from .methods import (
+    method_document_type_smart_links_add,
+    method_document_type_smart_links_remove
+)
 from .permissions import (
     permission_resolved_smart_link_view, permission_smart_link_delete,
     permission_smart_link_edit, permission_smart_link_view
@@ -54,6 +58,15 @@ class LinkingApp(MayanAppConfig):
         SmartLink = self.get_model(model_name='SmartLink')
         SmartLinkCondition = self.get_model(model_name='SmartLinkCondition')
 
+        DocumentType.add_to_class(
+            name='smart_links_add',
+            value=method_document_type_smart_links_add
+        )
+        DocumentType.add_to_class(
+            name='smart_links_remove',
+            value=method_document_type_smart_links_remove
+        )
+
         DynamicSerializerField.add_serializer(
             klass=SmartLink,
             serializer_class='mayan.apps.linking.serializers.SmartLinkSerializer'
@@ -168,7 +181,8 @@ class LinkingApp(MayanAppConfig):
         menu_list_facet.bind_links(
             exclude=(ResolvedSmartLink,),
             links=(
-                link_smart_link_document_types, link_smart_link_condition_list
+                link_smart_link_document_types,
+                link_smart_link_condition_list
             ), sources=(SmartLink,)
         )
 
@@ -216,4 +230,6 @@ class LinkingApp(MayanAppConfig):
 
         # Setup
 
-        menu_setup.bind_links(links=(link_smart_link_setup,))
+        menu_setup.bind_links(
+            links=(link_smart_link_setup,)
+        )
