@@ -2,7 +2,9 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.permissions import PermissionNamespace
 
-namespace = PermissionNamespace(label=_('Smart links'), name='linking')
+namespace = PermissionNamespace(
+    label=_('Smart links'), name='linking'
+)
 
 permission_resolved_smart_link_view = namespace.add_permission(
     label=_('View resolved smart links'), name='resolved_smart_link_view'
