@@ -2,9 +2,12 @@ from pytz import common_timezones
 
 from django.conf import settings
 from django.db import models
-from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.events.classes import EventManagerSave
+from mayan.apps.events.decorators import method_event
+
+from .events import event_user_locale_profile_edited
 from .managers import UserLocaleProfileManager
 
 
@@ -32,8 +35,20 @@ class UserLocaleProfile(models.Model):
         verbose_name_plural = _('User locale profiles')
 
     def __str__(self):
-        return force_text(s=self.user)
+        return '{} ({}, {})'.format(
+            self.user, self.language or _('None'), self.timezone or _('None')
+        )
 
     def natural_key(self):
         return self.user.natural_key()
     natural_key.dependencies = [settings.AUTH_USER_MODEL]
+
+    @method_event(
+        event_manager_class=EventManagerSave,
+        edited={
+            'event': event_user_locale_profile_edited,
+            'target': 'user'
+        }
+    )
+    def save(self, *args, **kwargs):
+        return super().save(*args, **kwargs)
