@@ -14,13 +14,13 @@ class APIErrorLogPartitionEntryListView(
     get: Returns a list of all the object's error log entries
     """
     mayan_external_object_permissions = {
-        'GET': (permission_error_log_entry_view,),
+        'GET': (permission_error_log_entry_view,)
     }
     ordering_fields = ('id', 'datetime')
     serializer_class = ErrorLogPartitionEntrySerializer
 
-    def get_queryset(self):
-        return self.external_object.error_log.all()
+    def get_source_queryset(self):
+        return self.get_external_object().error_log.all()
 
 
 class APIErrorLogPartitionEntryDetailView(
@@ -42,5 +42,5 @@ class APIErrorLogPartitionEntryDetailView(
             '_event_actor': self.request.user
         }
 
-    def get_queryset(self):
-        return self.external_object.error_log.all()
+    def get_source_queryset(self):
+        return self.get_external_object().error_log.all()
