@@ -3,7 +3,7 @@ from django.db import migrations, models
 
 class Migration(migrations.Migration):
     dependencies = [
-        ('mailer', '0003_auto_20170703_1535'),
+        ('mailer', '0003_auto_20170703_1535')
     ]
 
     operations = [
@@ -14,6 +14,6 @@ class Migration(migrations.Migration):
                 default=True, help_text='If default, this mailing profile '
                 'will be pre-selected on the document mailing form.',
                 verbose_name='Default'
-            ),
+            )
         ),
     ]
