@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 TEST_EMAIL_ADDRESS = 'test@example.com'
 TEST_EMAIL_BODY = 'test body'
 TEST_EMAIL_BODY_HTML = '<strong>test body</strong>'
@@ -17,5 +15,4 @@ TEST_RECIPIENTS_MULTIPLE_MIXED = 'test@example.com,test2@example.com;test2@examp
 TEST_RECIPIENTS_MULTIPLE_MIXED_RESULT = [
     'test@example.com', 'test2@example.com', 'test2@example.com'
 ]
-TEST_USER_MAILER_BACKEND_PATH = 'mayan.apps.mailer.tests.mailers.TestBackend'
 TEST_USER_MAILER_LABEL = 'test user mailer label'
