@@ -12,18 +12,18 @@ from .literals import TEST_EMAIL_ADDRESS, TEST_EMAIL_FROM_ADDRESS
 from .mixins import DocumentVersionMailerViewTestMixin, MailerTestMixin
 
 
-class MailDocumentVersionViewsTestCase(
+class MailDocumentVersionViewTestCase(
     DocumentVersionMailerViewTestMixin, MailerTestMixin,
     GenericDocumentViewTestCase
 ):
-    def test_document_version_send_link_single_view_no_permission(self):
+    def test_document_version_link_send_single_view_no_permission(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_single_view()
+        response = self._request_test_document_version_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -31,19 +31,19 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_single_view_with_document_access(self):
+    def test_document_version_link_send_single_view_with_document_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_single_view()
+        response = self._request_test_document_version_link_send_single_view()
         self.assertEqual(response.status_code, 200)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -51,7 +51,7 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_single_view_with_mailer_access(self):
+    def test_document_version_link_send_single_view_with_mailer_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
@@ -62,7 +62,7 @@ class MailDocumentVersionViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_single_view()
+        response = self._request_test_document_version_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -70,13 +70,13 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_single_view_with_full_access(self):
+    def test_document_version_link_send_single_view_with_full_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
         self.grant_access(
@@ -85,7 +85,7 @@ class MailDocumentVersionViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_single_view()
+        response = self._request_test_document_version_link_send_single_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(len(mail.outbox), mail_messages + 1)
@@ -95,29 +95,29 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
 
-    def test_trashed_document_version_send_link_single_view_with_full_access(self):
+    def test_trashed_document_version_link_send_single_view_with_full_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_single_view()
+        response = self._request_test_document_version_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -125,14 +125,14 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_multiple_view_no_permission(self):
+    def test_document_version_link_send_multiple_view_no_permission(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_multiple_view()
+        response = self._request_test_document_version_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -140,19 +140,19 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_multiple_view_with_document_access(self):
+    def test_document_version_link_send_multiple_view_with_document_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_multiple_view()
+        response = self._request_test_document_version_link_send_multiple_view()
         self.assertEqual(response.status_code, 200)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -160,7 +160,7 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_multiple_view_with_mailer_access(self):
+    def test_document_version_link_send_multiple_view_with_mailer_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
@@ -171,7 +171,7 @@ class MailDocumentVersionViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_multiple_view()
+        response = self._request_test_document_version_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -179,13 +179,13 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_send_link_multiple_view_with_full_access(self):
+    def test_document_version_link_send_multiple_view_with_full_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
         self.grant_access(
@@ -194,7 +194,7 @@ class MailDocumentVersionViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_multiple_view()
+        response = self._request_test_document_version_link_send_multiple_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(len(mail.outbox), mail_messages + 1)
@@ -204,29 +204,29 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
 
-    def test_trashed_document_version_send_link_multiple_view_with_full_access(self):
+    def test_trashed_document_version_link_send_multiple_view_with_full_access(self):
         self._create_test_user_mailer()
 
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_link
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_send_link_multiple_view()
+        response = self._request_test_document_version_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -255,7 +255,7 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
 
@@ -294,7 +294,7 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
         self.grant_access(
@@ -314,7 +314,7 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
@@ -325,14 +325,14 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -365,7 +365,7 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
 
@@ -404,7 +404,7 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
         self.grant_access(
@@ -424,7 +424,7 @@ class MailDocumentVersionViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
@@ -435,14 +435,14 @@ class MailDocumentVersionViewsTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_version_attachment
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
