@@ -27,7 +27,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_single_view()
+        response = self._request_test_document_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -41,13 +41,13 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_single_view()
+        response = self._request_test_document_link_send_single_view()
         self.assertEqual(response.status_code, 200)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -66,7 +66,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_single_view()
+        response = self._request_test_document_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -80,7 +80,7 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
         self.grant_access(
@@ -89,7 +89,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_single_view()
+        response = self._request_test_document_link_send_single_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(len(mail.outbox), mail_messages + 1)
@@ -99,7 +99,7 @@ class MailDocumentViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
@@ -110,18 +110,18 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_single_view()
+        response = self._request_test_document_link_send_single_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -136,7 +136,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_multiple_view()
+        response = self._request_test_document_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -150,13 +150,13 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_multiple_view()
+        response = self._request_test_document_link_send_multiple_view()
         self.assertEqual(response.status_code, 200)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -175,7 +175,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_multiple_view()
+        response = self._request_test_document_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
@@ -189,7 +189,7 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
         self.grant_access(
@@ -198,7 +198,7 @@ class MailDocumentViewTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_multiple_view()
+        response = self._request_test_document_link_send_multiple_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(len(mail.outbox), mail_messages + 1)
@@ -208,7 +208,7 @@ class MailDocumentViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, self._test_user_mailer)
         self.assertEqual(events[0].verb, event_email_sent.id)
@@ -219,18 +219,18 @@ class MailDocumentViewTestCase(
         mail_messages = len(mail.outbox)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_send_document_link
         )
         self.grant_access(
             obj=self._test_user_mailer, permission=permission_user_mailer_use
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_send_link_multiple_view()
+        response = self._request_test_document_link_send_multiple_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(len(mail.outbox), mail_messages)
