@@ -1,4 +1,5 @@
-from mayan.apps.documents.literals import DOCUMENT_VERSION_EXPORT_MIMETYPE
+from mayan.apps.document_exports.classes import DocumentVersionExporter
+from mayan.apps.document_exports.literals import DOCUMENT_VERSION_EXPORT_MIMETYPE
 from mayan.apps.storage.utils import NamedTemporaryFile
 
 from .literals import EMAIL_SEPARATORS
@@ -14,7 +15,9 @@ def split_recipient_list(recipients, separator_list=None, separator_index=0):
     else:
         result = []
         for recipient in recipients:
-            result.extend(recipient.split(separator))
+            result.extend(
+                recipient.split(separator)
+            )
 
         return split_recipient_list(
             recipients=result, separator_list=separator_list,
@@ -37,7 +40,10 @@ def get_document_version_content(obj):
 
         def __enter__(self):
             self.file_object = NamedTemporaryFile(delete=False)
-            obj.export(file_object=self.file_object)
+            document_version_exporter = DocumentVersionExporter(
+                document_version=obj
+            )
+            document_version_exporter.export(file_object=self.file_object)
             self.file_object.seek(0)
             return self.file_object
 
