@@ -1,15 +1,18 @@
 from django.apps import apps
-from django.utils.encoding import force_text
 from django.utils.translation import ugettext_lazy as _
 
 from celery.schedules import crontab
 
+from mayan.apps.common.class_mixins import AppsModuleLoaderMixin
 from mayan.celery import app
 
-from .renderers import ChartJSLine
+from .renderers import (
+    RendererChartJSDoughnut, RendererChartJSLine, RendererChartJSPie
+)
 
 
-class StatisticNamespace:
+class StatisticNamespace(AppsModuleLoaderMixin):
+    _loader_module_name = 'statistics'
     _registry = {}
 
     @classmethod
@@ -27,7 +30,7 @@ class StatisticNamespace:
         self.__class__._registry[slug] = self
 
     def __str__(self):
-        return force_text(s=self.label)
+        return str(self.label)
 
     def add_statistic(self, klass, *args, **kwargs):
         statistic = klass(*args, **kwargs)
@@ -39,7 +42,10 @@ class StatisticNamespace:
         return self._statistics
 
 
-class Statistic:
+StatisticNamespace.verbose_name = _('Statistics namespace')
+
+
+class StatisticType:
     _registry = {}
     renderer = None
 
@@ -47,7 +53,9 @@ class Statistic:
     def evaluate(data):
         try:
             for key, value in data.items():
-                return {key: Statistic.evaluate(data=value)}
+                return {
+                    key: StatisticType.evaluate(data=value)
+                }
         except AttributeError:
             if type(data) == map:
                 data = list(data)
@@ -65,7 +73,9 @@ class Statistic:
 
         queryset = PeriodicTask.objects.filter(
             name__startswith='mayan_statistics.'
-        ).exclude(name__in=Statistic.get_task_names())
+        ).exclude(
+            name__in=StatisticType.get_task_names()
+        )
 
         for periodic_task in queryset:
             crontab_instance = periodic_task.crontab
@@ -89,9 +99,15 @@ class Statistic:
 
     @classmethod
     def get_task_names(cls):
-        return [task.get_task_name() for task in cls.get_all()]
+        return [
+            task.get_task_name() for task in cls.get_all()
+        ]
 
-    def __init__(self, slug, label, func, minute='*', hour='*', day_of_week='*', day_of_month='*', month_of_year='*'):
+    def __init__(
+        self, func, label, slug, day_of_month='*', day_of_week='*',
+        hour='*', minute='*', month_of_year='*'
+    ):
+        # Hidden import.
         from .queues import queue_statistics, task_execute_statistic
 
         self.slug = slug
@@ -99,8 +115,8 @@ class Statistic:
         self.func = func
 
         self.schedule = crontab(
-            minute=minute, hour=hour, day_of_week=day_of_week,
-            day_of_month=day_of_month, month_of_year=month_of_year,
+            day_of_month=day_of_month, day_of_week=day_of_week, hour=hour,
+            minute=minute, month_of_year=month_of_year
         )
 
         app.conf.beat_schedule.update(
@@ -117,25 +133,25 @@ class Statistic:
             {
                 self.get_task_name(): {
                     'queue': queue_statistics.name
-                },
+                }
             }
         )
 
         self.__class__._registry[slug] = self
 
     def __str__(self):
-        return force_text(s=self.label)
+        return str(self.label)
 
     def execute(self):
         results = self.func()
-        # Force evaluation of results to be able to store it serialized
-        # Needed for Python 3
-        # PY3
-        results = Statistic.evaluate(data=results)
+        # Force evaluation of results to be able to store it serialized.
+        results = StatisticType.evaluate(data=results)
         self.store_results(results=results)
 
-    def get_chart_data(self):
-        return self.renderer(data=self.get_results_data()).get_chart_data()
+    def get_chart_context(self):
+        return self.renderer(
+            data=self.get_results_data()
+        ).get_chart_context()
 
     def get_last_update(self):
         results = self.get_results()
@@ -166,7 +182,9 @@ class Statistic:
         if results:
             return results.get_data()
         else:
-            return {'series': {}}
+            return {
+                'series': {}
+            }
 
     def get_task_name(self):
         return 'mayan_statistics.task_execute_statistic_{}'.format(self.slug)
@@ -184,5 +202,16 @@ class Statistic:
         statistic_result.store_data(data=results)
 
 
-class StatisticLineChart(Statistic):
-    renderer = ChartJSLine
+class StatisticTypeDoughnutChart(StatisticType):
+    renderer = RendererChartJSDoughnut
+    type_label = _('Doughnut chart')
+
+
+class StatisticTypeLineChart(StatisticType):
+    renderer = RendererChartJSLine
+    type_label = _('Line chart')
+
+
+class StatisticTypePieChart(StatisticType):
+    renderer = RendererChartJSPie
+    type_label = _('Pie chart')
