@@ -1,6 +1,6 @@
 from mayan.apps.testing.tests.base import GenericViewTestCase
 
-from ..classes import Statistic
+from ..classes import StatisticType
 from ..permissions import permission_statistics_view
 
 from .mixins import StatisticsViewTestMixin
@@ -8,7 +8,7 @@ from .mixins import StatisticsViewTestMixin
 
 class StatisticsViewTestCase(StatisticsViewTestMixin, GenericViewTestCase):
     def test_statistic_detail_view_no_permission(self):
-        self.statistic = Statistic.get_all()[0]
+        self.statistic = StatisticType.get_all()[0]
 
         response = self._request_test_statistic_detail_view()
         self.assertEqual(response.status_code, 403)
@@ -16,7 +16,7 @@ class StatisticsViewTestCase(StatisticsViewTestMixin, GenericViewTestCase):
     def test_statistic_detail_view_with_permissions(self):
         self.grant_permission(permission=permission_statistics_view)
 
-        self.statistic = Statistic.get_all()[0]
+        self.statistic = StatisticType.get_all()[0]
 
         response = self._request_test_statistic_detail_view()
         self.assertEqual(response.status_code, 200)
