@@ -7,4 +7,9 @@ class MessageModelTestCase(MessageTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_message()
 
+        self._clear_events()
+
         self.assertTrue(self._test_message.get_absolute_url())
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
