@@ -27,7 +27,9 @@ class MetadataTypeManager(models.Manager):
 
 
 class DocumentTypeMetadataTypeManager(models.Manager):
-    def get_by_natural_key(self, document_natural_key, metadata_type_natural_key):
+    def get_by_natural_key(
+        self, document_natural_key, metadata_type_natural_key
+    ):
         Document = apps.get_model(
             app_label='documents', model_name='Document'
         )
@@ -35,7 +37,9 @@ class DocumentTypeMetadataTypeManager(models.Manager):
             app_label='metadata', model_name='MetadataType'
         )
         try:
-            document = Document.objects.get_by_natural_key(document_natural_key)
+            document = Document.objects.get_by_natural_key(
+                document_natural_key
+            )
         except Document.DoesNotExist:
             raise self.model.DoesNotExist
         else:
@@ -44,7 +48,9 @@ class DocumentTypeMetadataTypeManager(models.Manager):
             except MetadataType.DoesNotExist:
                 raise self.model.DoesNotExist
 
-        return self.get(document__pk=document.pk, metadata_type__pk=metadata_type.pk)
+        return self.get(
+            document__pk=document.pk, metadata_type__pk=metadata_type.pk
+        )
 
     def get_metadata_types_for(self, document_type):
         DocumentType = apps.get_model(
