@@ -1,7 +1,7 @@
 from django.db.models import Q
 from django.urls import reverse
 
-from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+from mayan.apps.documents.tests.literals import TEST_FILE_SMALL_PATH
 from mayan.apps.views.http import URL
 
 from ..models import DocumentMetadata, DocumentTypeMetadataType, MetadataType
@@ -18,22 +18,22 @@ class DocumentMetadataAPIViewTestMixin:
         pk_list = list(DocumentMetadata.objects.values_list('pk', flat=True))
 
         data = {
-            'metadata_type_id': self.test_metadata_type.pk,
+            'metadata_type_id': self._test_metadata_type.pk,
             'value': TEST_METADATA_VALUE
         }
         data.update(extra_data or {})
 
         response = self.post(
             viewname='rest_api:documentmetadata-list',
-            kwargs={'document_id': self.test_document.pk}, data=data
+            kwargs={'document_id': self._test_document.pk}, data=data
         )
 
         try:
-            self.test_document_metadata = DocumentMetadata.objects.get(
+            self._test_document_metadata = DocumentMetadata.objects.get(
                 ~Q(pk__in=pk_list)
             )
         except DocumentMetadata.DoesNotExist:
-            self.test_document_metadata = None
+            self._test_document_metadata = None
 
         return response
 
@@ -41,8 +41,8 @@ class DocumentMetadataAPIViewTestMixin:
         return self.delete(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_id': self.test_document.pk,
-                'metadata_id': self.test_document_metadata.pk
+                'document_id': self._test_document.pk,
+                'metadata_id': self._test_document_metadata.pk
             }
         )
 
@@ -55,8 +55,8 @@ class DocumentMetadataAPIViewTestMixin:
         return self.patch(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_id': self.test_document.pk,
-                'metadata_id': self.test_document_metadata.pk
+                'document_id': self._test_document.pk,
+                'metadata_id': self._test_document_metadata.pk
             }, data=data
         )
 
@@ -69,23 +69,23 @@ class DocumentMetadataAPIViewTestMixin:
         return self.put(
             viewname='rest_api:documentmetadata-detail',
             kwargs={
-                'document_id': self.test_document.pk,
-                'metadata_id': self.test_document_metadata.pk
+                'document_id': self._test_document.pk,
+                'metadata_id': self._test_document_metadata.pk
             }, data=data
         )
 
     def _request_document_metadata_list_api_view(self):
         return self.get(
             viewname='rest_api:documentmetadata-list', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
 
 
 class DocumentMetadataMixin:
     def _create_test_document_metadata(self):
-        self.test_document_metadata = self.test_document.metadata.create(
-            metadata_type=self.test_metadata_type, value=TEST_METADATA_VALUE
+        self._test_document_metadata = self._test_document.metadata.create(
+            metadata_type=self._test_metadata_type, value=TEST_METADATA_VALUE
         )
 
 
@@ -93,24 +93,24 @@ class DocumentMetadataViewTestMixin:
     def _request_test_document_metadata_add_get_view(self):
         return self.get(
             viewname='metadata:metadata_add', kwargs={
-                'document_id': self.test_document.pk
-            }, data={'metadata_type': self.test_metadata_type.pk}
+                'document_id': self._test_document.pk
+            }, data={'metadata_type': self._test_metadata_type.pk}
         )
 
     def _request_test_document_metadata_add_post_view(self):
         return self.post(
             viewname='metadata:metadata_add', kwargs={
-                'document_id': self.test_document.pk
-            }, data={'metadata_type': self.test_metadata_type.pk}
+                'document_id': self._test_document.pk
+            }, data={'metadata_type': self._test_metadata_type.pk}
         )
 
     def _request_test_document_metadata_multiple_add_post_view(self):
         return self.post(
             viewname='metadata:metadata_add', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data={
                 'metadata_type': [
-                    metadata_type.pk for metadata_type in self.test_metadata_types
+                    metadata_type.pk for metadata_type in self._test_metadata_types
                 ],
             }
         )
@@ -119,7 +119,7 @@ class DocumentMetadataViewTestMixin:
         self, extra_data=None, follow=False
     ):
         data = {
-            'form-0-metadata_type_id': self.test_metadata_type.pk,
+            'form-0-metadata_type_id': self._test_metadata_type.pk,
             'form-0-update': True,
             'form-0-value': TEST_METADATA_VALUE_EDITED,
             'form-TOTAL_FORMS': '1',
@@ -132,29 +132,29 @@ class DocumentMetadataViewTestMixin:
 
         return self.post(
             viewname='metadata:metadata_edit', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data=data, follow=follow
         )
 
     def _request_test_document_metadata_list_view(self):
         return self.get(
-            viewname='metadata:metadata_view', kwargs={
-                'document_id': self.test_document.pk
+            viewname='metadata:metadata_list', kwargs={
+                'document_id': self._test_document.pk
             }
         )
 
     def _request_test_document_metadata_remove_get_view(self):
         return self.get(
             viewname='metadata:metadata_remove', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
 
     def _request_test_document_metadata_remove_post_view(self, index=0):
         return self.post(
             viewname='metadata:metadata_remove',
-            kwargs={'document_id': self.test_document.pk}, data={
-                'form-0-metadata_type_id': self.test_metadata_types[index].pk,
+            kwargs={'document_id': self._test_document.pk}, data={
+                'form-0-metadata_type_id': self._test_metadata_types[index].pk,
                 'form-0-update': True,
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
@@ -166,9 +166,9 @@ class DocumentMetadataViewTestMixin:
         return self.post(
             viewname='metadata:metadata_multiple_add', data={
                 'id_list': '{},{}'.format(
-                    self.test_documents[0].pk, self.test_documents[1].pk
+                    self._test_documents[0].pk, self._test_documents[1].pk
                 ),
-                'metadata_type': self.test_metadata_type.pk
+                'metadata_type': self._test_metadata_type.pk
             }
         )
 
@@ -176,7 +176,7 @@ class DocumentMetadataViewTestMixin:
         return self.get(
             viewname='metadata:metadata_multiple_edit', data={
                 'id_list': '{},{}'.format(
-                    self.test_documents[0].pk, self.test_documents[1].pk
+                    self._test_documents[0].pk, self._test_documents[1].pk
                 )
             }
         )
@@ -185,9 +185,9 @@ class DocumentMetadataViewTestMixin:
         return self.post(
             viewname='metadata:metadata_multiple_edit', data={
                 'id_list': '{},{}'.format(
-                    self.test_documents[0].pk, self.test_documents[1].pk
+                    self._test_documents[0].pk, self._test_documents[1].pk
                 ),
-                'form-0-metadata_type_id': self.test_metadata_type.pk,
+                'form-0-metadata_type_id': self._test_metadata_type.pk,
                 'form-0-update': True,
                 'form-0-value': TEST_METADATA_VALUE_EDITED,
                 'form-TOTAL_FORMS': '1',
@@ -200,7 +200,7 @@ class DocumentMetadataViewTestMixin:
         return self.get(
             viewname='metadata:metadata_multiple_remove', data={
                 'id_list': '{},{}'.format(
-                    self.test_documents[0].pk, self.test_documents[0].pk
+                    self._test_documents[0].pk, self._test_documents[0].pk
                 )
             }
         )
@@ -209,9 +209,9 @@ class DocumentMetadataViewTestMixin:
         return self.post(
             viewname='metadata:metadata_multiple_remove', data={
                 'id_list': '{},{}'.format(
-                    self.test_documents[0].pk, self.test_documents[1].pk
+                    self._test_documents[0].pk, self._test_documents[1].pk
                 ),
-                'form-0-metadata_type_id': self.test_metadata_type.pk,
+                'form-0-metadata_type_id': self._test_metadata_type.pk,
                 'form-0-update': True,
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
@@ -226,18 +226,18 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
 
         response = self.post(
             viewname='rest_api:documenttypemetadatatype-list',
-            kwargs={'document_type_id': self.test_document_type.pk}, data={
-                'metadata_type_id': self.test_metadata_type.pk,
+            kwargs={'document_type_id': self._test_document_type.pk}, data={
+                'metadata_type_id': self._test_metadata_type.pk,
                 'required': False
             }
         )
 
         try:
-            self.test_document_type_metadata_type = DocumentTypeMetadataType.objects.get(
+            self._test_document_type_metadata_type = DocumentTypeMetadataType.objects.get(
                 ~Q(pk__in=pk_list)
             )
         except DocumentTypeMetadataType.DoesNotExist:
-            self.test_document_type_metadata_type = None
+            self._test_document_type_metadata_type = None
 
         return response
 
@@ -245,15 +245,15 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
         return self.delete(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_id': self.test_document_type.pk,
-                'metadata_type_id': self.test_document_type_metadata_type.pk
+                'document_type_id': self._test_document_type.pk,
+                'metadata_type_id': self._test_document_type_metadata_type.pk
             }
         )
 
     def _request_document_type_metadata_type_list_api_view(self):
         return self.get(
             viewname='rest_api:documenttypemetadatatype-list', kwargs={
-                'document_type_id': self.test_document_type.pk
+                'document_type_id': self._test_document_type.pk
             }
         )
 
@@ -261,8 +261,8 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
         return self.patch(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_id': self.test_document_type.pk,
-                'metadata_type_id': self.test_document_type_metadata_type.pk
+                'document_type_id': self._test_document_type.pk,
+                'metadata_type_id': self._test_document_type_metadata_type.pk
             }, data={
                 'required': True
             }
@@ -272,8 +272,8 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
         return self.put(
             viewname='rest_api:documenttypemetadatatype-detail',
             kwargs={
-                'document_type_id': self.test_document_type.pk,
-                'metadata_type_id': self.test_document_type_metadata_type.pk
+                'document_type_id': self._test_document_type.pk,
+                'metadata_type_id': self._test_document_type_metadata_type.pk
             }, data={
                 'required': True
             }
@@ -282,8 +282,8 @@ class DocumentTypeMetadataTypeAPIViewTestMixin:
 
 class DocumentTypeMetadataTypeTestMixin:
     def _create_test_document_type_metadata_type(self):
-        self.test_document_type_metadata_type = self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type, required=False
+        self._test_document_type_metadata_type = self._test_document_type.metadata.create(
+            metadata_type=self._test_metadata_type, required=False
         )
 
 
@@ -294,21 +294,21 @@ class MetadataDocumentUploadWizardStepTestMixin:
         url = URL(
             path=reverse(viewname='sources:document_upload_interactive')
         )
-        url.args['metadata0_metadata_type_id'] = self.test_metadata_type.pk
+        url.args['metadata0_metadata_type_id'] = self._test_metadata_type.pk
         url.args['metadata0_value'] = metadata_value
 
-        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_FILE_SMALL_PATH, mode='rb') as file_object:
             return self.post(
                 path=url.to_string(), data={
                     'document-language': 'eng', 'source-file': file_object,
-                    'document_type_id': self.test_document_type.pk,
+                    'document_type_id': self._test_document_type.pk,
                 }
             )
 
     def _request_document_create_view(self):
         return self.post(
             viewname='sources:document_create_multiple', data={
-                'document_type_selection-document_type': self.test_document_type.pk,
+                'document_type_selection-document_type': self._test_document_type.pk,
                 'document_create_wizard-current_step': 0
             }
         )
@@ -325,41 +325,41 @@ class MetadataTypeAPIViewTestMixin:
         )
 
         try:
-            self.test_metadata_type = MetadataType.objects.get(
+            self._test_metadata_type = MetadataType.objects.get(
                 ~Q(pk__in=pk_list)
             )
         except MetadataType.DoesNotExist:
-            self.test_metadata_type = None
+            self._test_metadata_type = None
 
         return response
 
     def _request_test_metadata_type_delete_api_view(self):
         return self.delete(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}
         )
 
     def _request_test_metadata_type_detail_api_view(self):
         return self.get(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}
         )
 
     def _request_test_metadata_type_edit_api_view_via_patch(self):
         return self.patch(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
-                'label': '{} edited'.format(self.test_metadata_type.label),
-                'name': '{}_edited'.format(self.test_metadata_type.name),
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}, data={
+                'label': '{} edited'.format(self._test_metadata_type.label),
+                'name': '{}_edited'.format(self._test_metadata_type.name),
             }
         )
 
     def _request_test_metadata_type_edit_api_view_via_put(self):
         return self.put(
             viewname='rest_api:metadatatype-detail',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
-                'label': '{} edited'.format(self.test_metadata_type.label),
-                'name': '{}_edited'.format(self.test_metadata_type.name),
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}, data={
+                'label': '{} edited'.format(self._test_metadata_type.label),
+                'name': '{}_edited'.format(self._test_metadata_type.name),
             }
         )
 
@@ -368,22 +368,30 @@ class MetadataTypeAPIViewTestMixin:
 
 
 class MetadataTypeTestMixin:
+    auto_add_test_metadata_type_to_test_document_type = True
+    auto_create_test_metadata_type = False
+
     def setUp(self):
         super().setUp()
-        self.test_metadata_types = []
+        self._test_metadata_types = []
         self._test_document_type_metadata_type_relationships = []
 
+        if self.auto_create_test_metadata_type:
+            self._create_test_metadata_type(
+                add_test_document_type=self.auto_add_test_metadata_type_to_test_document_type
+            )
+
     def _get_test_metadata_type_queryset(self):
         return MetadataType.objects.filter(
             pk__in=[
-                metadata_type.pk for metadata_type in self.test_metadata_types
+                metadata_type.pk for metadata_type in self._test_metadata_types
             ]
         )
 
     def _create_test_metadata_type(
         self, add_test_document_type=False, extra_kwargs=None, required=False
     ):
-        total_test_metadata_types = len(self.test_metadata_types)
+        total_test_metadata_types = len(self._test_metadata_types)
         name = '{}_{}'.format(
             TEST_METADATA_TYPE_NAME, total_test_metadata_types
         )
@@ -396,13 +404,13 @@ class MetadataTypeTestMixin:
         if extra_kwargs:
             kwargs.update(extra_kwargs)
 
-        self.test_metadata_type = MetadataType.objects.create(**kwargs)
-        self.test_metadata_types.append(self.test_metadata_type)
+        self._test_metadata_type = MetadataType.objects.create(**kwargs)
+        self._test_metadata_types.append(self._test_metadata_type)
 
         if add_test_document_type:
             self._test_document_type_metadata_type_relationships.append(
-                self.test_document_type.metadata.create(
-                    metadata_type=self.test_metadata_type, required=required
+                self._test_document_type.metadata.create(
+                    metadata_type=self._test_metadata_type, required=required
                 )
             )
 
@@ -414,7 +422,7 @@ class MetadataTypeViewTestMixin:
 
         return self.post(
             viewname='metadata:document_type_metadata_type_relationship',
-            kwargs={'document_type_id': self.test_document_type.pk}, data={
+            kwargs={'document_type_id': self._test_document_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
                 'form-0-relationship_type': 'none'
@@ -427,7 +435,7 @@ class MetadataTypeViewTestMixin:
 
         return self.post(
             viewname='metadata:document_type_metadata_type_relationship',
-            kwargs={'document_type_id': self.test_document_type.pk}, data={
+            kwargs={'document_type_id': self._test_document_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
                 'form-0-relationship_type': 'required'
@@ -444,32 +452,32 @@ class MetadataTypeViewTestMixin:
         )
 
         try:
-            self.test_metadata_type = MetadataType.objects.get(
+            self._test_metadata_type = MetadataType.objects.get(
                 ~Q(pk__in=pk_list)
             )
         except MetadataType.DoesNotExist:
-            self.test_metadata_type = None
+            self._test_metadata_type = None
 
         return response
 
-    def _request_test_metadata_type_delete_single_view(self):
+    def _request_test_metadata_type_single_delete_view(self):
         return self.post(
-            viewname='metadata:metadata_type_delete_single', kwargs={
-                'metadata_type_id': self.test_metadata_type.pk
+            viewname='metadata:metadata_type_single_delete', kwargs={
+                'metadata_type_id': self._test_metadata_type.pk
             }
         )
 
-    def _request_test_metadata_type_delete_multiple_view(self):
+    def _request_test_metadata_type_multiple_delete_view(self):
         return self.post(
-            viewname='metadata:metadata_type_delete_multiple', data={
-                'id_list': self.test_metadata_type.pk
+            viewname='metadata:metadata_type_multiple_delete', data={
+                'id_list': self._test_metadata_type.pk
             }
         )
 
     def _request_test_metadata_type_edit_view(self):
         return self.post(
             viewname='metadata:metadata_type_edit', kwargs={
-                'metadata_type_id': self.test_metadata_type.pk
+                'metadata_type_id': self._test_metadata_type.pk
             }, data={
                 'label': TEST_METADATA_TYPE_LABEL_EDITED,
                 'name': TEST_METADATA_TYPE_NAME_EDITED
@@ -487,7 +495,7 @@ class MetadataTypeViewTestMixin:
 
         return self.post(
             viewname='metadata:metadata_type_document_type_relationship',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
                 'form-0-relationship_type': 'none'
@@ -500,7 +508,7 @@ class MetadataTypeViewTestMixin:
 
         return self.post(
             viewname='metadata:metadata_type_document_type_relationship',
-            kwargs={'metadata_type_id': self.test_metadata_type.pk}, data={
+            kwargs={'metadata_type_id': self._test_metadata_type.pk}, data={
                 'form-TOTAL_FORMS': '1',
                 'form-INITIAL_FORMS': '0',
                 'form-0-relationship_type': 'required'
