@@ -36,8 +36,8 @@ class DocumentMetadataActionTestCase(
         super().setUp()
         self._create_test_document_stub()
         self._create_test_metadata_type()
-        self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type
+        self._test_document_type.metadata.create(
+            metadata_type=self._test_metadata_type
         )
 
     def test_document_metadata_add_action(self):
@@ -45,27 +45,27 @@ class DocumentMetadataActionTestCase(
             form_data={'metadata_types': MetadataType.objects.all()}
         )
 
-        metadata_count = self.test_document.metadata.count()
+        metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
         self.assertEqual(
-            self.test_document.metadata.count(), metadata_count + 1
+            self._test_document.metadata.count(), metadata_count + 1
         )
         self.assertTrue(
-            self.test_document.metadata.filter(
-                metadata_type=self.test_metadata_type
+            self._test_document.metadata.filter(
+                metadata_type=self._test_metadata_type
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_added.id)
 
     def test_document_metadata_edit_action(self):
@@ -73,27 +73,27 @@ class DocumentMetadataActionTestCase(
 
         action = DocumentMetadataEditAction(
             form_data={
-                'metadata_type': self.test_metadata_type.pk,
+                'metadata_type': self._test_metadata_type.pk,
                 'value': TEST_METADATA_VALUE_EDITED
             }
         )
 
-        metadata_value = self.test_document.metadata.first().value
+        metadata_value = self._test_document.metadata.first().value
 
         self._clear_events()
 
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
         self.assertNotEqual(
-            metadata_value, self.test_document.metadata.first().value
+            metadata_value, self._test_document.metadata.first().value
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_edited.id)
 
     def test_document_metadata_remove_action(self):
@@ -103,27 +103,27 @@ class DocumentMetadataActionTestCase(
             form_data={'metadata_types': MetadataType.objects.all()}
         )
 
-        metadata_count = self.test_document.metadata.count()
+        metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
         self.assertEqual(
-            self.test_document.metadata.count(), metadata_count - 1
+            self._test_document.metadata.count(), metadata_count - 1
         )
         self.assertFalse(
-            self.test_document.metadata.filter(
-                metadata_type=self.test_metadata_type
+            self._test_document.metadata.filter(
+                metadata_type=self._test_metadata_type
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_removed.id)
 
 
@@ -140,11 +140,11 @@ class DocumentMetadataActionViewTestCase(
         self._create_test_workflow_template()
         self._create_test_workflow_template_state()
         self._create_test_metadata_type()
-        self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type
+        self._test_document_type.metadata.create(
+            metadata_type=self._test_metadata_type
         )
         self._test_workflow_template.document_types.add(
-            self.test_document_type
+            self._test_document_type
         )
 
     def test_document_metadata_add_action_create_view(self):
@@ -153,7 +153,7 @@ class DocumentMetadataActionViewTestCase(
             permission=permission_workflow_template_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_add
         )
 
@@ -161,7 +161,7 @@ class DocumentMetadataActionViewTestCase(
 
         response = self._request_test_workflow_template_state_action_create_post_view(
             class_path=DOCUMENT_METADATA_ADD_ACTION_CLASS_PATH, extra_data={
-                'metadata_types': self.test_metadata_type.pk
+                'metadata_types': self._test_metadata_type.pk
             }
         )
         self.assertEqual(response.status_code, 302)
@@ -185,7 +185,7 @@ class DocumentMetadataActionViewTestCase(
             permission=permission_workflow_template_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
@@ -193,7 +193,7 @@ class DocumentMetadataActionViewTestCase(
 
         response = self._request_test_workflow_template_state_action_create_post_view(
             class_path=DOCUMENT_METADATA_EDIT_ACTION_CLASS_PATH, extra_data={
-                'metadata_type': self.test_metadata_type.pk,
+                'metadata_type': self._test_metadata_type.pk,
                 'value': TEST_METADATA_VALUE
             }
         )
@@ -218,7 +218,7 @@ class DocumentMetadataActionViewTestCase(
             permission=permission_workflow_template_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_remove
         )
 
@@ -227,7 +227,7 @@ class DocumentMetadataActionViewTestCase(
         response = self._request_test_workflow_template_state_action_create_post_view(
             class_path=DOCUMENT_METADATA_REMOVE_ACTION_CLASS_PATH,
             extra_data={
-                'metadata_types': self.test_metadata_type.pk
+                'metadata_types': self._test_metadata_type.pk
             }
         )
         self.assertEqual(response.status_code, 302)
