@@ -13,9 +13,11 @@ class MirroringApp(MayanAppConfig):
     verbose_name = _('Mirroring')
 
     def ready(self):
-        super(MirroringApp, self).ready()
+        super().ready()
 
-        Document = apps.get_model(app_label='documents', model_name='Document')
+        Document = apps.get_model(
+            app_label='documents', model_name='Document'
+        )
         IndexInstanceNode = apps.get_model(
             app_label='document_indexing', model_name='IndexInstanceNode'
         )
