@@ -1,6 +1,10 @@
+import shutil
+
+from django.utils.encoding import force_text
 from django.utils.module_loading import import_string
 
 from mayan.apps.converter.classes import ConverterBase
+from mayan.apps.storage.utils import TemporaryFile
 
 from .settings import setting_ocr_backend, setting_ocr_backend_arguments
 
@@ -28,3 +32,13 @@ class OCRBackendBase:
 
         for transformation in transformations:
             self.converter.transform(transformation=transformation)
+
+        image = self.converter.get_page()
+
+        with TemporaryFile() as temporary_image_file:
+            shutil.copyfileobj(fsrc=image, fdst=temporary_image_file)
+            temporary_image_file.seek(0)
+
+            return force_text(
+                s=self._execute(image_file_object=temporary_image_file)
+            )
