@@ -1,5 +1,4 @@
 from django import forms
-from django.utils.encoding import force_text
 from django.utils.html import conditional_escape
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _, ugettext
@@ -33,9 +32,11 @@ class DocumentVersionPageOCRContentDetailForm(forms.Form):
             Not critical, just ignore and display empty content.
             """
         else:
-            content = conditional_escape(force_text(s=page_content))
+            content = conditional_escape(
+                str(page_content)
+            )
 
-        self.fields['contents'].initial = mark_safe(content)
+        self.fields['contents'].initial = mark_safe(s=content)
 
 
 class DocumentVersionPageOCRContentEditForm(forms.ModelForm):
@@ -87,7 +88,11 @@ class DocumentVersionOCRContentForm(forms.Form):
                 Not critical, just ignore and proceed to next page.
                 """
             else:
-                content.append(conditional_escape(force_text(s=page_content)))
+                content.append(
+                    conditional_escape(
+                        text=str(page_content)
+                    )
+                )
                 content.append(
                     '\n\n\n<hr/><div class="document-page-content-divider">- %s -</div><hr/>\n\n\n' % (
                         ugettext(
@@ -96,4 +101,6 @@ class DocumentVersionOCRContentForm(forms.Form):
                     )
                 )
 
-        self.fields['contents'].initial = mark_safe(''.join(content))
+        self.fields['contents'].initial = mark_safe(
+            s=''.join(content)
+        )
