@@ -7,13 +7,13 @@ queue_ocr = CeleryQueue(name='ocr', label=_('OCR'), worker=worker_d)
 
 queue_ocr.add_task_type(
     dotted_path='mayan.apps.ocr.tasks.task_document_version_ocr_finished',
-    label=_('Finish document file OCR')
+    label=_('Finish document version OCR')
 )
 queue_ocr.add_task_type(
     dotted_path='mayan.apps.ocr.tasks.task_document_version_page_ocr_process',
-    label=_('Document file page OCR')
+    label=_('Document version page OCR')
 )
 queue_ocr.add_task_type(
     dotted_path='mayan.apps.ocr.tasks.task_document_version_ocr_process',
-    label=_('Document file OCR')
+    label=_('Document version OCR')
 )
