@@ -1,5 +1,6 @@
 from ..events import event_ocr_document_version_finished
 from ..models import DocumentVersionPageOCRContent
+from ..tasks import task_document_version_ocr_process
 
 from .literals import (
     TEST_DOCUMENT_VERSION_OCR_CONTENT,
@@ -63,37 +64,14 @@ class DocumentVersionOCRAPIViewTestMixin:
         )
 
 
-class DocumentVersionPageOCRAPIViewTestMixin:
-    def _request_test_document_version_page_ocr_content_detail_api_view_via_get(self):
-        return self.get(
-            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
-                'document_id': self._test_document.pk,
+class DocumentVersionOCRTaskTestMixin:
+    def _execute_task_document_version_ocr_process(self):
+        task_document_version_ocr_process.apply_async(
+            kwargs={
                 'document_version_id': self._test_document_version.pk,
-                'document_version_page_id': self._test_document_version_page.pk
+                'user_id': self._test_case_user.pk
             }
-        )
-
-    def _request_test_document_version_page_ocr_content_edit_api_view_via_patch(self):
-        return self.patch(
-            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
-                'document_id': self._test_document.pk,
-                'document_version_id': self._test_document_version.pk,
-                'document_version_page_id': self._test_document_version_page.pk
-            }, data={
-                'content': TEST_DOCUMENT_VERSION_PAGE_OCR_CONTENT_UPDATED
-            }
-        )
-
-    def _request_test_document_version_page_ocr_content_edit_api_view_via_put(self):
-        return self.put(
-            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
-                'document_id': self._test_document.pk,
-                'document_version_id': self._test_document_version.pk,
-                'document_version_page_id': self._test_document_version_page.pk
-            }, data={
-                'content': TEST_DOCUMENT_VERSION_PAGE_OCR_CONTENT_UPDATED
-            }
-        )
+        ).get()
 
 
 class DocumentVersionOCRTestMixin:
@@ -167,6 +145,39 @@ class DocumentVersionOCRViewTestMixin:
         )
 
 
+class DocumentVersionPageOCRAPIViewTestMixin:
+    def _request_test_document_version_page_ocr_content_detail_api_view_via_get(self):
+        return self.get(
+            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
+                'document_id': self._test_document.pk,
+                'document_version_id': self._test_document_version.pk,
+                'document_version_page_id': self._test_document_version_page.pk
+            }
+        )
+
+    def _request_test_document_version_page_ocr_content_edit_api_view_via_patch(self):
+        return self.patch(
+            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
+                'document_id': self._test_document.pk,
+                'document_version_id': self._test_document_version.pk,
+                'document_version_page_id': self._test_document_version_page.pk
+            }, data={
+                'content': TEST_DOCUMENT_VERSION_PAGE_OCR_CONTENT_UPDATED
+            }
+        )
+
+    def _request_test_document_version_page_ocr_content_edit_api_view_via_put(self):
+        return self.put(
+            viewname='rest_api:document-version-page-ocr-content-detail-view', kwargs={
+                'document_id': self._test_document.pk,
+                'document_version_id': self._test_document_version.pk,
+                'document_version_page_id': self._test_document_version_page.pk
+            }, data={
+                'content': TEST_DOCUMENT_VERSION_PAGE_OCR_CONTENT_UPDATED
+            }
+        )
+
+
 class DocumentVersionPageOCRViewTestMixin:
     def _request_test_document_version_page_ocr_content_detail_view(self):
         return self.get(
