@@ -1,10 +1,10 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.document_states.classes import WorkflowAction
-from mayan.apps.documents.models.document_page_models import DocumentPage
+from mayan.apps.documents.models.document_version_page_models import DocumentVersionPage
 from mayan.apps.templating.classes import Template
 
-from .models import DocumentPageOCRContent
+from .models import DocumentVersionPageOCRContent
 
 __all__ = ('UpdateDocumentPageOCRAction',)
 
@@ -23,8 +23,8 @@ class UpdateDocumentPageOCRAction(WorkflowAction):
                     'the Python logical None, or an empty string (\'\') '
                     'are considered to be logical false, any other value is '
                     'considered to be the logical true.'
-                ), 'required': False, 'model': DocumentPage,
-                'model_variable': 'document_page',
+                ), 'required': False, 'model': DocumentVersionPage,
+                'model_variable': 'document_page'
             }
         },
         'page_content': {
@@ -34,10 +34,10 @@ class UpdateDocumentPageOCRAction(WorkflowAction):
                 'initial_help_text': _(
                     'A template that will generate the OCR content to be '
                     'saved.'
-                ), 'required': False, 'model': DocumentPage,
-                'model_variable': 'document_page',
+                ), 'required': False, 'model': DocumentVersionPage,
+                'model_variable': 'document_page'
             }
-        },
+        }
     }
     field_order = ('page_condition', 'page_content')
     label = _('Update document page OCR content')
@@ -51,11 +51,11 @@ class UpdateDocumentPageOCRAction(WorkflowAction):
             return False
 
     def execute(self, context):
-        for document_page in context['document'].pages_valid:
-            context['document_page'] = document_page
+        for document_version_page in context['document'].pages:
+            context['document_version_page'] = document_version_page
             if self.evaluate_condition(context=context, condition=self.form_data['page_condition']):
-                DocumentPageOCRContent.objects.update_or_create(
-                    document_page=document_page, defaults={
+                DocumentVersionPageOCRContent.objects.update_or_create(
+                    document_version_page=document_version_page, defaults={
                         'content': Template(
                             template_string=self.form_data['page_content']
                         ).render(context=context)
