@@ -15,7 +15,7 @@ from .mixins import (
 )
 
 
-class RoleViewsTestCase(
+class RoleViewTestCase(
     RoleTestMixin, RoleViewTestMixin, GenericViewTestCase
 ):
     def test_role_creation_view_no_permission(self):
@@ -47,17 +47,17 @@ class RoleViewsTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_created.id)
 
-    def test_role_delete_single_view_no_permission(self):
+    def test_role_single_delete_view_no_permission(self):
         self._create_test_role()
 
         role_count = Role.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_role_delete_single_view()
+        response = self._request_test_role_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(Role.objects.count(), role_count)
@@ -65,18 +65,18 @@ class RoleViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_role_delete_single_view_with_access(self):
+    def test_role_single_delete_view_with_access(self):
         self._create_test_role()
 
         self.grant_access(
-            obj=self.test_role, permission=permission_role_delete
+            obj=self._test_role, permission=permission_role_delete
         )
 
         role_count = Role.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_role_delete_single_view()
+        response = self._request_test_role_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(Role.objects.count(), role_count - 1)
@@ -84,14 +84,14 @@ class RoleViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_role_delete_multiple_view_no_permission(self):
+    def test_role_multiple_delete_view_no_permission(self):
         self._create_test_role()
 
         role_count = Role.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_role_delete_multiple_view()
+        response = self._request_test_role_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(Role.objects.count(), role_count)
@@ -99,18 +99,18 @@ class RoleViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_role_delete_multiple_view_with_access(self):
+    def test_role_multiple_delete_view_with_access(self):
         self._create_test_role()
 
         role_count = Role.objects.count()
 
         self.grant_access(
-            obj=self.test_role, permission=permission_role_delete
+            obj=self._test_role, permission=permission_role_delete
         )
 
         self._clear_events()
 
-        response = self._request_test_role_delete_multiple_view()
+        response = self._request_test_role_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(Role.objects.count(), role_count - 1)
@@ -120,7 +120,7 @@ class RoleViewsTestCase(
 
     def test_role_edit_view_no_permission(self):
         self._create_test_role()
-        role_label = self.test_role.label
+        role_label = self._test_role.label
 
         self._clear_events()
 
@@ -128,32 +128,32 @@ class RoleViewsTestCase(
 
         self.assertEqual(response.status_code, 404)
 
-        self.test_role.refresh_from_db()
-        self.assertEqual(self.test_role.label, role_label)
+        self._test_role.refresh_from_db()
+        self.assertEqual(self._test_role.label, role_label)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_role_edit_view_with_access(self):
         self._create_test_role()
-        self.grant_access(obj=self.test_role, permission=permission_role_edit)
+        self.grant_access(obj=self._test_role, permission=permission_role_edit)
 
-        role_label = self.test_role.label
+        role_label = self._test_role.label
 
         self._clear_events()
 
         response = self._request_test_role_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_role.refresh_from_db()
-        self.assertNotEqual(self.test_role.label, role_label)
+        self._test_role.refresh_from_db()
+        self.assertNotEqual(self._test_role.label, role_label)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
     def test_role_list_view_no_permission(self):
@@ -164,7 +164,7 @@ class RoleViewsTestCase(
         response = self._request_test_role_list_view()
         self.assertEqual(response.status_code, 200)
         self.assertNotContains(
-            response=response, text=self.test_role.label, status_code=200
+            response=response, text=self._test_role.label, status_code=200
         )
 
         events = self._get_test_events()
@@ -172,13 +172,13 @@ class RoleViewsTestCase(
 
     def test_role_list_view_with_access(self):
         self._create_test_role()
-        self.grant_access(obj=self.test_role, permission=permission_role_view)
+        self.grant_access(obj=self._test_role, permission=permission_role_view)
 
         self._clear_events()
 
         response = self._request_test_role_list_view()
         self.assertContains(
-            response=response, text=self.test_role.label, status_code=200
+            response=response, text=self._test_role.label, status_code=200
         )
 
         events = self._get_test_events()
@@ -195,17 +195,17 @@ class RoleGroupAddRemoveViewTestCase(
         self._create_test_group()
 
     def test_role_group_add_remove_get_view_no_permission(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self._clear_events()
 
         response = self._request_test_role_group_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -213,10 +213,10 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_role_group_add_remove_get_view_with_role_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -224,11 +224,11 @@ class RoleGroupAddRemoveViewTestCase(
 
         response = self._request_test_role_group_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=200
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -236,10 +236,10 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_role_group_add_remove_get_view_with_group_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -247,11 +247,11 @@ class RoleGroupAddRemoveViewTestCase(
 
         response = self._request_test_role_group_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -259,14 +259,14 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_role_group_add_remove_get_view_with_full_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -274,11 +274,11 @@ class RoleGroupAddRemoveViewTestCase(
 
         response = self._request_test_role_group_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -292,7 +292,7 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group not in self.test_role.groups.all()
+            self._test_group not in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
@@ -300,7 +300,7 @@ class RoleGroupAddRemoveViewTestCase(
 
     def test_role_group_add_view_with_role_access(self):
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -310,7 +310,7 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_group not in self.test_role.groups.all()
+            self._test_group not in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
@@ -318,7 +318,7 @@ class RoleGroupAddRemoveViewTestCase(
 
     def test_role_group_add_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -328,7 +328,7 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group not in self.test_role.groups.all()
+            self._test_group not in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
@@ -336,11 +336,11 @@ class RoleGroupAddRemoveViewTestCase(
 
     def test_role_group_add_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -350,19 +350,19 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_group in self.test_role.groups.all()
+            self._test_group in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
     def test_role_group_remove_view_no_permission(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self._clear_events()
 
@@ -370,17 +370,17 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group in self.test_role.groups.all()
+            self._test_group in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_role_group_remove_view_with_role_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -390,17 +390,17 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_group in self.test_role.groups.all()
+            self._test_group in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_role_group_remove_view_with_group_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -410,21 +410,21 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group in self.test_role.groups.all()
+            self._test_group in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_role_group_remove_view_with_full_access(self):
-        self.test_role.groups.add(self.test_group)
+        self._test_role.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -434,15 +434,15 @@ class RoleGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_group not in self.test_role.groups.all()
+            self._test_group not in self._test_role.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
 
@@ -455,17 +455,17 @@ class RolePermissionAddRemoveViewTestCase(
         self._create_test_permission()
 
     def test_role_permission_add_remove_get_view_no_permission(self):
-        self.test_role.permissions.add(self.test_permission.stored_permission)
+        self._test_role.permissions.add(self._test_permission.stored_permission)
 
         self._clear_events()
 
         response = self._request_test_role_permission_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_permission),
+            response=response, text=str(self._test_permission),
             status_code=404
         )
 
@@ -481,10 +481,10 @@ class RolePermissionAddRemoveViewTestCase(
         GitLab issue #757 "Permissions list does not show an object until
         one has been created"
         """
-        self.test_role.permissions.add(self.test_permission.stored_permission)
+        self._test_role.permissions.add(self._test_permission.stored_permission)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -492,11 +492,11 @@ class RolePermissionAddRemoveViewTestCase(
 
         response = self._request_test_role_permission_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_permission),
+            response=response, text=str(self._test_permission),
             status_code=200
         )
 
@@ -510,7 +510,7 @@ class RolePermissionAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_permission.stored_permission not in self.test_role.permissions.all()
+            self._test_permission.stored_permission not in self._test_role.permissions.all()
         )
 
         events = self._get_test_events()
@@ -518,7 +518,7 @@ class RolePermissionAddRemoveViewTestCase(
 
     def test_role_permission_add_view_with_access(self):
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -528,21 +528,21 @@ class RolePermissionAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_permission.stored_permission in self.test_role.permissions.all()
+            self._test_permission.stored_permission in self._test_role.permissions.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(
-            events[0].action_object, self.test_permission.stored_permission
+            events[0].action_object, self._test_permission.stored_permission
         )
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
     def test_role_permission_remove_view_no_permission(self):
-        self.test_role.permissions.add(self.test_permission.stored_permission)
+        self._test_role.permissions.add(self._test_permission.stored_permission)
 
         self._clear_events()
 
@@ -550,17 +550,17 @@ class RolePermissionAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_permission.stored_permission in self.test_role.permissions.all()
+            self._test_permission.stored_permission in self._test_role.permissions.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_role_permission_remove_view_with_access(self):
-        self.test_role.permissions.add(self.test_permission.stored_permission)
+        self._test_role.permissions.add(self._test_permission.stored_permission)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -570,17 +570,17 @@ class RolePermissionAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_permission.stored_permission not in self.test_role.permissions.all()
+            self._test_permission.stored_permission not in self._test_role.permissions.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(
-            events[0].action_object, self.test_permission.stored_permission
+            events[0].action_object, self._test_permission.stored_permission
         )
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
 
@@ -594,17 +594,17 @@ class GroupRoleAddRemoveViewTestCase(
         self._create_test_role()
 
     def test_group_role_add_remove_get_view_no_permission(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self._clear_events()
 
         response = self._request_test_group_role_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=404
         )
 
@@ -612,10 +612,10 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_role_add_remove_get_view_with_group_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -623,11 +623,11 @@ class GroupRoleAddRemoveViewTestCase(
 
         response = self._request_test_group_role_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=200
         )
 
@@ -635,10 +635,10 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_role_add_remove_get_view_with_role_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -646,11 +646,11 @@ class GroupRoleAddRemoveViewTestCase(
 
         response = self._request_test_group_role_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=404
         )
 
@@ -658,14 +658,14 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_role_add_remove_get_view_with_full_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -673,11 +673,11 @@ class GroupRoleAddRemoveViewTestCase(
 
         response = self._request_test_group_role_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_role),
+            response=response, text=str(self._test_role),
             status_code=200
         )
 
@@ -691,7 +691,7 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_role not in self.test_group.roles.all()
+            self._test_role not in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
@@ -699,7 +699,7 @@ class GroupRoleAddRemoveViewTestCase(
 
     def test_group_role_add_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -709,7 +709,7 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_role not in self.test_group.roles.all()
+            self._test_role not in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
@@ -717,7 +717,7 @@ class GroupRoleAddRemoveViewTestCase(
 
     def test_group_role_add_view_with_role_access(self):
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -727,7 +727,7 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_role not in self.test_group.roles.all()
+            self._test_role not in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
@@ -735,11 +735,11 @@ class GroupRoleAddRemoveViewTestCase(
 
     def test_group_role_add_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -749,19 +749,19 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_role in self.test_group.roles.all()
+            self._test_role in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
 
     def test_group_role_remove_view_no_permission(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self._clear_events()
 
@@ -769,17 +769,17 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_role in self.test_group.roles.all()
+            self._test_role in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_role_remove_view_with_group_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
 
@@ -789,17 +789,17 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_role in self.test_group.roles.all()
+            self._test_role in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_role_remove_view_with_role_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -809,21 +809,21 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_role in self.test_group.roles.all()
+            self._test_role in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_role_remove_view_with_full_access(self):
-        self.test_group.roles.add(self.test_role)
+        self._test_group.roles.add(self._test_role)
 
         self.grant_access(
-            obj=self.test_group,
+            obj=self._test_group,
             permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_role,
+            obj=self._test_role,
             permission=permission_role_edit
         )
 
@@ -833,13 +833,13 @@ class GroupRoleAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_role not in self.test_group.roles.all()
+            self._test_role not in self._test_group.roles.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_role)
+        self.assertEqual(events[0].target, self._test_role)
         self.assertEqual(events[0].verb, event_role_edited.id)
