@@ -5,10 +5,9 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
 from mayan.apps.common.apps import MayanAppConfig
-from mayan.apps.converter.links import link_transformation_list
 from mayan.apps.common.menus import menu_list_facet
 
-from .layers import layer_redactions
+from .links import link_redaction_list
 from .transformations import *  # NOQA
 from .permissions import (
     permission_redaction_create, permission_redaction_delete,
@@ -29,7 +28,7 @@ class RedactionsApp(MayanAppConfig):
     static_media_ignore_patterns = (
         'redactions/node_modules/cropperjs/src/*',
         'redactions/node_modules/cropperjs/types/index.d.ts',
-        'redactions/node_modules/jquery-cropper/src/*',
+        'redactions/node_modules/jquery-cropper/src/*'
     )
     verbose_name = _('Redactions')
 
@@ -68,11 +67,6 @@ class RedactionsApp(MayanAppConfig):
             )
         )
 
-        link_redaction_list = link_transformation_list.copy(
-            layer=layer_redactions
-        )
-        link_redaction_list.text = _('Redactions')
-
         menu_list_facet.bind_links(
             links=(link_redaction_list,), sources=(
                 DocumentFilePage, DocumentVersionPage,
