@@ -22,12 +22,18 @@ class RESTAPIViewTestCase(RESTAPIViewTestMixin, GenericViewTestCase):
         response = self._request_test_browser_api_view()
         self.assertEqual(response.status_code, 200)
 
-    @unittest.skipIf(connection.vendor != 'sqlite', 'Skip for known Django issues #15802 and #27074')
+    @unittest.skipIf(
+        condition=connection.vendor != 'sqlite',
+        reason='Skip for known Django issues #15802 and #27074'
+    )
     def test_redoc_ui_view(self):
         response = self._request_test_redoc_ui_view()
         self.assertEqual(response.status_code, 200)
 
-    @unittest.skipIf(connection.vendor != 'sqlite', 'Skip for known Django issues #15802 and #27074')
+    @unittest.skipIf(
+        condition=connection.vendor != 'sqlite',
+        reason='Skip for known Django issues #15802 and #27074'
+    )
     def test_swagger_ui_view(self):
         response = self._request_test_swagger_ui_view()
         self.assertEqual(response.status_code, 200)
@@ -82,8 +88,8 @@ class BatchAPIRequestViewTestCase(BaseAPITestCase):
                 mayan_view_permissions = {
                     'POST': (self._test_permission,)
                 }
-                queryset = self.TestModel.objects.all()
                 serializer_class = TestModelSerializer
+                source_queryset = self.TestModel.objects.all()
 
             return TestView.as_view()
 
@@ -105,8 +111,8 @@ class BatchAPIRequestViewTestCase(BaseAPITestCase):
                     'PATCH': (self._test_permission,),
                     'PUT': (self._test_permission,)
                 }
-                queryset = TestModel.objects.all()
                 serializer_class = TestModelSerializer
+                source_queryset = TestModel.objects.all()
 
             return TestView.as_view()
 
@@ -382,8 +388,8 @@ class DynamicFieldSerializerAPIViewTestCase(
 
         class TestView(generics.RetrieveAPIView):
             lookup_url_kwarg = 'test_object_id'
-            queryset = self.TestModelChild.objects.all()
             serializer_class = local_serializer_class
+            source_queryset = self.TestModelChild.objects.all()
 
         return TestView
 
@@ -520,8 +526,8 @@ class DynamicFieldSerializerWithMixinAPIViewTestCase(
             external_object_queryset = self.TestModelChild.objects.all()
             external_object_pk_url_kwarg = 'test_object_id'
             lookup_url_kwarg = 'test_object_id'
-            queryset = self.TestModelChild.objects.all()
             serializer_class = local_serializer_class
+            source_queryset = self.TestModelChild.objects.all()
 
         return TestView
 
