@@ -8,7 +8,9 @@ from .literals import API_VERSION
 
 
 api_version_urls = [
-    url(regex=r'^$', name='api_version_root', view=APIVersionRoot.as_view()),
+    url(
+        regex=r'^$', name='api_version_root', view=APIVersionRoot.as_view()
+    ),
     url(
         regex=r'^auth/token/obtain/$', name='auth_token_obtain',
         view=BrowseableObtainAuthToken.as_view()
@@ -28,8 +30,12 @@ api_urls = [
         regex=r'^swagger(?P<format>.json|.yaml)$', name='schema-json',
         view=schema_view.without_ui(cache_timeout=None),
     ),
-    url(regex=r'^v{}/'.format(API_VERSION), view=include(api_version_urls)),
-    url(regex=r'^$', name='api_root', view=APIRoot.as_view())
+    url(
+        regex=r'^v{}/'.format(API_VERSION), view=include(api_version_urls)
+    ),
+    url(
+        regex=r'^$', name='api_root', view=APIRoot.as_view()
+    )
 ]
 
 urlpatterns = [
@@ -41,5 +47,7 @@ urlpatterns = [
         regex=r'^redoc/ui/$', name='schema-redoc',
         view=schema_view.with_ui('redoc', cache_timeout=None)
     ),
-    url(regex=r'^', view=include(api_urls))
+    url(
+        regex=r'^', view=include(api_urls)
+    )
 ]
