@@ -3,6 +3,13 @@ ENVIRONMENT_TEST_VALUE = '999999'
 
 TEST_BOOTSTAP_SETTING_NAME = 'TEST_BOOTSTRAP_SETTING'
 
+TEST_CONFIG_FILE_NAME = 'TEST_CONFIG_FILE_NAME'
+TEST_CONFIG_FILE_VALUE = 'TEST_CONFIG_FILE_VALUE'
+TEST_ENVIRONMENT_VARIABLE_NAME = 'TEST_ENVIRONMENT_VARIABLE_NAME'
+TEST_ENVIRONMENT_VALUE = 'TEST_ENVIRONMENT_VALUE'
+TEST_GLOBAL_NAME = 'TEST_GLOBAL_NAME'
+TEST_GLOBAL_VALUE = 'TEST_GLOBAL_VALUE'
+
 TEST_NAMESPACE_LABEL = 'test namespace label'
 TEST_NAMESPACE_NAME = 'test_namespace_name'
 
