@@ -1,7 +1,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.dependencies.classes import (
-    BinaryDependency, JavaScriptDependency, PythonDependency
+    BinaryDependency, PythonDependency
 )
 
 from .literals import DEFAULT_BINARY_SCANIMAGE_PATH
@@ -15,9 +15,6 @@ BinaryDependency(
         'mayan.apps.sources.source_backends.SourceBackendSANEScanner', {}
     ).get('scanimage_path', DEFAULT_BINARY_SCANIMAGE_PATH)
 )
-JavaScriptDependency(
-    module=__name__, name='dropzone', version_string='=5.9.3'
-)
 PythonDependency(
     module=__name__, name='flanker', version_string='==0.9.11'
 )
