@@ -10,18 +10,18 @@ from mayan.apps.documents.permissions import (
     permission_document_create, permission_document_file_new
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
-from mayan.apps.documents.tests.literals import TEST_COMPRESSED_DOCUMENT_PATH
+from mayan.apps.documents.tests.literals import TEST_FILE_COMPRESSED_PATH
 
 from ..source_backends.literals import SOURCE_UNCOMPRESS_CHOICE_ALWAYS
 
 from .mixins.base_mixins import (
     DocumentFileUploadViewTestMixin, DocumentUploadWizardViewTestMixin
 )
-from .mixins.web_form_source_mixins import WebFormSourceTestMixin
+from .mixins.web_form_source_mixins import WebFormSourceBackendTestMixin
 
 
 class WebFormDocumentUploadWizardViewTestCase(
-    WebFormSourceTestMixin, DocumentUploadWizardViewTestMixin,
+    WebFormSourceBackendTestMixin, DocumentUploadWizardViewTestMixin,
     GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
@@ -29,11 +29,11 @@ class WebFormDocumentUploadWizardViewTestCase(
     @override_settings(DOCUMENTS_LANGUAGE='fra')
     def test_default_document_language_setting(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         self._clear_events()
@@ -49,16 +49,16 @@ class WebFormDocumentUploadWizardViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_upload_compressed_file(self):
-        backend_data = self.test_source.get_backend_data()
+        backend_data = self._test_source.get_backend_data()
         backend_data['uncompress'] = SOURCE_UNCOMPRESS_CHOICE_ALWAYS
-        self.test_source.set_backend_data(obj=backend_data)
-        self.test_source.save()
+        self._test_source.set_backend_data(obj=backend_data)
+        self._test_source.save()
 
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -66,7 +66,7 @@ class WebFormDocumentUploadWizardViewTestCase(
         self._clear_events()
 
         response = self._request_upload_wizard_view(
-            document_path=TEST_COMPRESSED_DOCUMENT_PATH
+            document_path=TEST_FILE_COMPRESSED_PATH
         )
         self.assertEqual(response.status_code, 302)
 
@@ -98,7 +98,7 @@ class WebFormDocumentUploadWizardViewTestCase(
             test_document_versions[1].pages.last()
         )
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_documents[0])
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -125,7 +125,7 @@ class WebFormDocumentUploadWizardViewTestCase(
             events[4].verb, event_document_version_page_created.id
         )
 
-        self.assertEqual(events[5].action_object, self.test_document_type)
+        self.assertEqual(events[5].action_object, self._test_document_type)
         self.assertEqual(events[5].actor, self._test_case_user)
         self.assertEqual(events[5].target, test_documents[1])
         self.assertEqual(events[5].verb, event_document_created.id)
@@ -174,7 +174,7 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_document_type_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -191,7 +191,7 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -208,10 +208,10 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -220,7 +220,7 @@ class WebFormDocumentUploadWizardViewTestCase(
 
         response = self._request_upload_interactive_view()
         self.assertContains(
-            response=response, text=self.test_source.label, status_code=200
+            response=response, text=self._test_source.label, status_code=200
         )
 
         self.assertEqual(Document.objects.count(), test_document_count)
@@ -243,7 +243,7 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_document_type_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -260,7 +260,7 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -277,10 +277,10 @@ class WebFormDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_full_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -300,7 +300,7 @@ class WebFormDocumentUploadWizardViewTestCase(
         test_document_version = test_document.version_active
         test_document_version_page = test_document_version.pages.first()
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -329,11 +329,11 @@ class WebFormDocumentUploadWizardViewTestCase(
 
 
 class WebFormDocumentFileUploadViewTestCase(
-    DocumentFileUploadViewTestMixin, WebFormSourceTestMixin,
+    DocumentFileUploadViewTestMixin, WebFormSourceBackendTestMixin,
     GenericDocumentViewTestCase
 ):
     def test_document_file_upload_view_no_permission(self):
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
@@ -341,63 +341,63 @@ class WebFormDocumentFileUploadViewTestCase(
 
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count + 1
+            self._test_document.files.count(), file_count + 1
         )
 
         events = self._get_test_events()
@@ -432,92 +432,92 @@ class WebFormDocumentFileUploadViewTestCase(
 
     def test_trashed_document_file_upload_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count
+            self._test_document.files.count(), file_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_no_permission(self):
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count + 1)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count + 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 4)
@@ -551,48 +551,48 @@ class WebFormDocumentFileUploadViewTestCase(
 
     def test_trashed_document_file_upload_no_source_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_preserve_filename(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
 
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count + 1
+            self._test_document.files.count(), file_count + 1
         )
         self.assertEqual(
-            self.test_document.file_latest.filename,
-            self.test_document_filename
+            self._test_document.file_latest.filename,
+            self._test_document_filename
         )
 
         events = self._get_test_events()
@@ -627,7 +627,7 @@ class WebFormDocumentFileUploadViewTestCase(
 
 
 class WebFormDocumentCreateSourceSwitchLinkViewTestCase(
-    WebFormSourceTestMixin, DocumentUploadWizardViewTestMixin,
+    WebFormSourceBackendTestMixin, DocumentUploadWizardViewTestMixin,
     GenericDocumentViewTestCase
 ):
     auto_create_test_source = False
@@ -638,7 +638,7 @@ class WebFormDocumentCreateSourceSwitchLinkViewTestCase(
         self._create_test_web_form_source()
 
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
             obj=self._test_sources[1], permission=permission_document_create
@@ -664,7 +664,7 @@ class WebFormDocumentCreateSourceSwitchLinkViewTestCase(
 
 
 class WebFormDocumentFileUploadSourceSwitchLinkViewTestCase(
-    DocumentFileUploadViewTestMixin, WebFormSourceTestMixin,
+    DocumentFileUploadViewTestMixin, WebFormSourceBackendTestMixin,
     GenericDocumentViewTestCase
 ):
     auto_create_test_source = False
@@ -674,12 +674,12 @@ class WebFormDocumentFileUploadSourceSwitchLinkViewTestCase(
         self._create_test_web_form_source()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
             obj=self._test_sources[1], permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
@@ -691,9 +691,9 @@ class WebFormDocumentFileUploadSourceSwitchLinkViewTestCase(
             response=response, text=self._test_sources[1].label, status_code=200
         )
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count
+            self._test_document.files.count(), file_count
         )
 
         events = self._get_test_events()
