@@ -1,4 +1,5 @@
-from mayan.apps.events.classes import EventModelRegistry
+from django.urls import reverse
+
 from mayan.apps.testing.tests.base import BaseTestCase
 
 from ..models import DownloadFile, SharedUploadedFile
@@ -21,21 +22,13 @@ class DownloadFileModelTestCase(DownloadFileTestMixin, BaseTestCase):
 
         self.assertEqual(DownloadFile.objects.stale().count(), 1)
 
-    def test_method_get_absolute_url_without_content_object(self):
+    def test_method_get_absolute_url(self):
         self._create_test_download_file()
 
-        self.assertFalse(self.test_download_file.get_absolute_url())
-
-    def test_method_get_absolute_url_with_content_object(self):
-        self._create_test_object()
-        self.TestModel.add_to_class(
-            name='get_absolute_url', value=lambda self: 'test_value'
+        self.assertEqual(
+            self.test_download_file.get_absolute_url(),
+            reverse(viewname='storage:download_file_list')
         )
-        EventModelRegistry.register(model=self.TestModel)
-
-        self._create_test_download_file(content_object=self._test_object)
-
-        self.assertTrue(self.test_download_file.get_absolute_url())
 
 
 class SharedUploadedFileManagerTestCase(
