@@ -9,12 +9,13 @@ def method_document_get_tags(self, permission, user):
     DocumentTag = apps.get_model(app_label='tags', model_name='DocumentTag')
 
     return AccessControlList.objects.restrict_queryset(
-        permission=permission,
-        queryset=DocumentTag.objects.filter(documents=self), user=user
+        permission=permission, queryset=DocumentTag.objects.filter(
+            documents=self
+        ), user=user
     )
 
 
 method_document_get_tags.help_text = _(
-    'Return a the tags attached to the document.'
+    'Return the tags attached to the document.'
 )
 method_document_get_tags.short_description = _('get_tags()')
