@@ -1,5 +1,5 @@
 from mayan.apps.common.tests.mixins import ObjectCopyTestMixin
-from mayan.apps.documents.tests.mixins import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import BaseTestCase
 
 from .mixins import TagTestMixin
@@ -11,4 +11,4 @@ class TagCopyTestCase(
     def setUp(self):
         super().setUp()
         self._create_test_tag(add_test_document=True)
-        self.test_object = self.test_tag
+        self._test_object = self._test_tag
