@@ -25,7 +25,9 @@ class TagIndexingTestCase(
         )
 
     def test_indexing_tag_attach(self):
-        self._test_tag.attach_to(document=self._test_document)
+        self._test_tag.attach_to(
+            document=self._test_document, user=self._test_case_user
+        )
 
         value = self._test_tag.label
 
@@ -37,7 +39,9 @@ class TagIndexingTestCase(
         )
 
     def test_indexing_tag_delete(self):
-        self._test_tag.attach_to(document=self._test_document)
+        self._test_tag.attach_to(
+            document=self._test_document, user=self._test_case_user
+        )
 
         value = self._test_tag.label
 
@@ -51,7 +55,9 @@ class TagIndexingTestCase(
         )
 
     def test_indexing_tag_edit(self):
-        self._test_tag.attach_to(document=self._test_document)
+        self._test_tag.attach_to(
+            document=self._test_document, user=self._test_case_user
+        )
         value = self._test_tag.label
 
         self._test_tag.label = TEST_TAG_LABEL_EDITED
@@ -72,8 +78,12 @@ class TagIndexingTestCase(
         )
 
     def test_indexing_tag_remove(self):
-        self._test_tag.attach_to(document=self._test_document)
-        self._test_tag.remove_from(document=self._test_document)
+        self._test_tag.attach_to(
+            document=self._test_document, user=self._test_case_user
+        )
+        self._test_tag.remove_from(
+            document=self._test_document, user=self._test_case_user
+        )
         value = self._test_tag.label
 
         self.assertFalse(
