@@ -11,11 +11,13 @@ class APITemplateDetailView(generics.RetrieveAPIView):
     Returns the selected partial template details.
     get: Retrieve the details of the partial template.
     """
-    serializer_class = AJAXTemplateSerializer
     permission_classes = (IsAuthenticated,)
+    serializer_class = AJAXTemplateSerializer
 
     def get_object(self):
-        return AJAXTemplate.get(self.kwargs['name']).render(
+        return AJAXTemplate.get(
+            name=self.kwargs['name']
+        ).render(
             request=self.request
         )
 
@@ -24,8 +26,10 @@ class APITemplateListView(generics.ListAPIView):
     """
     Returns a list of all the available templates.
     """
-    serializer_class = AJAXTemplateSerializer
     permission_classes = (IsAuthenticated,)
+    serializer_class = AJAXTemplateSerializer
 
-    def get_queryset(self):
-        return AJAXTemplate.all(rendered=True, request=self.request)
+    def get_source_queryset(self):
+        return AJAXTemplate.all(
+            rendered=True, request=self.request
+        )
