@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.dynamic_search.classes import SearchModel
+from mayan.apps.dynamic_search.search_models import SearchModel
 
 from .permissions import permission_group_view, permission_user_view
 from .querysets import get_user_queryset
@@ -37,5 +37,5 @@ search_model_user.add_model_field(
     field='last_name', label=_('Last name')
 )
 search_model_user.add_model_field(
-    field='username', label=_('username')
+    field='username', label=_('Username')
 )
