@@ -55,7 +55,7 @@ class GroupAPITestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_created.id)
 
     def test_group_delete_api_view_no_permission(self):
@@ -75,7 +75,7 @@ class GroupAPITestCase(
     def test_group_delete_api_view_with_access(self):
         self._create_test_group()
         self.grant_access(
-            obj=self.test_group, permission=permission_group_delete
+            obj=self._test_group, permission=permission_group_delete
         )
         group_count = Group.objects.count()
 
@@ -103,14 +103,14 @@ class GroupAPITestCase(
     def test_group_detail_api_view_with_access(self):
         self._create_test_group()
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
 
         self._clear_events()
 
         response = self._request_test_group_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.data['id'], self.test_group.id)
+        self.assertEqual(response.data['id'], self._test_group.id)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -118,15 +118,15 @@ class GroupAPITestCase(
     def test_group_edit_api_view_via_patch_no_permission(self):
         self._create_test_group()
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_group.refresh_from_db()
-        self.assertEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -135,39 +135,39 @@ class GroupAPITestCase(
         self._create_test_group()
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_group.refresh_from_db()
-        self.assertNotEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertNotEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
     def test_group_edit_api_view_via_put_no_permission(self):
         self._create_test_group()
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_group.refresh_from_db()
-        self.assertEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -176,25 +176,25 @@ class GroupAPITestCase(
         self._create_test_group()
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_group.refresh_from_db()
-        self.assertNotEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertNotEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
     def test_group_list_api_view_no_permission(self):
@@ -213,14 +213,14 @@ class GroupAPITestCase(
         self._create_test_group()
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
 
         self._clear_events()
 
         response = self._request_test_group_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.data['results'][0]['id'], self.test_group.id)
+        self.assertEqual(response.data['results'][0]['id'], self._test_group.id)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -240,14 +240,14 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_user not in self.test_group.user_set.all())
+        self.assertTrue(self._test_user not in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_api_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -255,14 +255,14 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertTrue(self.test_user not in self.test_group.user_set.all())
+        self.assertTrue(self._test_user not in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_api_view_with_user_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -270,17 +270,17 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_user not in self.test_group.user_set.all())
+        self.assertTrue(self._test_user not in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -288,18 +288,18 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.assertTrue(self.test_user in self.test_group.user_set.all())
+        self.assertTrue(self._test_user in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_user)
+        self.assertEqual(events[0].action_object, self._test_user)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
     def test_group_user_list_api_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
@@ -310,10 +310,10 @@ class GroupUserAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_list_api_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
 
         self._clear_events()
@@ -326,9 +326,9 @@ class GroupUserAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_list_api_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
-        self.grant_access(obj=self.test_user, permission=permission_user_view)
+        self.grant_access(obj=self._test_user, permission=permission_user_view)
 
         self._clear_events()
 
@@ -339,42 +339,42 @@ class GroupUserAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_list_api_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
-        self.grant_access(obj=self.test_user, permission=permission_user_view)
+        self.grant_access(obj=self._test_user, permission=permission_user_view)
 
         self._clear_events()
 
         response = self._request_test_group_user_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['results'][0]['username'], self.test_user.username
+            response.data['results'][0]['username'], self._test_user.username
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_api_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
         response = self._request_test_group_user_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_user in self.test_group.user_set.all())
+        self.assertTrue(self._test_user in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_api_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -382,16 +382,16 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertTrue(self.test_user in self.test_group.user_set.all())
+        self.assertTrue(self._test_user in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_api_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -399,19 +399,19 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_user in self.test_group.user_set.all())
+        self.assertTrue(self._test_user in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_api_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -419,14 +419,14 @@ class GroupUserAPIViewTestCase(
         response = self._request_test_group_user_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.assertFalse(self.test_user in self.test_group.user_set.all())
+        self.assertFalse(self._test_user in self._test_group.user_set.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_user)
+        self.assertEqual(events[0].action_object, self._test_user)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
 
@@ -461,7 +461,7 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_created.id)
 
     def test_user_delete_api_view_no_permission(self):
@@ -482,7 +482,7 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
     def test_user_delete_api_view_with_access(self):
         self._create_test_user()
         self.grant_access(
-            obj=self.test_user, permission=permission_user_delete
+            obj=self._test_user, permission=permission_user_delete
         )
 
         user_count = get_user_model().objects.count()
@@ -511,7 +511,7 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
     def test_user_detail_api_view_with_access(self):
         self._create_test_user()
         self.grant_access(
-            obj=self.test_user, permission=permission_user_view
+            obj=self._test_user, permission=permission_user_view
         )
 
         self._clear_events()
@@ -519,7 +519,7 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
         response = self._request_test_user_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['username'], self.test_user.username
+            response.data['username'], self._test_user.username
         )
 
         events = self._get_test_events()
@@ -528,15 +528,15 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
     def test_user_edit_patch_api_view_no_permission(self):
         self._create_test_user()
 
-        user_username = self.test_user.username
+        user_username = self._test_user.username
 
         self._clear_events()
 
         response = self._request_test_user_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_user.refresh_from_db()
-        self.assertEqual(self.test_user.username, user_username)
+        self._test_user.refresh_from_db()
+        self.assertEqual(self._test_user.username, user_username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -545,39 +545,39 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
         self._create_test_user()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
-        user_username = self.test_user.username
+        user_username = self._test_user.username
 
         self._clear_events()
 
         response = self._request_test_user_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_user.refresh_from_db()
-        self.assertNotEqual(self.test_user.username, user_username)
+        self._test_user.refresh_from_db()
+        self.assertNotEqual(self._test_user.username, user_username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
     def test_user_edit_put_api_view_no_permission(self):
         self._create_test_user()
 
-        user_username = self.test_user.username
+        user_username = self._test_user.username
 
         self._clear_events()
 
         response = self._request_test_user_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_user.refresh_from_db()
-        self.assertEqual(self.test_user.username, user_username)
+        self._test_user.refresh_from_db()
+        self.assertEqual(self._test_user.username, user_username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -586,39 +586,39 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
         self._create_test_user()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
-        user_username = self.test_user.username
+        user_username = self._test_user.username
 
         self._clear_events()
 
         response = self._request_test_user_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_user.refresh_from_db()
-        self.assertNotEqual(self.test_user.username, user_username)
+        self._test_user.refresh_from_db()
+        self.assertNotEqual(self._test_user.username, user_username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
     def test_user_password_change_api_view_no_permission(self):
         self._create_test_user()
 
-        password_hash = self.test_user.password
+        password_hash = self._test_user.password
 
         self._clear_events()
 
         response = self._request_test_user_password_change_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_user.refresh_from_db()
-        self.assertEqual(self.test_user.password, password_hash)
+        self._test_user.refresh_from_db()
+        self.assertEqual(self._test_user.password, password_hash)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -627,25 +627,25 @@ class UserAPIViewTestCase(UserAPIViewTestMixin, BaseAPITestCase):
         self._create_test_user()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
-        password_hash = self.test_user.password
+        password_hash = self._test_user.password
 
         self._clear_events()
 
         response = self._request_test_user_password_change_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_user.refresh_from_db()
-        self.assertNotEqual(self.test_user.password, password_hash)
+        self._test_user.refresh_from_db()
+        self.assertNotEqual(self._test_user.password, password_hash)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
 
@@ -658,7 +658,7 @@ class UserGroupAPIViewTestCase(
         self._create_test_user()
 
     def test_user_group_list_api_view_no_permission(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self._clear_events()
 
@@ -669,10 +669,10 @@ class UserGroupAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_list_api_view_with_user_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_view
+            obj=self._test_user, permission=permission_user_view
         )
 
         self._clear_events()
@@ -685,10 +685,10 @@ class UserGroupAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_list_api_view_with_group_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
 
         self._clear_events()
@@ -700,13 +700,13 @@ class UserGroupAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_list_api_view_with_full_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_view
+            obj=self._test_user, permission=permission_user_view
         )
 
         self._clear_events()
@@ -714,7 +714,7 @@ class UserGroupAPIViewTestCase(
         response = self._request_test_user_group_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['results'][0]['name'], self.test_group.name
+            response.data['results'][0]['name'], self._test_group.name
         )
 
         events = self._get_test_events()
