@@ -249,14 +249,14 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_created.id)
 
-    def test_user_delete_view_no_permission(self):
+    def test_user_delete_get_view_no_permission(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
 
         self._clear_events()
 
-        response = self._request_test_user_single_delete_view()
+        response = self._request_test_user_single_delete_get_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(get_user_model().objects.count(), user_count)
@@ -264,7 +264,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_user_delete_view_with_access(self):
+    def test_user_delete_get_view_with_access(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
@@ -275,7 +275,75 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
 
         self._clear_events()
 
-        response = self._request_test_user_single_delete_view()
+        response = self._request_test_user_single_delete_get_view()
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(get_user_model().objects.count(), user_count)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_user_multiple_delete_get_view_no_permission(self):
+        self._create_test_user()
+
+        user_count = get_user_model().objects.count()
+
+        self._clear_events()
+
+        response = self._request_test_user_multiple_delete_get_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(get_user_model().objects.count(), user_count)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_user_multiple_delete_get_view_with_access(self):
+        self._create_test_user()
+
+        user_count = get_user_model().objects.count()
+
+        self.grant_access(
+            obj=self._test_user, permission=permission_user_delete
+        )
+
+        self._clear_events()
+
+        response = self._request_test_user_multiple_delete_get_view()
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(get_user_model().objects.count(), user_count)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_user_delete_post_view_no_permission(self):
+        self._create_test_user()
+
+        user_count = get_user_model().objects.count()
+
+        self._clear_events()
+
+        response = self._request_test_user_single_delete_post_view()
+        self.assertEqual(response.status_code, 404)
+
+        self.assertEqual(get_user_model().objects.count(), user_count)
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_user_delete_post_view_with_access(self):
+        self._create_test_user()
+
+        user_count = get_user_model().objects.count()
+
+        self.grant_access(
+            obj=self._test_user, permission=permission_user_delete
+        )
+
+        self._clear_events()
+
+        response = self._request_test_user_single_delete_post_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(get_user_model().objects.count(), user_count - 1)
@@ -283,14 +351,14 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_user_multiple_delete_view_no_permission(self):
+    def test_user_multiple_delete_post_view_no_permission(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
 
         self._clear_events()
 
-        response = self._request_test_user_multiple_delete_view()
+        response = self._request_test_user_multiple_delete_post_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(get_user_model().objects.count(), user_count)
@@ -298,7 +366,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_user_multiple_delete_view_with_access(self):
+    def test_user_multiple_delete_post_view_with_access(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
@@ -309,7 +377,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
 
         self._clear_events()
 
-        response = self._request_test_user_multiple_delete_view()
+        response = self._request_test_user_multiple_delete_post_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(get_user_model().objects.count(), user_count - 1)
