@@ -9,7 +9,7 @@ from mayan.apps.views.generics import (
     AddRemoveView, MultipleObjectDeleteView, SingleObjectCreateView,
     SingleObjectDetailView, SingleObjectEditView, SingleObjectListView
 )
-from mayan.apps.views.mixins import ExternalObjectViewMixin
+from mayan.apps.views.view_mixins import ExternalObjectViewMixin
 
 from ..icons import (
     icon_current_user_detail, icon_user_create, icon_user_edit,
@@ -29,7 +29,7 @@ from .view_mixins import DynamicUserFormFieldViewMixin
 
 class UserCreateView(SingleObjectCreateView):
     extra_context = {
-        'title': _('Create new user'),
+        'title': _('Create new user')
     }
     fields = FIELDS_ALL
     fieldsets = FIELDSETS_ALL
@@ -40,7 +40,7 @@ class UserCreateView(SingleObjectCreateView):
     def form_valid(self, form):
         super().form_valid(form=form)
         return HttpResponseRedirect(
-            reverse(
+            redirect_to=reverse(
                 viewname='authentication:user_set_password', kwargs={
                     'user_id': self.object.pk
                 }
@@ -55,13 +55,15 @@ class UserDeleteView(MultipleObjectDeleteView):
     error_message = _('Error deleting user "%(instance)s"; %(exception)s')
     object_permission = permission_user_delete
     pk_url_kwarg = 'user_id'
-    post_action_redirect = reverse_lazy(viewname='user_management:user_list')
+    post_action_redirect = reverse_lazy(
+        viewname='user_management:user_list'
+    )
+    success_message_plural = _('%(count)d users deleted successfully.')
     success_message_single = _('User "%(object)s" deleted successfully.')
     success_message_singular = _('%(count)d user deleted successfully.')
-    success_message_plural = _('%(count)d users deleted successfully.')
+    title_plural = _('Delete the %(count)d selected users.')
     title_single = _('Delete user: %(object)s.')
     title_singular = _('Delete the %(count)d selected user.')
-    title_plural = _('Delete the %(count)d selected users.')
     view_icon = icon_user_single_delete
 
     def get_extra_context(self, **kwargs):
@@ -73,6 +75,8 @@ class UserDeleteView(MultipleObjectDeleteView):
                     'process is not reversible.'
                 )
             }
+        else:
+            return {}
 
     def get_source_queryset(self):
         return get_user_queryset(user=self.request.user)
@@ -105,7 +109,7 @@ class UserEditView(DynamicUserFormFieldViewMixin, SingleObjectEditView):
     def get_extra_context(self):
         return {
             'object': self.object,
-            'title': _('Edit user: %s') % self.object,
+            'title': _('Edit user: %s') % self.object
         }
 
     def get_instance_extra_data(self):
@@ -116,25 +120,25 @@ class UserEditView(DynamicUserFormFieldViewMixin, SingleObjectEditView):
 
 
 class UserGroupAddRemoveView(AddRemoveView):
+    list_available_title = _('Available groups')
+    # Translators: "User groups" here refer to the list of groups of a
+    # specific user. The user's group membership.
+    list_added_title = _('User groups')
     main_object_method_add_name = 'groups_add'
     main_object_method_remove_name = 'groups_remove'
     main_object_permission = permission_user_edit
     main_object_pk_url_kwarg = 'user_id'
     secondary_object_model = Group
     secondary_object_permission = permission_group_edit
-    list_available_title = _('Available groups')
-    # Translators: "User groups" here refer to the list of groups of a
-    # specific user. The user's group membership.
-    list_added_title = _('User groups')
     view_icon = icon_user_group_list
 
     def get_actions_extra_kwargs(self):
-        return {'_event_actor': self.request.user}
+        return {'user': self.request.user}
 
     def get_extra_context(self):
         return {
             'object': self.main_object,
-            'title': _('Groups of user: %s') % self.main_object,
+            'title': _('Groups of user: %s') % self.main_object
         }
 
     def get_list_added_queryset(self):
@@ -163,7 +167,7 @@ class UserListView(SingleObjectListView):
                 'a user account you will prompted to set a password for it. '
             ),
             'no_results_title': _('There are no user accounts'),
-            'title': _('Users'),
+            'title': _('Users')
         }
 
     def get_source_queryset(self):
@@ -176,6 +180,9 @@ class UserOptionsEditView(ExternalObjectViewMixin, SingleObjectEditView):
     fields = ('block_password_change',)
     view_icon = icon_user_set_options
 
+    def get_external_object_queryset(self):
+        return get_user_queryset(user=self.request.user)
+
     def get_extra_context(self):
         return {
             'title': _(
@@ -194,6 +201,3 @@ class UserOptionsEditView(ExternalObjectViewMixin, SingleObjectEditView):
 
     def get_post_action_redirect(self):
         return reverse(viewname='user_management:user_list')
-
-    def get_external_object_queryset(self):
-        return get_user_queryset(user=self.request.user)
