@@ -4,9 +4,9 @@ clash with the mayan/settings/* module
 """
 from django.utils.translation import ugettext_lazy as _
 
-from mayan.apps.smart_settings.classes import Namespace
+from mayan.apps.smart_settings.classes import SettingNamespace
 
-namespace = Namespace(name='mayan', label=_('Mayan'))
+namespace = SettingNamespace(name='mayan', label=_('Mayan'))
 
 setting_celery_class = namespace.add_setting(
     help_text=_('The class used to instantiate the main Celery app.'),
