@@ -1,41 +1,44 @@
+from pathlib import Path
 import os
 import sys
 
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.smart_settings.literals import COMMAND_NAME_SETTINGS_REVERT
 from mayan.apps.smart_settings.utils import SettingNamespaceSingleton
 
 from .literals import DEFAULT_SECRET_KEY, SECRET_KEY_FILENAME, SYSTEM_DIR
 
-# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
-
-BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-
+BASE_DIR = Path(__file__).parent.parent
 # Quick-start development settings - unsuitable for production
 # See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/
 
-setting_namespace = SettingNamespaceSingleton(global_symbol_table=globals())
-if 'revertsettings' in sys.argv:
+setting_namespace = SettingNamespaceSingleton(
+    global_symbol_table=globals()
+)
+
+if COMMAND_NAME_SETTINGS_REVERT in sys.argv:
     setting_namespace.update_globals(only_critical=True)
     DATABASES = {
         'default': {
             'ENGINE': 'django.db.backends.sqlite3',
-            'NAME': os.path.join(MEDIA_ROOT, 'db.sqlite3')  # NOQA: F821
+            'NAME': Path(MEDIA_ROOT, 'db.sqlite3')  # NOQA: F821
         }
     }
 else:
     setting_namespace.update_globals()
 
-environment_secret_key = os.environ.get('MAYAN_SECRET_KEY')
-if environment_secret_key:
-    SECRET_KEY = environment_secret_key
-else:
-    SECRET_KEY_PATH = os.path.join(MEDIA_ROOT, SYSTEM_DIR, SECRET_KEY_FILENAME)
+try:
+    SECRET_KEY = os.environ['MAYAN_SECRET_KEY']
+except KeyError:
+    path_secret_key = Path(
+        MEDIA_ROOT, SYSTEM_DIR, SECRET_KEY_FILENAME  # NOQA: F821
+    )
     try:
-        with open(file=SECRET_KEY_PATH) as file_object:  # NOQA: F821
+        with path_secret_key.open(mode='rb') as file_object:  # NOQA: F821
             SECRET_KEY = file_object.read().strip()
-    except IOError:
+    except FileNotFoundError:
         SECRET_KEY = DEFAULT_SECRET_KEY
 
 # Application definition
@@ -60,6 +63,7 @@ INSTALLED_APPS = (
     'django_celery_beat',
     'formtools',
     'mathfilters',
+    'mozilla_django_oidc',
     'mptt',
     'rest_framework',
     'rest_framework.authtoken',
@@ -78,6 +82,7 @@ INSTALLED_APPS = (
     # and User models are properly setup using runtime methods.
     'mayan.apps.user_management',
     'mayan.apps.authentication',
+    'mayan.apps.authentication_oidc',
     'mayan.apps.authentication_otp',
     'mayan.apps.autoadmin',
     'mayan.apps.common',
@@ -110,6 +115,8 @@ INSTALLED_APPS = (
     'mayan.apps.cabinets',
     'mayan.apps.checkouts',
     'mayan.apps.document_comments',
+    'mayan.apps.document_downloads',
+    'mayan.apps.document_exports',
     'mayan.apps.document_indexing',
     'mayan.apps.document_parsing',
     'mayan.apps.document_signatures',
@@ -129,7 +136,7 @@ INSTALLED_APPS = (
     'mayan.apps.tags',
     'mayan.apps.web_links',
     # Placed after rest_api to allow template overriding.
-    'drf_yasg'
+    'drf_yasg',
 )
 
 MIDDLEWARE = (
@@ -246,7 +253,7 @@ MEDIA_URL = 'media/'
 SITE_ID = 1
 
 STATIC_ROOT = os.environ.get(
-    'MAYAN_STATIC_ROOT', os.path.join(MEDIA_ROOT, 'static')  # NOQA: F821
+    'MAYAN_STATIC_ROOT', Path(MEDIA_ROOT, 'static')  # NOQA: F821
 )
 
 MEDIA_URL = 'media/'
@@ -272,7 +279,8 @@ REST_FRAMEWORK = {
         'rest_framework.authentication.TokenAuthentication',
         'rest_framework.authentication.BasicAuthentication'
     ),
-    'DEFAULT_PAGINATION_CLASS': 'mayan.apps.rest_api.pagination.MayanPageNumberPagination'
+    'DEFAULT_PAGINATION_CLASS': 'mayan.apps.rest_api.pagination.MayanPageNumberPagination',
+    'EXCEPTION_HANDLER': 'mayan.apps.rest_api.exception_handlers.mayan_exception_handler'
 }
 
 # --------- Pagination --------
@@ -332,22 +340,32 @@ for app in INSTALLED_APPS:
         )
 
 repeated_apps = tuple(
-    set(COMMON_EXTRA_APPS_PRE).intersection(set(COMMON_EXTRA_APPS))
+    set(COMMON_EXTRA_APPS_PRE).intersection(  # NOQA: F821
+        set(COMMON_EXTRA_APPS)  # NOQA: F821
+    )
 )
 if repeated_apps:
     raise ImproperlyConfigured(
         'Apps "{}" cannot be specified in `COMMON_EXTRA_APPS_PRE` and '
         '`COMMON_EXTRA_APPS` at the same time.'.format(
-            ', '.join(tuple(repeated_apps))
+            ', '.join(
+                tuple(repeated_apps)
+            )
         )
     )
 
-INSTALLED_APPS = tuple(COMMON_EXTRA_APPS_PRE or ()) + INSTALLED_APPS  # NOQA: F821
+INSTALLED_APPS = tuple(
+    COMMON_EXTRA_APPS_PRE or ()  # NOQA: F821
+) + INSTALLED_APPS
 
-INSTALLED_APPS = INSTALLED_APPS + tuple(COMMON_EXTRA_APPS or ())  # NOQA: F821
+INSTALLED_APPS = INSTALLED_APPS + tuple(
+    COMMON_EXTRA_APPS or ()  # NOQA: F821
+)
 
 INSTALLED_APPS = [
-    APP for APP in INSTALLED_APPS if APP not in (COMMON_DISABLED_APPS or ())  # NOQA: F821
+    APP for APP in INSTALLED_APPS if APP not in (
+        COMMON_DISABLED_APPS or ()  # NOQA: F821
+    )
 ]
 
 if not DATABASES:
@@ -367,6 +385,8 @@ if not DATABASES:
         DATABASES = {
             'default': {
                 'ENGINE': 'django.db.backends.sqlite3',
-                'NAME': os.path.join(MEDIA_ROOT, 'db.sqlite3')  # NOQA: F821
+                'NAME': str(
+                    Path(MEDIA_ROOT, 'db.sqlite3')  # NOQA: F821
+                )
             }
         }
