@@ -18,15 +18,37 @@ DEFAULT_USER_SETTINGS_MODULE = 'user_settings'
 DOCKER_HOST_REGISTRY_NAME = 'docker-registry.local'
 DOCKER_HOST_REGISTRY_PORT = 5000
 DOCKER_IMAGE_MAYAN_NAME = 'mayanedms/mayanedms'
-DOCKER_DIND_IMAGE_VERSION = 'docker:20-dind'
-DOCKER_ELASTIC_IMAGE_VERSION = 'docker.elastic.co/elasticsearch/elasticsearch:7.17.0'
-DOCKER_LINUX_IMAGE_VERSION = 'debian:11.4-slim'
+DOCKER_KEYCLOAK_IMAGE_VERSION = 'keycloak/keycloak:20.0.1'
+DOCKER_DIND_IMAGE_VERSION = 'docker:20.10.21-dind'
+DOCKER_ELASTIC_IMAGE_VERSION = 'elasticsearch:7.17.7'
+DOCKER_LINUX_IMAGE_VERSION = 'debian:11.5-slim'
 DOCKER_MYSQL_IMAGE_VERSION = 'mysql:8.0'
 DOCKER_ORACLE_IMAGE_VERSION = 'wnameless/oracle-xe-11g-r2'
-DOCKER_POSTGRES_IMAGE_VERSION = 'postgres:12.11-alpine'
+DOCKER_POSTGRES_IMAGE_VERSION = 'postgres:13.8-alpine'
 DOCKER_PYTHON_IMAGE_VERSION = 'python:3.10-slim'
-DOCKER_RABBITMQ_IMAGE_VERSION = 'rabbitmq:3.10-alpine'
-DOCKER_REDIS_IMAGE_VERSION = 'redis:6.2-alpine'
+DOCKER_RABBITMQ_IMAGE_VERSION = 'rabbitmq:3.11.2-alpine'
+DOCKER_REDIS_IMAGE_VERSION = 'redis:7.0.5-alpine'
+GIT_REMOTE_NAME = 'origin'
+GITLAB_CI_BRANCH_BUILDS_DOCKER = 'builds/docker'
+GITLAB_CI_BRANCH_BUILDS_DOCUMENTATION = 'builds/documentation'
+GITLAB_CI_BRANCH_BUILDS_PYTHON = 'builds/python'
+GITLAB_CI_BRANCH_DEPLOYMENTS_DEMO = 'deployments/demo'
+GITLAB_CI_BRANCH_DEPLOYMENTS_STAGING = 'deployments/staging'
+GITLAB_CI_BRANCH_RELEASES_ALL_MAJOR = 'releases/all/major'
+GITLAB_CI_BRANCH_RELEASES_ALL_MINOR = 'releases/all/minor'
+GITLAB_CI_BRANCH_RELEASES_DOCKER_MAJOR = 'releases/docker/major'
+GITLAB_CI_BRANCH_RELEASES_DOCKER_MINOR = 'releases/docker/minor'
+GITLAB_CI_BRANCH_RELEASES_DOCUMENTATION = 'releases/documentation'
+GITLAB_CI_BRANCH_RELEASES_NIGHTLY = 'releases/nightly'
+GITLAB_CI_BRANCH_RELEASES_PYTHON_MAJOR = 'releases/python/major'
+GITLAB_CI_BRANCH_RELEASES_PYTHON_MINOR = 'releases/python/minor'
+GITLAB_CI_BRANCH_RELEASES_STAGING = 'releases/staging'
+GITLAB_CI_BRANCH_RELEASES_TESTING = 'releases/testing'
+GITLAB_CI_BRANCH_TESTS_ALL = 'tests/all'
+GITLAB_CI_BRANCH_TESTS_DOCKER = 'tests/docker'
+GITLAB_CI_BRANCH_TESTS_PYTHON_ALL = 'tests/python/all'
+GITLAB_CI_BRANCH_TESTS_PYTHON_BASE = 'tests/python/base'
+GITLAB_CI_BRANCH_TESTS_PYTHON_UPGRADE = 'tests/python/upgrade'
 GUNICORN_LIMIT_REQUEST_LINE = 4094
 GUNICORN_MAX_REQUESTS = 500
 GUNICORN_REQUESTS_JITTER = 50
