@@ -13,7 +13,7 @@ DOCUMENT_PARSING_AUTO_PARSING = False
 FILE_METADATA_AUTO_PROCESS = False
 
 INSTALLED_APPS = [
-    cls for cls in INSTALLED_APPS if cls != 'whitenoise.runserver_nostatic'
+    cls for cls in INSTALLED_APPS if cls != 'whitenoise.runserver_nostatic'  # NOQA: F405
 ]
 
 LOGGING_LOG_FILE_PATH = '/tmp/mayan-errors.log'
@@ -23,7 +23,7 @@ LOGGING_LEVEL = 'WARNING'
 # Remove whitenoise from middlewares. Causes out of memory errors during test
 # suit.
 MIDDLEWARE = [
-    cls for cls in MIDDLEWARE if cls not in [
+    cls for cls in MIDDLEWARE if cls not in [  # NOQA: F405
         'common.middleware.error_logging.ErrorLoggingMiddleware',
         'django.middleware.security.SecurityMiddleware',
         'corsheaders.middleware.CorsMiddleware',
@@ -42,7 +42,7 @@ PASSWORD_HASHERS = (
     'django.contrib.auth.hashers.MD5PasswordHasher',
 )
 
-SEARCH_BACKEND = 'mayan.apps.dynamic_search.tests.backends.TestSearchBackend'
+SEARCH_BACKEND = 'mayan.apps.dynamic_search.tests.backends.TestSearchBackendProxy'
 
 STATICFILES_STORAGE = None
 
